@@ -33,20 +33,44 @@ A set of helper functions designed to help with initializing boto3/botocore
 connections.
 """
 
+from __future__ import annotations
+
 import json
 import os
+import sys
 import traceback
+import typing
+from typing import Any
+from typing import Callable
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Set
+from typing import Tuple
+from typing import Type
+from typing import Union
 
 BOTO3_IMP_ERR = None
 try:
     import boto3
     import botocore
+    from botocore.exceptions import ClientError
 
     HAS_BOTO3 = True
 except ImportError:
     BOTO3_IMP_ERR = traceback.format_exc()
     HAS_BOTO3 = False
 
+if typing.TYPE_CHECKING:
+    from typing_extensions import TypeAlias
+
+    from .retries import RetryingBotoClientWrapper
+
+    ClientType: TypeAlias = Union[botocore.client.BaseClient, RetryingBotoClientWrapper]
+    ResourceType: TypeAlias = boto3.resources.base.ServiceResource
+    BotoConn = Union[ClientType, ResourceType, Tuple[ClientType, ResourceType]]
+    from .modules import AnsibleAWSModule
+
 try:
     from packaging.version import Version
 
@@ -57,15 +81,13 @@ except ImportError:
 from ansible.module_utils._text import to_native
 from ansible.module_utils.ansible_release import __version__
 from ansible.module_utils.basic import missing_required_lib
-from ansible.module_utils.six import binary_type
-from ansible.module_utils.six import text_type
 
 from .common import get_collection_info
 from .exceptions import AnsibleBotocoreError
 from .retries import AWSRetry
 
-MINIMUM_BOTOCORE_VERSION = "1.29.0"
-MINIMUM_BOTO3_VERSION = "1.26.0"
+MINIMUM_BOTOCORE_VERSION = "1.34.0"
+MINIMUM_BOTO3_VERSION = "1.34.0"
 
 
 def _get_user_agent_string():
@@ -79,38 +101,37 @@ def _get_user_agent_string():
     return result
 
 
-def boto3_conn(module, conn_type=None, resource=None, region=None, endpoint=None, **params):
+def boto3_conn(
+    module: AnsibleAWSModule,
+    conn_type: str,
+    resource: Optional[str] = None,
+    region: Optional[str] = None,
+    endpoint: Optional[str] = None,
+    **params,
+) -> BotoConn:
     """
     Builds a boto3 resource/client connection cleanly wrapping the most common failures.
     Handles:
-        ValueError,
-        botocore.exceptions.ProfileNotFound, botocore.exceptions.PartialCredentialsError,
-        botocore.exceptions.NoCredentialsError, botocore.exceptions.ConfigParseError,
-        botocore.exceptions.NoRegionError
+        ValueError, botocore.exceptions.BotoCoreError
     """
     try:
         return _boto3_conn(conn_type=conn_type, resource=resource, region=region, endpoint=endpoint, **params)
-    except ValueError as e:
-        module.fail_json(
-            msg=f"Couldn't connect to AWS: {to_native(e)}",
-        )
-    except (
-        botocore.exceptions.ProfileNotFound,
-        botocore.exceptions.PartialCredentialsError,
-        botocore.exceptions.NoCredentialsError,
-        botocore.exceptions.ConfigParseError,
-    ) as e:
-        module.fail_json(
-            msg=to_native(e),
-        )
     except botocore.exceptions.NoRegionError:
         module.fail_json(
+            # pylint: disable-next=protected-access
             msg=f"The {module._name} module requires a region and none was found in configuration, "
             "environment variables or module parameters",
         )
+    except (ValueError, botocore.exceptions.BotoCoreError) as e:
+        if hasattr(module, "fail_json_aws"):
+            module.fail_json_aws(e, msg="Couldn't connect to AWS")
+        module.fail_json(msg=f"Couldn't connect to AWS: {to_native(e)}")
 
 
-def _merge_botocore_config(config_a, config_b):
+def _merge_botocore_config(
+    config_a: botocore.config.Config,
+    config_b: Union[botocore.config.Config, Dict],
+) -> botocore.config.Config:
     """
     Merges the extra configuration options from config_b into config_a.
     Supports both botocore.config.Config objects and dicts
@@ -122,7 +143,13 @@ def _merge_botocore_config(config_a, config_b):
     return config_a.merge(config_b)
 
 
-def _boto3_conn(conn_type=None, resource=None, region=None, endpoint=None, **params):
+def _boto3_conn(
+    conn_type: str,
+    resource: Optional[str] = None,
+    region: Optional[str] = None,
+    endpoint: Optional[str] = None,
+    **params,
+) -> BotoConn:
     """
     Builds a boto3 resource/client connection cleanly wrapping the most common failures.
     No exceptions are caught/handled.
@@ -157,8 +184,8 @@ def _boto3_conn(conn_type=None, resource=None, region=None, endpoint=None, **par
         return session.client(resource, config=config, region_name=region, endpoint_url=endpoint, **params)
     else:
         client = session.client(resource, config=config, region_name=region, endpoint_url=endpoint, **params)
-        resource = session.resource(resource, config=config, region_name=region, endpoint_url=endpoint, **params)
-        return client, resource
+        boto3_resource = session.resource(resource, config=config, region_name=region, endpoint_url=endpoint, **params)
+        return client, boto3_resource
 
 
 # Inventory plugins don't have access to the same 'module', they need to throw
@@ -166,7 +193,7 @@ def _boto3_conn(conn_type=None, resource=None, region=None, endpoint=None, **par
 boto3_inventory_conn = _boto3_conn
 
 
-def boto_exception(err):
+def boto_exception(err: Exception) -> str:
     """
     Extracts the error message from a boto exception.
 
@@ -174,16 +201,18 @@ def boto_exception(err):
     :return: Error message
     """
     if hasattr(err, "error_message"):
-        error = err.error_message
+        error = err.error_message  # pyright: ignore[reportAttributeAccessIssue]
     elif hasattr(err, "message"):
-        error = str(err.message) + " " + str(err) + " - " + str(type(err))
+        error = (
+            str(err.message) + " " + str(err) + " - " + str(type(err))  # pyright: ignore[reportAttributeAccessIssue]
+        )
     else:
         error = f"{Exception}: {err}"
 
     return error
 
 
-def _aws_region(params):
+def _aws_region(params: Dict) -> Optional[str]:
     region = params.get("region")
 
     if region:
@@ -197,19 +226,14 @@ def _aws_region(params):
         # Botocore doesn't like empty strings, make sure we default to None in the case of an empty
         # string.
         profile_name = params.get("profile") or None
-        return botocore.session.Session(profile=profile_name).get_config_variable("region")
-    except botocore.exceptions.ProfileNotFound:
+        return boto3.session.Session(profile_name=profile_name).region_name
+    except botocore.exceptions.BotoCoreError:
         return None
 
 
-def get_aws_region(module, boto3=None):  # pylint: disable=redefined-outer-name
-    if boto3 is not None:
-        module.deprecate(
-            "get_aws_region(): the boto3 parameter will be removed in a release after 2025-05-01. "
-            "The parameter has been ignored since release 4.0.0.",
-            date="2025-05-01",
-            collection_name="amazon.aws",
-        )
+def get_aws_region(
+    module: AnsibleAWSModule,
+) -> Optional[str]:
     try:
         return _aws_region(module.params)
     except AnsibleBotocoreError as e:
@@ -219,7 +243,7 @@ def get_aws_region(module, boto3=None):  # pylint: disable=redefined-outer-name
             module.fail_json(msg=e.message)
 
 
-def _aws_connection_info(params):
+def _aws_connection_info(params: Dict) -> Tuple[Optional[str], Optional[str], Dict[str, Any]]:
     endpoint_url = params.get("endpoint_url")
     access_key = params.get("access_key")
     secret_key = params.get("secret_key")
@@ -267,20 +291,15 @@ def _aws_connection_info(params):
         boto_params["aws_config"] = botocore.config.Config(**config)
 
     for param, value in boto_params.items():
-        if isinstance(value, binary_type):
-            boto_params[param] = text_type(value, "utf-8", "strict")
+        if isinstance(value, bytes):
+            boto_params[param] = str(value, "utf-8", "strict")
 
     return region, endpoint_url, boto_params
 
 
-def get_aws_connection_info(module, boto3=None):  # pylint: disable=redefined-outer-name
-    if boto3 is not None:
-        module.deprecate(
-            "get_aws_connection_info(): the boto3 parameter will be removed in a release after 2025-05-01. "
-            "The parameter has been ignored since release 4.0.0.",
-            date="2025-05-01",
-            collection_name="amazon.aws",
-        )
+def get_aws_connection_info(
+    module: AnsibleAWSModule,
+) -> Tuple[Optional[str], Optional[str], Dict]:
     try:
         return _aws_connection_info(module.params)
     except AnsibleBotocoreError as e:
@@ -290,13 +309,22 @@ def get_aws_connection_info(module, boto3=None):  # pylint: disable=redefined-ou
             module.fail_json(msg=e.message)
 
 
-def _paginated_query(client, paginator_name, **params):
+def _paginated_query(
+    client: ClientType,
+    paginator_name: str,
+    **params,
+) -> Any:
     paginator = client.get_paginator(paginator_name)
     result = paginator.paginate(**params).build_full_result()
     return result
 
 
-def paginated_query_with_retries(client, paginator_name, retry_decorator=None, **params):
+def paginated_query_with_retries(
+    client: ClientType,
+    paginator_name: str,
+    retry_decorator=None,
+    **params,
+) -> Any:
     """
     Performs a boto3 paginated query.
     By default uses uses AWSRetry.jittered_backoff(retries=10) to retry queries
@@ -315,7 +343,7 @@ def paginated_query_with_retries(client, paginator_name, retry_decorator=None, *
     return result
 
 
-def gather_sdk_versions():
+def gather_sdk_versions() -> Dict:
     """Gather AWS SDK (boto3 and botocore) dependency versions
 
     Returns {'boto3_version': str, 'botocore_version': str}
@@ -330,7 +358,10 @@ def gather_sdk_versions():
     )
 
 
-def is_boto3_error_code(code, e=None):
+def is_boto3_error_code(
+    code: Union[List, Tuple, Set, str],
+    e: Optional[BaseException] = None,
+) -> Type[Exception]:
     """Check if the botocore exception is raised by a specific error code.
 
     Returns ClientError if the error code matches, a dummy exception if it does not have an error code or does not match
@@ -343,20 +374,50 @@ def is_boto3_error_code(code, e=None):
     except botocore.exceptions.ClientError as e:
         # handle the generic error case for all other codes
     """
-    from botocore.exceptions import ClientError
-
     if e is None:
-        import sys
-
-        dummy, e, dummy = sys.exc_info()
-    if not isinstance(code, list):
+        e = sys.exc_info()[1]
+    if not isinstance(code, (list, tuple, set)):
         code = [code]
-    if isinstance(e, ClientError) and e.response["Error"]["Code"] in code:
-        return ClientError
+    try:
+        if isinstance(e, ClientError) and e.response["Error"]["Code"] in code:
+            return ClientError
+    except KeyError:
+        pass
     return type("NeverEverRaisedException", (Exception,), {})
 
 
-def is_boto3_error_message(msg, e=None):
+def is_boto3_error_httpstatus(
+    status: Union[List, Tuple, Set, int],
+    e: Optional[BaseException] = None,
+) -> Type[Exception]:
+    """Check if the botocore exception is raised by a specific HTTP status code.
+
+    Returns ClientError if the HTTP status code matches, a dummy exception if it does not have a status code or does not match
+
+    Example:
+    try:
+        ec2.describe_instances(InstanceIds=['potato'])
+    except is_boto3_error_httpstatus(501):
+        # handle the error for that status code case
+    except botocore.exceptions.ClientError as e:
+        # handle the generic error case for all other status codes
+    """
+    if e is None:
+        e = sys.exc_info()[1]
+    if not isinstance(status, (list, tuple, set)):
+        status = [status]
+    try:
+        if isinstance(e, ClientError) and e.response["ResponseMetadata"]["HTTPStatusCode"] in status:
+            return ClientError
+    except KeyError:
+        pass
+    return type("NeverEverRaisedException", (Exception,), {})
+
+
+def is_boto3_error_message(
+    msg: str,
+    e: Optional[BaseException] = None,
+) -> Type[Exception]:
     """Check if the botocore exception contains a specific error message.
 
     Returns ClientError if the error code matches, a dummy exception if it does not have an error code or does not match
@@ -369,20 +430,24 @@ def is_boto3_error_message(msg, e=None):
     except botocore.exceptions.ClientError as e:
         # handle the generic error case for all other codes
     """
-    from botocore.exceptions import ClientError
 
     if e is None:
-        import sys
-
-        dummy, e, dummy = sys.exc_info()
-    if isinstance(e, ClientError) and msg in e.response["Error"]["Message"]:
-        return ClientError
+        e = sys.exc_info()[1]
+    try:
+        if isinstance(e, ClientError) and msg in e.response["Error"]["Message"]:
+            return ClientError
+    except KeyError:
+        pass
     return type("NeverEverRaisedException", (Exception,), {})
 
 
-def get_boto3_client_method_parameters(client, method_name, required=False):
+def get_boto3_client_method_parameters(
+    client: ClientType,
+    method_name: str,
+    required=False,
+) -> List:
     op = client.meta.method_to_api_mapping.get(method_name)
-    input_shape = client._service_model.operation_model(op).input_shape
+    input_shape = client._service_model.operation_model(op).input_shape  # pylint: disable=protected-access
     if not input_shape:
         parameters = []
     elif required:
@@ -393,14 +458,16 @@ def get_boto3_client_method_parameters(client, method_name, required=False):
 
 
 # Used by normalize_boto3_result
-def _boto3_handler(obj):
+def _boto3_handler(obj: Any) -> Any:
     if hasattr(obj, "isoformat"):
         return obj.isoformat()
     else:
         return obj
 
 
-def normalize_boto3_result(result):
+def normalize_boto3_result(
+    result: Union[List, Dict, Set],
+) -> Union[List, Dict, Set]:
     """
     Because Boto3 returns datetime objects where it knows things are supposed to
     be dates we need to mass-convert them over to strings which Ansible/Jinja
@@ -411,16 +478,16 @@ def normalize_boto3_result(result):
     return json.loads(json.dumps(result, default=_boto3_handler))
 
 
-def enable_placebo(session):
+def enable_placebo(session: boto3.session.Session) -> None:
     """
     Helper to record or replay offline modules for testing purpose.
     """
+    # pylint: disable=import-outside-toplevel
     if "_ANSIBLE_PLACEBO_RECORD" in os.environ:
         import placebo
 
-        existing_entries = os.listdir(os.environ["_ANSIBLE_PLACEBO_RECORD"])
-        idx = len(existing_entries)
-        data_path = f"{os.environ['_ANSIBLE_PLACEBO_RECORD']}/{idx}"
+        recorded_entries = os.listdir(os.environ["_ANSIBLE_PLACEBO_RECORD"])
+        data_path = f"{os.environ['_ANSIBLE_PLACEBO_RECORD']}/{len(recorded_entries)}"
         os.mkdir(data_path)
         pill = placebo.attach(session, data_path=data_path)
         pill.record()
@@ -429,21 +496,25 @@ def enable_placebo(session):
 
         import placebo
 
-        existing_entries = sorted([int(i) for i in os.listdir(os.environ["_ANSIBLE_PLACEBO_REPLAY"])])
-        idx = str(existing_entries[0])
-        data_path = os.environ["_ANSIBLE_PLACEBO_REPLAY"] + "/" + idx
+        replay_entries = sorted([int(i) for i in os.listdir(os.environ["_ANSIBLE_PLACEBO_REPLAY"])])
+        data_path = f"{os.environ['_ANSIBLE_PLACEBO_REPLAY']}/{replay_entries[0]}"
         try:
             shutil.rmtree("_tmp")
         except FileNotFoundError:
             pass
         shutil.move(data_path, "_tmp")
-        if len(existing_entries) == 1:
+        if len(replay_entries) == 1:
             os.rmdir(os.environ["_ANSIBLE_PLACEBO_REPLAY"])
         pill = placebo.attach(session, data_path="_tmp")
         pill.playback()
+    # pylint: enable=import-outside-toplevel
 
 
-def check_sdk_version_supported(botocore_version=None, boto3_version=None, warn=None):
+def check_sdk_version_supported(
+    botocore_version: Optional[str] = None,
+    boto3_version: Optional[str] = None,
+    warn: Optional[Callable] = None,
+) -> bool:
     """Checks to see if the available boto3 / botocore versions are supported
     args:
         botocore_version: (str) overrides the minimum version of botocore supported by the collection
@@ -481,13 +552,13 @@ def check_sdk_version_supported(botocore_version=None, boto3_version=None, warn=
     return supported
 
 
-def _version_at_least(a, b):
+def _version_at_least(a: str, b: str) -> bool:
     if not HAS_PACKAGING:
         return True
     return Version(a) >= Version(b)
 
 
-def boto3_at_least(desired):
+def boto3_at_least(desired: str) -> bool:
     """Check if the available boto3 version is greater than or equal to a desired version.
 
     Usage:
@@ -499,7 +570,7 @@ def boto3_at_least(desired):
     return _version_at_least(existing["boto3_version"], desired)
 
 
-def botocore_at_least(desired):
+def botocore_at_least(desired: str) -> bool:
     """Check if the available botocore version is greater than or equal to a desired version.
 
     Usage:
