@@ -18,8 +18,8 @@ options:
   query:
     description:
       - Specifies the resource type for which to gather information.
-      - Defaults to C(all) when I(function_name) is specified.
-      - Defaults to C(config) when I(function_name) is NOT specified.
+      - Defaults to V(all) when O(function_name) is specified.
+      - Defaults to V(config) when O(function_name) is NOT specified.
     choices: [ "aliases", "all", "config", "mappings", "policy", "versions", "tags" ]
     type: str
   function_name:
@@ -29,7 +29,7 @@ options:
     type: str
   event_source_arn:
     description:
-      - When I(query=mappings), this is the Amazon Resource Name (ARN) of the Amazon Kinesis or DynamoDB stream.
+      - When O(query=mappings), this is the Amazon Resource Name (ARN) of the Amazon Kinesis or DynamoDB stream.
     type: str
 author:
   - Pierre Jodouin (@pjodouin)
@@ -48,6 +48,11 @@ EXAMPLES = r"""
     function_name: myFunction
   register: my_function_details
 
+# Get basic information about AWS Lambda Functions in the current region
+- name: List Lambda Functions
+  amazon.aws.lambda_info:
+  register: lambda_functions
+
 # List all versions of a function
 - name: List function versions
   amazon.aws.lambda_info:
@@ -70,14 +75,10 @@ RETURN = r"""
 ---
 function:
     description:
-        - lambda function list.
-        - C(function) has been deprecated in will be removed in the next major release after 2025-01-01.
-    returned: success
-    type: dict
-function.TheName:
-    description:
-        - lambda function information, including event, mapping, and version information.
-        - C(function) has been deprecated in will be removed in the next major release after 2025-01-01.
+        - Lambda function list, keyed by function name.
+        - Each key is a function name with a value containing the function information,
+          including event, mapping, and version information.
+        - RV(function) has been deprecated and will be removed in a release after 2025-01-01.
     returned: success
     type: dict
 functions:
@@ -90,7 +91,7 @@ functions:
     contains:
         aliases:
             description: The aliases associated with the function.
-            returned: when C(query) is I(aliases) or I(all)
+            returned: when O(query=aliases) or O(query=all)
             type: list
             elements: str
         architectures:
@@ -125,6 +126,15 @@ functions:
             returned: success
             type: str
             sample: 'My function'
+        ephermal_storage:
+            description: The size of the function /tmp directory in MB.
+            type: dict
+            contains:
+                size:
+                    description: The size of the function /tmp directory.
+                    type: int
+                    returned: always
+                    sample: 512
         environment:
             description: The function's environment variables.
             returned: when environment variables exist
@@ -170,7 +180,7 @@ functions:
             sample: '2017-08-01T00:00:00.000+0000'
         mappings:
             description: List of configuration information for each event source mapping.
-            returned: when C(query) is I(all) or I(mappings)
+            returned: when O(query=all) or O(query=mappings)
             type: list
             elements: dict
             contains:
@@ -211,9 +221,14 @@ functions:
             returned: on success
             type: int
             sample: 128
+        package_type:
+            description: The type of deployment package.
+            type: str
+            returned: always
+            sample: "Zip"
         policy:
             description: The policy associated with the function.
-            returned: when C(query) is I(all) or I(policy)
+            returned: when O(query=all) or O(query=policy)
             type: dict
         revision_id:
             description: The latest updated revision of the function or alias.
@@ -230,6 +245,29 @@ functions:
             returned: on success
             type: str
             sample: 'nodejs6.10'
+        runtime_version_config:
+            description: The ARN of the runtime and any errors that occured.
+            type: dict
+            contains:
+                runtime_version_arn:
+                    description: The ARN of the runtime version you want the function to use.
+                    type: str
+                    returned: always
+                    sample: "arn:aws:lambda:us-west-2::runtime:123456789012"
+        snap_start:
+            description: Snapshot of the initialized execution environment when you publish a function version.
+            type: dict
+            contains:
+                apply_on:
+                    description: When set to V(PublishedVersions), Lambda creates a snapshot of the execution environment when you publish a function version.
+                    type: str
+                    sample: "None"
+                    returned: always
+                optimization_status:
+                    description: This element indicates whether SnapStart is activated for the specified function version.
+                    type: str
+                    returned: always
+                    sample: "Off"
         tracing_config:
             description: The function's AWS X-Ray tracing configuration.
             returned: on success
@@ -253,7 +291,7 @@ functions:
             sample: '1'
         versions:
             description: List of Lambda function versions.
-            returned: when C(query) is I(all) or I(versions)
+            returned: when O(query=all) or O(query=versions)
             type: list
             elements: dict
         vpc_config:
