@@ -15,7 +15,7 @@ description:
     strings, generating download links and copying objects that are already stored in Amazon S3.
   - S3 buckets can be created or deleted using the M(amazon.aws.s3_bucket) module.
   - Compatible with AWS, DigitalOcean, Ceph, Walrus, FakeS3 and StorageGRID.
-  - When using non-AWS services, I(endpoint_url) should be specified.
+  - When using non-AWS services, O(endpoint_url) should be specified.
 options:
   bucket:
     description:
@@ -24,18 +24,18 @@ options:
     type: str
   dest:
     description:
-      - The destination file path when downloading an object/key when I(mode=get).
-      - Ignored when I(mode) is not C(get).
+      - The destination file path when downloading an object/key when O(mode=get).
+      - Ignored when O(mode) is not V(get).
     type: path
   encrypt:
     description:
-      - Asks for server-side encryption of the objects when I(mode=put) or I(mode=copy).
-      - Ignored when I(mode) is neither C(put) nor C(copy).
+      - Asks for server-side encryption of the objects when O(mode=put) or O(mode=copy).
+      - Ignored when O(mode) is neither V(put) nor V(copy).
     default: true
     type: bool
   encryption_mode:
     description:
-      - The encryption mode to use if I(encrypt=true).
+      - The encryption mode to use if O(encrypt=true).
     default: AES256
     choices:
       - AES256
@@ -44,46 +44,57 @@ options:
   expiry:
     description:
       - Time limit (in seconds) for the URL generated and returned by S3/Walrus when performing a
-        I(mode=put) or I(mode=geturl) operation.
-      - Ignored when I(mode) is neither C(put) nor C(geturl).
+        O(mode=put) or O(mode=geturl) operation.
+      - Ignored when O(mode) is neither V(put) nor V(geturl).
     default: 600
     aliases: ['expiration']
     type: int
   headers:
     description:
-      - Custom headers to use when I(mode=put) as a dictionary of key value pairs.
-      - Ignored when I(mode) is not C(put).
+      - Custom headers to use when O(mode=put) as a dictionary of key value pairs.
+      - Keys that match supported S3 object arguments are promoted to top‑level ExtraArgs. Supported keys include
+        C(ContentType), C(Content-Disposition), C(ContentEncoding), C(ContentLanguage), C(CacheControl), C(Expires),
+        C(ACL), C(GrantFullControl), C(GrantRead), C(GrantReadACP), C(GrantWriteACP), C(StorageClass),
+        C(ServerSideEncryption), C(SSECustomerAlgorithm), C(SSECustomerKey), C(SSECustomerKeyMD5), C(SSEKMSKeyId),
+        and C(WebsiteRedirectLocation). Remaining keys are stored under C(Metadata).
+      - Both header name styles C(ContentType) and C(Content-Type) are supported. Underscore variants like
+        C(content_type) are not promoted and will be placed under C(Metadata).
+      - If C(ContentType) is not provided, a type is guessed from C(src) when uploading from a file. When uploading
+        using C(content) or C(content_base64) the default is C(binary/octet-stream).
+      - Ignored when O(mode) is not V(put).
     type: dict
   marker:
     description:
       - Specifies the key to start with when using list mode. Object keys are returned in
         alphabetical order, starting with key after the marker in order.
     type: str
-    default: ''
   max_keys:
     description:
-      - Max number of results to return when I(mode=list), set this if you want to retrieve fewer
-        than the default 1000 keys.
-      - Ignored when I(mode) is not C(list).
-    default: 1000
+      - Max number of results to return when O(mode=list)
+      - When not set, B(all) keys will be returned.
+      - Ignored when O(mode) is not V(list).
     type: int
   metadata:
     description:
-      - Metadata to use when I(mode=put) or I(mode=copy) as a dictionary of key value pairs.
+      - Metadata to use when O(mode=copy), O(mode=create) or O(mode=put) as a dictionary of key value pairs.
+      - Keys that match supported S3 object arguments are promoted to top‑level ExtraArgs (for example C(ContentType)).
+        Remaining keys are applied as user metadata under C(Metadata).
     type: dict
   mode:
     description:
       - Switches the module behaviour between
-      - 'C(put): upload'
-      - 'C(get): download'
-      - 'C(geturl): return download URL'
-      - 'C(getstr): download object as string'
-      - 'C(list): list keys'
-      - 'C(create): create bucket directories'
-      - 'C(delobj): delete object'
-      - 'C(copy): copy object that is already stored in another bucket'
+      - 'V(put): upload'
+      - 'V(get): download'
+      - 'V(geturl): return download URL'
+      - 'V(getstr): download object as string'
+      - 'V(list): list keys'
+      - 'V(create): create bucket directories'
+      - 'V(delobj): delete object'
+      - 'V(copy): copy object that is already stored in another bucket'
       - Support for creating and deleting buckets was removed in release 6.0.0.
         To create and manage the bucket itself please use the M(amazon.aws.s3_bucket) module.
+      - Support for V(list) has been deprecated and will be removed in a release after 2026-11-01.
+        The M(amazon.aws.s3_object_info) module should be used instead of V(list).
     required: true
     choices: ['get', 'put', 'create', 'geturl', 'getstr', 'delobj', 'list', 'copy']
     type: str
@@ -94,22 +105,22 @@ options:
       - Object key names should not include the leading C(/), see
         U(https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html) for more
         information.
-      - Support for passing the leading C(/) has been deprecated and will be removed
+      - Support for passing the leading V(/) has been deprecated and will be removed
         in a release after 2025-12-01.
     type: str
   sig_v4:
     description:
       - Forces the Boto SDK to use Signature Version 4.
-      - Only applies to get modes, I(mode=get), I(mode=getstr), I(mode=geturl).
+      - Only applies to get modes, O(mode=get), O(mode=getstr), O(mode=geturl).
     default: true
     type: bool
     version_added: 5.0.0
   permission:
     description:
       - This option lets the user set the canned permissions on the object/bucket that are created.
-        The permissions that can be set are C(private), C(public-read), C(public-read-write),
-        C(authenticated-read) for a bucket or C(private), C(public-read), C(public-read-write),
-        C(aws-exec-read), C(authenticated-read), C(bucket-owner-read), C(bucket-owner-full-control)
+        The permissions that can be set are V(private), V(public-read), V(public-read-write),
+        V(authenticated-read) for a bucket or V(private), V(public-read), V(public-read-write),
+        V(aws-exec-read), V(authenticated-read), V(bucket-owner-read), V(bucket-owner-full-control)
         for an object. Multiple permissions can be specified as a list; although only the first one
         will be used during the initial upload of the file.
       - For a full list of permissions see the AWS documentation
@@ -138,16 +149,16 @@ options:
   overwrite:
     description:
       - Force overwrite either locally on the filesystem or remotely with the object/key.
-      - Used when I(mode=put) or I(mode=get).
-      - Ignored when when I(mode) is neither C(put) nor C(get).
-      - Must be a Boolean, C(always), C(never), C(different) or C(latest).
-      - C(true) is the same as C(always).
-      - C(false) is equal to C(never).
+      - Used when O(mode=put) or O(mode=get).
+      - Ignored when when O(mode) is neither V(put) nor V(get).
+      - Must be a Boolean, V(always), V(never), V(different) or V(latest).
+      - V(true) is the same as V(always).
+      - V(false) is equal to V(never).
       - When this is set to C(different) the MD5 sum of the local file is compared with the 'ETag'
         of the object/key in S3.  The ETag may or may not be an MD5 digest of the object data. See
         the ETag response header here
         U(https://docs.aws.amazon.com/AmazonS3/latest/API/RESTCommonResponseHeaders.html).
-      - When I(mode=get) and I(overwrite=latest) the last modified timestamp of local file
+      - When O(mode=get) and O(overwrite=latest) the last modified timestamp of local file
         is compared with the 'LastModified' of the object/key in S3.
     default: 'different'
     aliases: ['force']
@@ -161,8 +172,8 @@ options:
   dualstack:
     description:
       - Enables Amazon S3 Dual-Stack Endpoints, allowing S3 communications using both IPv4 and IPv6.
-      - Support for passing I(dualstack) and I(endpoint_url) at the same time has been deprecated,
-        the dualstack endpoints are automatically configured using the configured I(region).
+      - Support for passing O(dualstack) and O(endpoint_url) at the same time has been deprecated,
+        the dualstack endpoints are automatically configured using the configured O(region).
         Support will be removed in a release after 2024-12-01.
     type: bool
     default: false
@@ -171,14 +182,14 @@ options:
       - Enable API compatibility with Ceph RGW.
       - It takes into account the S3 API subset working with Ceph in order to provide the same module
         behaviour where possible.
-      - Requires I(endpoint_url) if I(ceph=true).
+      - Requires O(endpoint_url) if O(ceph=true).
     aliases: ['rgw']
     default: false
     type: bool
   src:
     description:
       - The source file path when performing a C(put) operation.
-      - One of I(content), I(content_base64) or I(src) must be specified when I(mode=put)
+      - One of O(content), O(content_base64) or O(src) must be specified when O(mode=put)
         otherwise ignored.
     type: path
   content:
@@ -186,8 +197,8 @@ options:
       - The content to C(put) into an object.
       - The parameter value will be treated as a string and converted to UTF-8 before sending it to
         S3.
-      - To send binary data, use the I(content_base64) parameter instead.
-      - One of I(content), I(content_base64) or I(src) must be specified when I(mode=put)
+      - To send binary data, use the O(content_base64) parameter instead.
+      - One of O(content), O(content_base64) or O(src) must be specified when O(mode=put)
         otherwise ignored.
     version_added: "1.3.0"
     type: str
@@ -195,7 +206,7 @@ options:
     description:
       - The base64-encoded binary data to C(put) into an object.
       - Use this if you need to put raw binary data, and don't forget to encode in base64.
-      - One of I(content), I(content_base64) or I(src) must be specified when I(mode=put)
+      - One of O(content), O(content_base64) or O(src) must be specified when O(mode=put)
         otherwise ignored.
     version_added: "1.3.0"
     type: str
@@ -203,19 +214,19 @@ options:
     description:
       - Overrides initial bucket lookups in case bucket or IAM policies are restrictive.
       - This can be useful when a user may have the C(GetObject) permission but no other
-        permissions.  In which case using I(mode=get) will fail unless
-        I(ignore_nonexistent_bucket=true) is specified.
+        permissions. In which case using O(mode=get) will fail unless
+        O(ignore_nonexistent_bucket=true) is specified.
     type: bool
     default: false
   encryption_kms_key_id:
     description:
-      - KMS key id to use when encrypting objects using I(encrypting=aws:kms).
-      - Ignored if I(encryption) is not C(aws:kms).
+      - KMS key id to use when encrypting objects using O(encryption_mode=aws:kms).
+      - Ignored if O(encryption_mode) is not V(aws:kms).
     type: str
   copy_src:
     description:
     - The source details of the object to copy.
-    - Required if I(mode=copy).
+    - Required if O(mode=copy).
     type: dict
     version_added: 2.0.0
     suboptions:
@@ -228,7 +239,7 @@ options:
         type: str
         description:
         - key name of the source object.
-        - if not specified, all the objects of the I(copy_src.bucket) will be copied into the specified bucket.
+        - if not specified, all the objects of the O(copy_src.bucket) will be copied into the specified bucket.
         required: false
       version_id:
         type: str
@@ -237,7 +248,7 @@ options:
       prefix:
         description:
         - Copy all the keys that begin with the specified prefix.
-        - Ignored if I(copy_src.object) is supplied.
+        - Ignored if O(copy_src.object) is supplied.
         default: ""
         type: str
         version_added: 6.2.0
@@ -250,18 +261,20 @@ options:
     type: bool
     version_added: 3.1.0
     default: True
+  expected_bucket_owner:
+    description:
+      - The account ID of the expected bucket owner.
+      - If the account ID that you provide does not match the actual owner of the bucket,
+        the request fails with the HTTP status code 403 Forbidden (access denied).
+    type: str
+    version_added: 8.2.0
 author:
   - "Lester Wade (@lwade)"
   - "Sloane Hertel (@s-hertel)"
   - "Alina Buzachis (@alinabuzachis)"
 notes:
-  - Support for I(tags) and I(purge_tags) was added in release 2.0.0.
-  - In release 5.0.0 the I(s3_url) parameter was merged into the I(endpoint_url) parameter,
-    I(s3_url) remains as an alias for I(endpoint_url).
-  - For Walrus I(endpoint_url) should be set to the FQDN of the endpoint with neither scheme nor path.
-  - Support for the C(S3_URL) environment variable has been
-    deprecated and will be removed in a release after 2024-12-01, please use the I(endpoint_url) parameter
-    or the C(AWS_URL) environment variable.
+  - Support for O(tags) and O(purge_tags) was added in release 2.0.0.
+  - For Walrus O(endpoint_url) should be set to the FQDN of the endpoint with neither scheme nor path.
   - Support for creating and deleting buckets was removed in release 6.0.0.
 extends_documentation_fragment:
   - amazon.aws.common.modules
@@ -285,6 +298,16 @@ EXAMPLES = r"""
     content: "{{ lookup('template', 'templates/object.yaml.j2') }}"
     mode: put
 
+- name: PUT content with explicit ContentType and ContentDisposition
+  amazon.aws.s3_object:
+    bucket: mybucket
+    object: /index.html
+    content: "<html>Hello</html>\n"
+    mode: put
+    headers:
+      ContentType: "text/html; charset=utf-8"
+      ContentDisposition: inline
+
 - name: Simple PUT operation in Ceph RGW S3
   amazon.aws.s3_object:
     bucket: mybucket
@@ -325,7 +348,8 @@ EXAMPLES = r"""
     object: /my/desired/key.txt
     src: /usr/local/myfile.txt
     mode: put
-    headers: 'x-amz-grant-full-control=emailAddress=owner@example.com'
+    headers:
+      GrantFullControl: "emailAddress=owner@example.com"
 
 - name: List keys simple
   amazon.aws.s3_object:
@@ -377,12 +401,12 @@ msg:
   description: Message indicating the status of the operation.
   returned: always
   type: str
-  sample: PUT operation complete
+  sample: "PUT operation complete"
 url:
   description: URL of the object.
   returned: (for put and geturl operations)
   type: str
-  sample: https://my-bucket.s3.amazonaws.com/my-key.txt?AWSAccessKeyId=<access-key>&Expires=1506888865&Signature=<signature>
+  sample: "https://my-bucket.s3.amazonaws.com/my-key.txt?AWSAccessKeyId=<access-key>&Expires=1506888865&Signature=<signature>"
 expiry:
   description: Number of seconds the presigned url is valid for.
   returned: (for geturl operation)
@@ -402,11 +426,18 @@ s3_keys:
   - prefix1/
   - prefix1/key1
   - prefix1/key2
+tags:
+    description: Tags of the s3 object.
+    returned: always
+    type: dict
+    sample: {
+                "Owner": "dev001",
+                "env": "test"
+            }
 """
 
 import base64
 import copy
-import io
 import mimetypes
 import os
 import time
@@ -429,6 +460,7 @@ from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
 from ansible_collections.amazon.aws.plugins.module_utils.s3 import HAS_MD5
 from ansible_collections.amazon.aws.plugins.module_utils.s3 import calculate_etag
 from ansible_collections.amazon.aws.plugins.module_utils.s3 import calculate_etag_content
+from ansible_collections.amazon.aws.plugins.module_utils.s3 import list_bucket_object_keys
 from ansible_collections.amazon.aws.plugins.module_utils.s3 import s3_extra_params
 from ansible_collections.amazon.aws.plugins.module_utils.s3 import validate_bucket_name
 from ansible_collections.amazon.aws.plugins.module_utils.tagging import ansible_dict_to_boto3_tag_list
@@ -484,13 +516,13 @@ def etag_compare(module, s3, bucket, obj, version=None, local_file=None, content
 def _head_object(s3, bucket, obj, version=None):
     try:
         if version:
-            key_check = s3.head_object(aws_retry=True, Bucket=bucket, Key=obj, VersionId=version)
+            obj_head = s3.head_object(aws_retry=True, Bucket=bucket, Key=obj, VersionId=version)
         else:
-            key_check = s3.head_object(aws_retry=True, Bucket=bucket, Key=obj)
-        if not key_check:
+            obj_head = s3.head_object(aws_retry=True, Bucket=bucket, Key=obj)
+        if not obj_head:
             return {}
-        key_check.pop("ResponseMetadata")
-        return key_check
+        obj_head.pop("ResponseMetadata")
+        return obj_head
     except is_boto3_error_code("404"):
         return {}
 
@@ -564,41 +596,9 @@ def bucket_check(module, s3, bucket, validate=True):
         )
 
 
-@AWSRetry.jittered_backoff()
-def paginated_list(s3, **pagination_params):
-    pg = s3.get_paginator("list_objects_v2")
-    for page in pg.paginate(**pagination_params):
-        for data in page.get("Contents", []):
-            yield data["Key"]
-
-
-def paginated_versioned_list_with_fallback(s3, **pagination_params):
-    try:
-        versioned_pg = s3.get_paginator("list_object_versions")
-        for page in versioned_pg.paginate(**pagination_params):
-            delete_markers = [
-                {"Key": data["Key"], "VersionId": data["VersionId"]} for data in page.get("DeleteMarkers", [])
-            ]
-            current_objects = [
-                {"Key": data["Key"], "VersionId": data["VersionId"]} for data in page.get("Versions", [])
-            ]
-            yield delete_markers + current_objects
-    except is_boto3_error_code(IGNORE_S3_DROP_IN_EXCEPTIONS + ["AccessDenied"]):
-        for key in paginated_list(s3, **pagination_params):
-            yield [{"Key": key}]
-
-
 def list_keys(s3, bucket, prefix=None, marker=None, max_keys=None):
-    pagination_params = {
-        "Bucket": bucket,
-        "Prefix": prefix,
-        "StartAfter": marker,
-        "MaxKeys": max_keys,
-    }
-    pagination_params = {k: v for k, v in pagination_params.items() if v}
-
     try:
-        return list(paginated_list(s3, **pagination_params))
+        return list_bucket_object_keys(s3, bucket, prefix=prefix, start_after=marker, max_keys=max_keys)
     except (
         botocore.exceptions.ClientError,
         botocore.exceptions.BotoCoreError,
@@ -645,7 +645,7 @@ def put_object_acl(module, s3, bucket, obj, params=None):
         raise S3ObjectFailure(f"Failed while creating object {obj}.", e)
 
 
-def create_dirkey(module, s3, bucket, obj, encrypt, expiry):
+def create_dirkey(module, s3, bucket, obj, encrypt, expiry, metadata):
     if module.check_mode:
         module.exit_json(msg="PUT operation skipped - running in check mode", changed=True)
     params = {"Bucket": bucket, "Key": obj, "Body": b""}
@@ -654,6 +654,7 @@ def create_dirkey(module, s3, bucket, obj, encrypt, expiry):
             encrypt,
             module.params.get("encryption_mode"),
             module.params.get("encryption_kms_key_id"),
+            metadata,
         )
     )
     put_object_acl(module, s3, bucket, obj, params)
@@ -672,10 +673,7 @@ def create_dirkey(module, s3, bucket, obj, encrypt, expiry):
 
 
 def path_check(path):
-    if os.path.exists(path):
-        return True
-    else:
-        return False
+    return bool(os.path.exists(path))
 
 
 def guess_content_type(src):
@@ -763,6 +761,19 @@ def upload_s3file(
             module.params.get("encryption_kms_key_id"),
             metadata,
         )
+        # Promote supported headers to boto3 ExtraArgs and place unknown ones under Metadata
+        if headers:
+            if not isinstance(headers, dict):
+                module.warn("'headers' must be a dict; ignoring non-dict value")
+            else:
+                for option, value in headers.items():
+                    extra_arg_key = option_in_extra_args(option)
+                    if extra_arg_key:
+                        extra[extra_arg_key] = value
+                    else:
+                        # Fall back to Metadata for non-ExtraArgs headers
+                        extra.setdefault("Metadata", {})
+                        extra["Metadata"][option] = value
         if module.params.get("permission"):
             permissions = module.params["permission"]
             if isinstance(permissions, str):
@@ -776,8 +787,11 @@ def upload_s3file(
         if src:
             s3.upload_file(aws_retry=True, Filename=src, Bucket=bucket, Key=obj, ExtraArgs=extra)
         else:
-            f = io.BytesIO(content)
-            s3.upload_fileobj(aws_retry=True, Fileobj=f, Bucket=bucket, Key=obj, ExtraArgs=extra)
+            # For in-memory content uploads, use put_object so promoted headers
+            # (e.g. ContentType, ContentDisposition, CacheControl) are applied consistently
+            params = {"Bucket": bucket, "Key": obj, "Body": content}
+            params.update(extra)
+            s3.put_object(aws_retry=True, **params)
     except (
         botocore.exceptions.ClientError,
         botocore.exceptions.BotoCoreError,
@@ -799,9 +813,6 @@ def upload_s3file(
 def download_s3file(module, s3, bucket, obj, dest, retries, version=None):
     if module.check_mode:
         module.exit_json(msg="GET operation skipped - running in check mode", changed=True)
-    # retries is the number of loops; range/xrange needs to be one
-    # more to get that count of loops.
-    _get_object_content(module, s3, bucket, obj, version)
 
     optional_kwargs = {"ExtraArgs": {"VersionId": version}} if version else {}
     for x in range(0, retries + 1):
@@ -873,13 +884,15 @@ def put_download_url(s3, bucket, obj, expiry):
 
 
 def get_current_object_tags_dict(module, s3, bucket, obj, version=None):
+    params = {"Bucket": bucket, "Key": obj}
+
+    if module.params.get("expected_bucket_owner"):
+        params["ExpectedBucketOwner"] = module.params["expected_bucket_owner"]
+    if version:
+        params["VersionId"] = version
+
     try:
-        if version:
-            current_tags = s3.get_object_tagging(aws_retry=True, Bucket=bucket, Key=obj, VersionId=version).get(
-                "TagSet"
-            )
-        else:
-            current_tags = s3.get_object_tagging(aws_retry=True, Bucket=bucket, Key=obj).get("TagSet")
+        current_tags = s3.get_object_tagging(aws_retry=True, **params).get("TagSet")
     except is_boto3_error_code(IGNORE_S3_DROP_IN_EXCEPTIONS):
         module.warn("GetObjectTagging is not implemented by your storage provider.")
         return {}
@@ -978,13 +991,13 @@ def ensure_tags(client, module, bucket, obj):
     return current_tags_dict, changed
 
 
-def get_binary_content(vars):
+def get_binary_content(s3_vars):
     # the content will be uploaded as a byte string, so we must encode it first
     bincontent = None
-    if vars.get("content"):
-        bincontent = vars["content"].encode("utf-8")
-    if vars.get("content_base64"):
-        bincontent = base64.standard_b64decode(vars["content_base64"])
+    if s3_vars.get("content"):
+        bincontent = s3_vars["content"].encode("utf-8")
+    if s3_vars.get("content_base64"):
+        bincontent = base64.standard_b64decode(s3_vars["content_base64"])
     return bincontent
 
 
@@ -1068,7 +1081,7 @@ def s3_object_do_put(module, connection, connection_v4, s3_vars):
         connection = connection_v4
 
     if s3_vars["src"] is not None and not path_check(s3_vars["src"]):
-        module.fail_json(msg=f"Local object \"{s3_vars['src']}\" does not exist for PUT operation")
+        module.fail_json(msg=f'Local object "{s3_vars["src"]}" does not exist for PUT operation')
 
     keyrtn = key_check(
         module,
@@ -1171,6 +1184,7 @@ def s3_object_do_create(module, connection, connection_v4, s3_vars):
         s3_vars["object"],
         s3_vars["encrypt"],
         s3_vars["expiry"],
+        s3_vars["metadata"],
     )
 
 
@@ -1265,7 +1279,6 @@ def calculate_object_etag(module, s3, bucket, obj, head_etag, version=None):
 
 def copy_object_to_bucket(module, s3, bucket, obj, encrypt, metadata, validate, src_bucket, src_obj, versionId=None):
     try:
-        params = {"Bucket": bucket, "Key": obj}
         if not key_check(module, s3, src_bucket, src_obj, version=versionId, validate=validate):
             # Key does not exist in source bucket
             module.exit_json(
@@ -1319,25 +1332,29 @@ def copy_object_to_bucket(module, s3, bucket, obj, encrypt, metadata, validate,
             }
             if versionId:
                 bucketsrc.update({"VersionId": versionId})
-            params.update({"CopySource": bucketsrc})
-            params.update(
-                get_extra_params(
-                    encrypt,
-                    module.params.get("encryption_mode"),
-                    module.params.get("encryption_kms_key_id"),
-                    metadata,
-                )
+
+            extra_args = get_extra_params(
+                encrypt,
+                module.params.get("encryption_mode"),
+                module.params.get("encryption_kms_key_id"),
+                metadata,
             )
+
             if metadata:
                 # 'MetadataDirective' Specifies whether the metadata is copied from the source object or replaced
                 # with metadata that's provided in the request. The default value is 'COPY', therefore when user
                 # specifies a metadata we should set it to 'REPLACE'
-                params.update({"MetadataDirective": "REPLACE"})
-            s3.copy_object(aws_retry=True, **params)
+                extra_args.update({"MetadataDirective": "REPLACE"})
+
+            # perform a "managed" copy rather simply using copy_object.  This will automatically use
+            # multi-part uploads where necessary (https://github.com/boto/boto3/issues/1715)
+            s3.copy(bucketsrc, bucket, obj, ExtraArgs=extra_args, aws_retry=True)
+
+            # We can't set the ACLs & tags during the copy, update them afterwards
             put_object_acl(module, s3, bucket, obj)
-            # Tags
             tags, tags_updated = ensure_tags(s3, module, bucket, obj)
-            msg = f"Object copied from bucket {bucketsrc['Bucket']} to bucket {bucket}."
+
+            msg = f"Object copied from bucket {src_bucket} to bucket {bucket}."
             return changed, {"msg": msg, "tags": tags}
     except (
         botocore.exceptions.BotoCoreError,
@@ -1489,8 +1506,8 @@ def main():
         encryption_mode=dict(choices=["AES256", "aws:kms"], default="AES256"),
         expiry=dict(default=600, type="int", aliases=["expiration"]),
         headers=dict(type="dict"),
-        marker=dict(default=""),
-        max_keys=dict(default=1000, type="int", no_log=False),
+        marker=dict(),
+        max_keys=dict(type="int", no_log=False),
         metadata=dict(type="dict"),
         mode=dict(choices=valid_modes, required=True),
         sig_v4=dict(default=True, type="bool"),
@@ -1519,6 +1536,7 @@ def main():
             ),
         ),
         validate_bucket_name=dict(type="bool", default=True),
+        expected_bucket_owner=dict(type="str"),
     )
 
     required_if = [
@@ -1539,6 +1557,16 @@ def main():
         mutually_exclusive=[["content", "content_base64", "src"]],
     )
 
+    if module.params.get("mode") == "list":
+        module.deprecate(
+            (
+                "Support for 'list' mode has been deprecated and will be removed in a release after "
+                "2024-11-01.  Please use the amazon.aws.s3_object_info module instead."
+            ),
+            date="2026-11-01",
+            collection_name="amazon.aws",
+        )
+
     endpoint_url = module.params.get("endpoint_url")
     dualstack = module.params.get("dualstack")
 
