@@ -10,8 +10,7 @@ __metaclass__ = type
 from ansible.plugins.action import ActionBase
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
-        AnsibleArgSpecValidator,
-    )
+        AnsibleArgSpecValidator, )
 except ImportError:
     ANSIBLE_UTILS_IS_INSTALLED = False
 else:
@@ -20,7 +19,7 @@ from ansible.errors import AnsibleActionFail
 from ansible_collections.cisco.meraki.plugins.plugin_utils.meraki import (
     MERAKI,
     meraki_argument_spec,
-    meraki_compare_equality2,
+    meraki_compare_equality,
     get_dict_result,
 )
 from ansible_collections.cisco.meraki.plugins.plugin_utils.exceptions import (
@@ -43,12 +42,14 @@ argument_spec.update(dict(
     isolationEnabled=dict(type="bool"),
     rstpEnabled=dict(type="bool"),
     stpGuard=dict(type="str"),
+    stpPortFastTrunk=dict(type="bool"),
     linkNegotiation=dict(type="str"),
     portScheduleId=dict(type="str"),
     udld=dict(type="str"),
     accessPolicyType=dict(type="str"),
     accessPolicyNumber=dict(type="int"),
     macAllowList=dict(type="list"),
+    macWhitelistLimit=dict(type="int"),
     stickyMacAllowList=dict(type="list"),
     stickyMacAllowListLimit=dict(type="int"),
     stormControlEnabled=dict(type="bool"),
@@ -57,6 +58,8 @@ argument_spec.update(dict(
     flexibleStackingEnabled=dict(type="bool"),
     daiTrusted=dict(type="bool"),
     profile=dict(type="dict"),
+    dot3az=dict(type="dict"),
+    highSpeed=dict(type="dict"),
     serial=dict(type="str"),
     portId=dict(type="str"),
 ))
@@ -84,12 +87,14 @@ class DevicesSwitchPorts(object):
             isolationEnabled=params.get("isolationEnabled"),
             rstpEnabled=params.get("rstpEnabled"),
             stpGuard=params.get("stpGuard"),
+            stpPortFastTrunk=params.get("stpPortFastTrunk"),
             linkNegotiation=params.get("linkNegotiation"),
             portScheduleId=params.get("portScheduleId"),
             udld=params.get("udld"),
             accessPolicyType=params.get("accessPolicyType"),
             accessPolicyNumber=params.get("accessPolicyNumber"),
             macAllowList=params.get("macAllowList"),
+            macWhitelistLimit=params.get("macWhitelistLimit"),
             stickyMacAllowList=params.get("stickyMacAllowList"),
             stickyMacAllowListLimit=params.get("stickyMacAllowListLimit"),
             stormControlEnabled=params.get("stormControlEnabled"),
@@ -98,110 +103,157 @@ class DevicesSwitchPorts(object):
             flexibleStackingEnabled=params.get("flexibleStackingEnabled"),
             daiTrusted=params.get("daiTrusted"),
             profile=params.get("profile"),
+            dot3az=params.get("dot3az"),
+            highSpeed=params.get("highSpeed"),
             serial=params.get("serial"),
             port_id=params.get("portId"),
         )
 
     def get_all_params(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('serial') is not None or self.new_object.get('serial') is not None:
+        if self.new_object.get('serial') is not None or self.new_object.get(
+                'serial') is not None:
             new_object_params['serial'] = self.new_object.get('serial')
         return new_object_params
 
     def get_params_by_id(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('serial') is not None or self.new_object.get('serial') is not None:
+        if self.new_object.get('serial') is not None or self.new_object.get(
+                'serial') is not None:
             new_object_params['serial'] = self.new_object.get('serial')
-        if self.new_object.get('portId') is not None or self.new_object.get('port_id') is not None:
+        if self.new_object.get('portId') is not None or self.new_object.get(
+                'port_id') is not None:
             new_object_params['portId'] = self.new_object.get('portId') or \
                 self.new_object.get('port_id')
         return new_object_params
 
     def update_by_id_params(self):
         new_object_params = {}
-        if self.new_object.get('name') is not None or self.new_object.get('name') is not None:
+        if self.new_object.get('name') is not None or self.new_object.get(
+                'name') is not None:
             new_object_params['name'] = self.new_object.get('name') or \
                 self.new_object.get('name')
-        if self.new_object.get('tags') is not None or self.new_object.get('tags') is not None:
+        if self.new_object.get('tags') is not None or self.new_object.get(
+                'tags') is not None:
             new_object_params['tags'] = self.new_object.get('tags') or \
                 self.new_object.get('tags')
-        if self.new_object.get('enabled') is not None or self.new_object.get('enabled') is not None:
+        if self.new_object.get('enabled') is not None or self.new_object.get(
+                'enabled') is not None:
             new_object_params['enabled'] = self.new_object.get('enabled')
-        if self.new_object.get('poeEnabled') is not None or self.new_object.get('poe_enabled') is not None:
+        if self.new_object.get('poeEnabled') is not None or self.new_object.get(
+                'poe_enabled') is not None:
             new_object_params['poeEnabled'] = self.new_object.get('poeEnabled')
-        if self.new_object.get('type') is not None or self.new_object.get('type') is not None:
+        if self.new_object.get('type') is not None or self.new_object.get(
+                'type') is not None:
             new_object_params['type'] = self.new_object.get('type') or \
                 self.new_object.get('type')
-        if self.new_object.get('vlan') is not None or self.new_object.get('vlan') is not None:
+        if self.new_object.get('vlan') is not None or self.new_object.get(
+                'vlan') is not None:
             new_object_params['vlan'] = self.new_object.get('vlan') or \
                 self.new_object.get('vlan')
-        if self.new_object.get('voiceVlan') is not None or self.new_object.get('voice_vlan') is not None:
-            new_object_params['voiceVlan'] = self.new_object.get('voiceVlan') or \
-                self.new_object.get('voice_vlan')
-        if self.new_object.get('allowedVlans') is not None or self.new_object.get('allowed_vlans') is not None:
-            new_object_params['allowedVlans'] = self.new_object.get('allowedVlans') or \
-                self.new_object.get('allowed_vlans')
-        if self.new_object.get('isolationEnabled') is not None or self.new_object.get('isolation_enabled') is not None:
+        if self.new_object.get('voiceVlan') is not None or self.new_object.get(
+                'voice_vlan') is not None:
+            new_object_params['voiceVlan'] = self.new_object.get(
+                'voiceVlan') or self.new_object.get('voice_vlan')
+        if self.new_object.get('allowedVlans') is not None or self.new_object.get(
+                'allowed_vlans') is not None:
+            new_object_params['allowedVlans'] = self.new_object.get(
+                'allowedVlans') or self.new_object.get('allowed_vlans')
+        if self.new_object.get('isolationEnabled') is not None or self.new_object.get(
+                'isolation_enabled') is not None:
             new_object_params['isolationEnabled'] = self.new_object.get(
                 'isolationEnabled')
-        if self.new_object.get('rstpEnabled') is not None or self.new_object.get('rstp_enabled') is not None:
+        if self.new_object.get('rstpEnabled') is not None or self.new_object.get(
+                'rstp_enabled') is not None:
             new_object_params['rstpEnabled'] = self.new_object.get(
                 'rstpEnabled')
-        if self.new_object.get('stpGuard') is not None or self.new_object.get('stp_guard') is not None:
-            new_object_params['stpGuard'] = self.new_object.get('stpGuard') or \
-                self.new_object.get('stp_guard')
-        if self.new_object.get('linkNegotiation') is not None or self.new_object.get('link_negotiation') is not None:
-            new_object_params['linkNegotiation'] = self.new_object.get('linkNegotiation') or \
-                self.new_object.get('link_negotiation')
-        if self.new_object.get('portScheduleId') is not None or self.new_object.get('port_schedule_id') is not None:
-            new_object_params['portScheduleId'] = self.new_object.get('portScheduleId') or \
-                self.new_object.get('port_schedule_id')
-        if self.new_object.get('udld') is not None or self.new_object.get('udld') is not None:
+        if self.new_object.get('stpGuard') is not None or self.new_object.get(
+                'stp_guard') is not None:
+            new_object_params['stpGuard'] = self.new_object.get(
+                'stpGuard') or self.new_object.get('stp_guard')
+        if self.new_object.get('stpPortFastTrunk') is not None or self.new_object.get(
+                'stp_port_fast_trunk') is not None:
+            new_object_params['stpPortFastTrunk'] = self.new_object.get(
+                'stpPortFastTrunk')
+        if self.new_object.get('linkNegotiation') is not None or self.new_object.get(
+                'link_negotiation') is not None:
+            new_object_params['linkNegotiation'] = self.new_object.get(
+                'linkNegotiation') or self.new_object.get('link_negotiation')
+        if self.new_object.get('portScheduleId') is not None or self.new_object.get(
+                'port_schedule_id') is not None:
+            new_object_params['portScheduleId'] = self.new_object.get(
+                'portScheduleId') or self.new_object.get('port_schedule_id')
+        if self.new_object.get('udld') is not None or self.new_object.get(
+                'udld') is not None:
             new_object_params['udld'] = self.new_object.get('udld') or \
                 self.new_object.get('udld')
-        if self.new_object.get('accessPolicyType') is not None or self.new_object.get('access_policy_type') is not None:
-            new_object_params['accessPolicyType'] = self.new_object.get('accessPolicyType') or \
-                self.new_object.get('access_policy_type')
-        if self.new_object.get('accessPolicyNumber') is not None or self.new_object.get('access_policy_number') is not None:
-            new_object_params['accessPolicyNumber'] = self.new_object.get('accessPolicyNumber') or \
-                self.new_object.get('access_policy_number')
-        if self.new_object.get('macAllowList') is not None or self.new_object.get('mac_allow_list') is not None:
-            new_object_params['macAllowList'] = self.new_object.get('macAllowList') or \
-                self.new_object.get('mac_allow_list')
-        if self.new_object.get('stickyMacAllowList') is not None or self.new_object.get('sticky_mac_allow_list') is not None:
-            new_object_params['stickyMacAllowList'] = self.new_object.get('stickyMacAllowList') or \
-                self.new_object.get('sticky_mac_allow_list')
-        if self.new_object.get('stickyMacAllowListLimit') is not None or self.new_object.get('sticky_mac_allow_list_limit') is not None:
-            new_object_params['stickyMacAllowListLimit'] = self.new_object.get('stickyMacAllowListLimit') or \
-                self.new_object.get('sticky_mac_allow_list_limit')
-        if self.new_object.get('stormControlEnabled') is not None or self.new_object.get('storm_control_enabled') is not None:
+        if self.new_object.get('accessPolicyType') is not None or self.new_object.get(
+                'access_policy_type') is not None:
+            new_object_params['accessPolicyType'] = self.new_object.get(
+                'accessPolicyType') or self.new_object.get('access_policy_type')
+        if self.new_object.get('accessPolicyNumber') is not None or self.new_object.get(
+                'access_policy_number') is not None:
+            new_object_params['accessPolicyNumber'] = self.new_object.get(
+                'accessPolicyNumber') or self.new_object.get('access_policy_number')
+        if self.new_object.get('macAllowList') is not None or self.new_object.get(
+                'mac_allow_list') is not None:
+            new_object_params['macAllowList'] = self.new_object.get(
+                'macAllowList') or self.new_object.get('mac_allow_list')
+        if self.new_object.get('macWhitelistLimit') is not None or self.new_object.get(
+                'mac_whitelist_limit') is not None:
+            new_object_params['macWhitelistLimit'] = self.new_object.get(
+                'macWhitelistLimit') or self.new_object.get('mac_whitelist_limit')
+        if self.new_object.get('stickyMacAllowList') is not None or self.new_object.get(
+                'sticky_mac_allow_list') is not None:
+            new_object_params['stickyMacAllowList'] = self.new_object.get(
+                'stickyMacAllowList') or self.new_object.get('sticky_mac_allow_list')
+        if self.new_object.get('stickyMacAllowListLimit') is not None or self.new_object.get(
+                'sticky_mac_allow_list_limit') is not None:
+            new_object_params['stickyMacAllowListLimit'] = self.new_object.get(
+                'stickyMacAllowListLimit') or self.new_object.get('sticky_mac_allow_list_limit')
+        if self.new_object.get('stormControlEnabled') is not None or self.new_object.get(
+                'storm_control_enabled') is not None:
             new_object_params['stormControlEnabled'] = self.new_object.get(
                 'stormControlEnabled')
-        if self.new_object.get('adaptivePolicyGroupId') is not None or self.new_object.get('adaptive_policy_group_id') is not None:
-            new_object_params['adaptivePolicyGroupId'] = self.new_object.get('adaptivePolicyGroupId') or \
-                self.new_object.get('adaptive_policy_group_id')
-        if self.new_object.get('peerSgtCapable') is not None or self.new_object.get('peer_sgt_capable') is not None:
+        if self.new_object.get('adaptivePolicyGroupId') is not None or self.new_object.get(
+                'adaptive_policy_group_id') is not None:
+            new_object_params['adaptivePolicyGroupId'] = self.new_object.get(
+                'adaptivePolicyGroupId') or self.new_object.get('adaptive_policy_group_id')
+        if self.new_object.get('peerSgtCapable') is not None or self.new_object.get(
+                'peer_sgt_capable') is not None:
             new_object_params['peerSgtCapable'] = self.new_object.get(
                 'peerSgtCapable')
-        if self.new_object.get('flexibleStackingEnabled') is not None or self.new_object.get('flexible_stacking_enabled') is not None:
+        if self.new_object.get('flexibleStackingEnabled') is not None or self.new_object.get(
+                'flexible_stacking_enabled') is not None:
             new_object_params['flexibleStackingEnabled'] = self.new_object.get(
                 'flexibleStackingEnabled')
-        if self.new_object.get('daiTrusted') is not None or self.new_object.get('dai_trusted') is not None:
+        if self.new_object.get('daiTrusted') is not None or self.new_object.get(
+                'dai_trusted') is not None:
             new_object_params['daiTrusted'] = self.new_object.get('daiTrusted')
-        if self.new_object.get('profile') is not None or self.new_object.get('profile') is not None:
+        if self.new_object.get('profile') is not None or self.new_object.get(
+                'profile') is not None:
             new_object_params['profile'] = self.new_object.get('profile') or \
                 self.new_object.get('profile')
-        if self.new_object.get('serial') is not None or self.new_object.get('serial') is not None:
+        if self.new_object.get('dot3az') is not None or self.new_object.get(
+                'dot3az') is not None:
+            new_object_params['dot3az'] = self.new_object.get('dot3az') or \
+                self.new_object.get('dot3az')
+        if self.new_object.get('highSpeed') is not None or self.new_object.get(
+                'high_speed') is not None:
+            new_object_params['highSpeed'] = self.new_object.get(
+                'highSpeed') or self.new_object.get('high_speed')
+        if self.new_object.get('serial') is not None or self.new_object.get(
+                'serial') is not None:
             new_object_params['serial'] = self.new_object.get('serial') or \
                 self.new_object.get('serial')
-        if self.new_object.get('portId') is not None or self.new_object.get('port_id') is not None:
+        if self.new_object.get('portId') is not None or self.new_object.get(
+                'port_id') is not None:
             new_object_params['portId'] = self.new_object.get('portId') or \
                 self.new_object.get('port_id')
         return new_object_params
 
     def get_object_by_name(self, name):
         result = None
-        name = self.new_object.get('portId') or self.new_object.get('port_id')
         # NOTE: Does not have a get by name method, using get all
         try:
             items = self.meraki.exec_meraki(
@@ -280,12 +332,14 @@ class DevicesSwitchPorts(object):
             ("isolationEnabled", "isolationEnabled"),
             ("rstpEnabled", "rstpEnabled"),
             ("stpGuard", "stpGuard"),
+            ("stpPortFastTrunk", "stpPortFastTrunk"),
             ("linkNegotiation", "linkNegotiation"),
             ("portScheduleId", "portScheduleId"),
             ("udld", "udld"),
             ("accessPolicyType", "accessPolicyType"),
             ("accessPolicyNumber", "accessPolicyNumber"),
             ("macAllowList", "macAllowList"),
+            ("macWhitelistLimit", "macWhitelistLimit"),
             ("stickyMacAllowList", "stickyMacAllowList"),
             ("stickyMacAllowListLimit", "stickyMacAllowListLimit"),
             ("stormControlEnabled", "stormControlEnabled"),
@@ -294,14 +348,19 @@ class DevicesSwitchPorts(object):
             ("flexibleStackingEnabled", "flexibleStackingEnabled"),
             ("daiTrusted", "daiTrusted"),
             ("profile", "profile"),
+            ("dot3az", "dot3az"),
+            ("highSpeed", "highSpeed"),
             ("serial", "serial"),
             ("portId", "portId"),
         ]
         # Method 1. Params present in request (Ansible) obj are the same as the current (ISE) params
         # If any does not have eq params, it requires update
-        return any(not meraki_compare_equality2(current_obj.get(meraki_param),
-                                                requested_obj.get(ansible_param))
-                   for (meraki_param, ansible_param) in obj_params)
+        return any(
+            not meraki_compare_equality(
+                current_obj.get(meraki_param),
+                requested_obj.get(ansible_param)) for (
+                meraki_param,
+                ansible_param) in obj_params)
 
     def update(self):
         id = self.new_object.get("id")
