@@ -10,8 +10,7 @@ __metaclass__ = type
 from ansible.plugins.action import ActionBase
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
-        AnsibleArgSpecValidator,
-    )
+        AnsibleArgSpecValidator, )
 except ImportError:
     ANSIBLE_UTILS_IS_INSTALLED = False
 else:
@@ -32,14 +31,18 @@ argument_spec = meraki_argument_spec()
 # Add arguments specific for this module
 argument_spec.update(dict(
     state=dict(type="str", default="present", choices=["present", "absent"]),
-    defaultGateway=dict(type="str"),
-    interfaceIp=dict(type="str"),
-    ipv6=dict(type="dict"),
-    multicastRouting=dict(type="str"),
     name=dict(type="str"),
-    ospfSettings=dict(type="dict"),
+    mode=dict(type="str"),
     subnet=dict(type="str"),
+    switchPortId=dict(type="str"),
+    interfaceIp=dict(type="str"),
+    multicastRouting=dict(type="str"),
     vlanId=dict(type="int"),
+    defaultGateway=dict(type="str"),
+    ospfSettings=dict(type="dict"),
+    ipv6=dict(type="dict"),
+    vrf=dict(type="dict"),
+    loopback=dict(type="dict"),
     serial=dict(type="str"),
     interfaceId=dict(type="str"),
 ))
@@ -57,108 +60,168 @@ class DevicesSwitchRoutingInterfaces(object):
     def __init__(self, params, meraki):
         self.meraki = meraki
         self.new_object = dict(
-            defaultGateway=params.get("defaultGateway"),
-            interfaceIp=params.get("interfaceIp"),
-            ipv6=params.get("ipv6"),
-            multicastRouting=params.get("multicastRouting"),
             name=params.get("name"),
-            ospfSettings=params.get("ospfSettings"),
+            mode=params.get("mode"),
             subnet=params.get("subnet"),
+            switchPortId=params.get("switchPortId"),
+            interfaceIp=params.get("interfaceIp"),
+            multicastRouting=params.get("multicastRouting"),
             vlanId=params.get("vlanId"),
+            defaultGateway=params.get("defaultGateway"),
+            ospfSettings=params.get("ospfSettings"),
+            ipv6=params.get("ipv6"),
+            vrf=params.get("vrf"),
+            loopback=params.get("loopback"),
             serial=params.get("serial"),
             interfaceId=params.get("interfaceId"),
         )
 
     def get_all_params(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('protocol') is not None or self.new_object.get('protocol') is not None:
+        if self.new_object.get('mode') is not None or self.new_object.get(
+                'mode') is not None:
+            new_object_params['mode'] = self.new_object.get('mode')
+        if self.new_object.get('protocol') is not None or self.new_object.get(
+                'protocol') is not None:
             new_object_params['protocol'] = self.new_object.get('protocol')
-        if self.new_object.get('serial') is not None or self.new_object.get('serial') is not None:
+        if self.new_object.get('serial') is not None or self.new_object.get(
+                'serial') is not None:
             new_object_params['serial'] = self.new_object.get('serial')
         return new_object_params
 
     def get_params_by_id(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('serial') is not None or self.new_object.get('serial') is not None:
+        if self.new_object.get('serial') is not None or self.new_object.get(
+                'serial') is not None:
             new_object_params['serial'] = self.new_object.get('serial')
-        if self.new_object.get('interfaceId') is not None or self.new_object.get('interface_id') is not None:
-            new_object_params['interfaceId'] = self.new_object.get('interfaceId') or \
-                self.new_object.get('interface_id')
+        if self.new_object.get('interfaceId') is not None or self.new_object.get(
+                'interface_id') is not None:
+            new_object_params['interfaceId'] = self.new_object.get(
+                'interfaceId') or self.new_object.get('interface_id')
         return new_object_params
 
     def create_params(self):
         new_object_params = {}
-        if self.new_object.get('defaultGateway') is not None or self.new_object.get('default_gateway') is not None:
-            new_object_params['defaultGateway'] = self.new_object.get('defaultGateway') or \
-                self.new_object.get('default_gateway')
-        if self.new_object.get('interfaceIp') is not None or self.new_object.get('interface_ip') is not None:
-            new_object_params['interfaceIp'] = self.new_object.get('interfaceIp') or \
-                self.new_object.get('interface_ip')
-        if self.new_object.get('ipv6') is not None or self.new_object.get('ipv6') is not None:
-            new_object_params['ipv6'] = self.new_object.get('ipv6') or \
-                self.new_object.get('ipv6')
-        if self.new_object.get('multicastRouting') is not None or self.new_object.get('multicast_routing') is not None:
-            new_object_params['multicastRouting'] = self.new_object.get('multicastRouting') or \
-                self.new_object.get('multicast_routing')
-        if self.new_object.get('name') is not None or self.new_object.get('name') is not None:
+        if self.new_object.get('name') is not None or self.new_object.get(
+                'name') is not None:
             new_object_params['name'] = self.new_object.get('name') or \
                 self.new_object.get('name')
-        if self.new_object.get('ospfSettings') is not None or self.new_object.get('ospf_settings') is not None:
-            new_object_params['ospfSettings'] = self.new_object.get('ospfSettings') or \
-                self.new_object.get('ospf_settings')
-        if self.new_object.get('subnet') is not None or self.new_object.get('subnet') is not None:
+        if self.new_object.get('mode') is not None or self.new_object.get(
+                'mode') is not None:
+            new_object_params['mode'] = self.new_object.get('mode') or \
+                self.new_object.get('mode')
+        if self.new_object.get('subnet') is not None or self.new_object.get(
+                'subnet') is not None:
             new_object_params['subnet'] = self.new_object.get('subnet') or \
                 self.new_object.get('subnet')
-        if self.new_object.get('vlanId') is not None or self.new_object.get('vlan_id') is not None:
+        if self.new_object.get('switchPortId') is not None or self.new_object.get(
+                'switch_port_id') is not None:
+            new_object_params['switchPortId'] = self.new_object.get(
+                'switchPortId') or self.new_object.get('switch_port_id')
+        if self.new_object.get('interfaceIp') is not None or self.new_object.get(
+                'interface_ip') is not None:
+            new_object_params['interfaceIp'] = self.new_object.get(
+                'interfaceIp') or self.new_object.get('interface_ip')
+        if self.new_object.get('multicastRouting') is not None or self.new_object.get(
+                'multicast_routing') is not None:
+            new_object_params['multicastRouting'] = self.new_object.get(
+                'multicastRouting') or self.new_object.get('multicast_routing')
+        if self.new_object.get('vlanId') is not None or self.new_object.get(
+                'vlan_id') is not None:
             new_object_params['vlanId'] = self.new_object.get('vlanId') or \
                 self.new_object.get('vlan_id')
-        if self.new_object.get('serial') is not None or self.new_object.get('serial') is not None:
+        if self.new_object.get('defaultGateway') is not None or self.new_object.get(
+                'default_gateway') is not None:
+            new_object_params['defaultGateway'] = self.new_object.get(
+                'defaultGateway') or self.new_object.get('default_gateway')
+        if self.new_object.get('ospfSettings') is not None or self.new_object.get(
+                'ospf_settings') is not None:
+            new_object_params['ospfSettings'] = self.new_object.get(
+                'ospfSettings') or self.new_object.get('ospf_settings')
+        if self.new_object.get('ipv6') is not None or self.new_object.get(
+                'ipv6') is not None:
+            new_object_params['ipv6'] = self.new_object.get('ipv6') or \
+                self.new_object.get('ipv6')
+        if self.new_object.get(
+                'vrf') is not None or self.new_object.get('vrf') is not None:
+            new_object_params['vrf'] = self.new_object.get('vrf') or \
+                self.new_object.get('vrf')
+        if self.new_object.get('loopback') is not None or self.new_object.get(
+                'loopback') is not None:
+            new_object_params['loopback'] = self.new_object.get(
+                'loopback') or self.new_object.get('loopback')
+        if self.new_object.get('serial') is not None or self.new_object.get(
+                'serial') is not None:
             new_object_params['serial'] = self.new_object.get('serial') or \
                 self.new_object.get('serial')
         return new_object_params
 
     def delete_by_id_params(self):
         new_object_params = {}
-        if self.new_object.get('serial') is not None or self.new_object.get('serial') is not None:
+        if self.new_object.get('serial') is not None or self.new_object.get(
+                'serial') is not None:
             new_object_params['serial'] = self.new_object.get('serial') or \
                 self.new_object.get('serial')
-        if self.new_object.get('interfaceId') is not None or self.new_object.get('interface_id') is not None:
-            new_object_params['interfaceId'] = self.new_object.get('interfaceId') or \
-                self.new_object.get('interface_id')
+        if self.new_object.get('interfaceId') is not None or self.new_object.get(
+                'interface_id') is not None:
+            new_object_params['interfaceId'] = self.new_object.get(
+                'interfaceId') or self.new_object.get('interface_id')
         return new_object_params
 
     def update_by_id_params(self):
         new_object_params = {}
-        if self.new_object.get('defaultGateway') is not None or self.new_object.get('default_gateway') is not None:
-            new_object_params['defaultGateway'] = self.new_object.get('defaultGateway') or \
-                self.new_object.get('default_gateway')
-        if self.new_object.get('interfaceIp') is not None or self.new_object.get('interface_ip') is not None:
-            new_object_params['interfaceIp'] = self.new_object.get('interfaceIp') or \
-                self.new_object.get('interface_ip')
-        if self.new_object.get('ipv6') is not None or self.new_object.get('ipv6') is not None:
-            new_object_params['ipv6'] = self.new_object.get('ipv6') or \
-                self.new_object.get('ipv6')
-        if self.new_object.get('multicastRouting') is not None or self.new_object.get('multicast_routing') is not None:
-            new_object_params['multicastRouting'] = self.new_object.get('multicastRouting') or \
-                self.new_object.get('multicast_routing')
-        if self.new_object.get('name') is not None or self.new_object.get('name') is not None:
+        if self.new_object.get('name') is not None or self.new_object.get(
+                'name') is not None:
             new_object_params['name'] = self.new_object.get('name') or \
                 self.new_object.get('name')
-        if self.new_object.get('ospfSettings') is not None or self.new_object.get('ospf_settings') is not None:
-            new_object_params['ospfSettings'] = self.new_object.get('ospfSettings') or \
-                self.new_object.get('ospf_settings')
-        if self.new_object.get('subnet') is not None or self.new_object.get('subnet') is not None:
+        if self.new_object.get('subnet') is not None or self.new_object.get(
+                'subnet') is not None:
             new_object_params['subnet'] = self.new_object.get('subnet') or \
                 self.new_object.get('subnet')
-        if self.new_object.get('vlanId') is not None or self.new_object.get('vlan_id') is not None:
+        if self.new_object.get('switchPortId') is not None or self.new_object.get(
+                'switch_port_id') is not None:
+            new_object_params['switchPortId'] = self.new_object.get(
+                'switchPortId') or self.new_object.get('switch_port_id')
+        if self.new_object.get('interfaceIp') is not None or self.new_object.get(
+                'interface_ip') is not None:
+            new_object_params['interfaceIp'] = self.new_object.get(
+                'interfaceIp') or self.new_object.get('interface_ip')
+        if self.new_object.get('multicastRouting') is not None or self.new_object.get(
+                'multicast_routing') is not None:
+            new_object_params['multicastRouting'] = self.new_object.get(
+                'multicastRouting') or self.new_object.get('multicast_routing')
+        if self.new_object.get('vlanId') is not None or self.new_object.get(
+                'vlan_id') is not None:
             new_object_params['vlanId'] = self.new_object.get('vlanId') or \
                 self.new_object.get('vlan_id')
-        if self.new_object.get('serial') is not None or self.new_object.get('serial') is not None:
+        if self.new_object.get('defaultGateway') is not None or self.new_object.get(
+                'default_gateway') is not None:
+            new_object_params['defaultGateway'] = self.new_object.get(
+                'defaultGateway') or self.new_object.get('default_gateway')
+        if self.new_object.get('ospfSettings') is not None or self.new_object.get(
+                'ospf_settings') is not None:
+            new_object_params['ospfSettings'] = self.new_object.get(
+                'ospfSettings') or self.new_object.get('ospf_settings')
+        if self.new_object.get('ipv6') is not None or self.new_object.get(
+                'ipv6') is not None:
+            new_object_params['ipv6'] = self.new_object.get('ipv6') or \
+                self.new_object.get('ipv6')
+        if self.new_object.get(
+                'vrf') is not None or self.new_object.get('vrf') is not None:
+            new_object_params['vrf'] = self.new_object.get('vrf') or \
+                self.new_object.get('vrf')
+        if self.new_object.get('loopback') is not None or self.new_object.get(
+                'loopback') is not None:
+            new_object_params['loopback'] = self.new_object.get(
+                'loopback') or self.new_object.get('loopback')
+        if self.new_object.get('serial') is not None or self.new_object.get(
+                'serial') is not None:
             new_object_params['serial'] = self.new_object.get('serial') or \
                 self.new_object.get('serial')
-        if self.new_object.get('interfaceId') is not None or self.new_object.get('interface_id') is not None:
-            new_object_params['interfaceId'] = self.new_object.get('interfaceId') or \
-                self.new_object.get('interface_id')
+        if self.new_object.get('interfaceId') is not None or self.new_object.get(
+                'interface_id') is not None:
+            new_object_params['interfaceId'] = self.new_object.get(
+                'interfaceId') or self.new_object.get('interface_id')
         return new_object_params
 
     def get_object_by_name(self, name):
@@ -230,22 +293,29 @@ class DevicesSwitchRoutingInterfaces(object):
         requested_obj = self.new_object
 
         obj_params = [
-            ("defaultGateway", "defaultGateway"),
-            ("interfaceIp", "interfaceIp"),
-            ("ipv6", "ipv6"),
-            ("multicastRouting", "multicastRouting"),
             ("name", "name"),
-            ("ospfSettings", "ospfSettings"),
+            ("mode", "mode"),
             ("subnet", "subnet"),
+            ("switchPortId", "switchPortId"),
+            ("interfaceIp", "interfaceIp"),
+            ("multicastRouting", "multicastRouting"),
             ("vlanId", "vlanId"),
+            ("defaultGateway", "defaultGateway"),
+            ("ospfSettings", "ospfSettings"),
+            ("ipv6", "ipv6"),
+            ("vrf", "vrf"),
+            ("loopback", "loopback"),
             ("serial", "serial"),
             ("interfaceId", "interfaceId"),
         ]
         # Method 1. Params present in request (Ansible) obj are the same as the current (DNAC) params
         # If any does not have eq params, it requires update
-        return any(not meraki_compare_equality2(current_obj.get(meraki_param),
-                                                requested_obj.get(ansible_param))
-                   for (meraki_param, ansible_param) in obj_params)
+        return any(
+            not meraki_compare_equality2(
+                current_obj.get(meraki_param),
+                requested_obj.get(ansible_param)) for (
+                meraki_param,
+                ansible_param) in obj_params)
 
     def create(self):
         result = self.meraki.exec_meraki(
