@@ -2,15 +2,15 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2021, Cisco Systems
-# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSE or
+# https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 from ansible.plugins.action import ActionBase
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
-        AnsibleArgSpecValidator,
-    )
+        AnsibleArgSpecValidator, )
 except ImportError:
     ANSIBLE_UTILS_IS_INSTALLED = False
 else:
@@ -26,6 +26,7 @@ argument_spec = meraki_argument_spec()
 # Add arguments specific for this module
 argument_spec.update(dict(
     serial=dict(type="str"),
+    mode=dict(type="str"),
     protocol=dict(type="str"),
     interfaceId=dict(type="str"),
 ))
@@ -79,6 +80,9 @@ class ActionModule(ActionBase):
         if params.get("serial") is not None:
             new_object["serial"] = params.get(
                 "serial")
+        if params.get("mode") is not None:
+            new_object["mode"] = params.get(
+                "mode")
         if params.get("protocol") is not None:
             new_object["protocol"] = params.get(
                 "protocol")
