@@ -10,8 +10,7 @@ __metaclass__ = type
 from ansible.plugins.action import ActionBase
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
-        AnsibleArgSpecValidator,
-    )
+        AnsibleArgSpecValidator, )
 except ImportError:
     ANSIBLE_UTILS_IS_INSTALLED = False
 else:
@@ -32,9 +31,9 @@ argument_spec = meraki_argument_spec()
 # Add arguments specific for this module
 argument_spec.update(dict(
     state=dict(type="str", default="present", choices=["present", "absent"]),
-    description=dict(type="str"),
-    origin=dict(type="dict"),
     prefix=dict(type="str"),
+    origin=dict(type="dict"),
+    description=dict(type="str"),
     networkId=dict(type="str"),
     staticDelegatedPrefixId=dict(type="str"),
 ))
@@ -52,73 +51,87 @@ class NetworksAppliancePrefixesDelegatedStatics(object):
     def __init__(self, params, meraki):
         self.meraki = meraki
         self.new_object = dict(
-            description=params.get("description"),
-            origin=params.get("origin"),
             prefix=params.get("prefix"),
+            origin=params.get("origin"),
+            description=params.get("description"),
             networkId=params.get("networkId"),
             staticDelegatedPrefixId=params.get("staticDelegatedPrefixId"),
         )
 
     def get_all_params(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
         return new_object_params
 
     def get_params_by_id(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
-        if self.new_object.get('staticDelegatedPrefixId') is not None or self.new_object.get('static_delegated_prefix_id') is not None:
-            new_object_params['staticDelegatedPrefixId'] = self.new_object.get('staticDelegatedPrefixId') or \
-                self.new_object.get('static_delegated_prefix_id')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
+        if self.new_object.get('staticDelegatedPrefixId') is not None or self.new_object.get(
+                'static_delegated_prefix_id') is not None:
+            new_object_params['staticDelegatedPrefixId'] = self.new_object.get(
+                'staticDelegatedPrefixId') or self.new_object.get('static_delegated_prefix_id')
         return new_object_params
 
     def create_params(self):
         new_object_params = {}
-        if self.new_object.get('description') is not None or self.new_object.get('description') is not None:
-            new_object_params['description'] = self.new_object.get('description') or \
-                self.new_object.get('description')
-        if self.new_object.get('origin') is not None or self.new_object.get('origin') is not None:
-            new_object_params['origin'] = self.new_object.get('origin') or \
-                self.new_object.get('origin')
-        if self.new_object.get('prefix') is not None or self.new_object.get('prefix') is not None:
+        if self.new_object.get('prefix') is not None or self.new_object.get(
+                'prefix') is not None:
             new_object_params['prefix'] = self.new_object.get('prefix') or \
                 self.new_object.get('prefix')
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
+        if self.new_object.get('origin') is not None or self.new_object.get(
+                'origin') is not None:
+            new_object_params['origin'] = self.new_object.get('origin') or \
+                self.new_object.get('origin')
+        if self.new_object.get('description') is not None or self.new_object.get(
+                'description') is not None:
+            new_object_params['description'] = self.new_object.get(
+                'description') or self.new_object.get('description')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
         return new_object_params
 
     def delete_by_id_params(self):
         new_object_params = {}
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
-        if self.new_object.get('staticDelegatedPrefixId') is not None or self.new_object.get('static_delegated_prefix_id') is not None:
-            new_object_params['staticDelegatedPrefixId'] = self.new_object.get('staticDelegatedPrefixId') or \
-                self.new_object.get('static_delegated_prefix_id')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
+        if self.new_object.get('staticDelegatedPrefixId') is not None or self.new_object.get(
+                'static_delegated_prefix_id') is not None:
+            new_object_params['staticDelegatedPrefixId'] = self.new_object.get(
+                'staticDelegatedPrefixId') or self.new_object.get('static_delegated_prefix_id')
         return new_object_params
 
     def update_by_id_params(self):
         new_object_params = {}
-        if self.new_object.get('description') is not None or self.new_object.get('description') is not None:
-            new_object_params['description'] = self.new_object.get('description') or \
-                self.new_object.get('description')
-        if self.new_object.get('origin') is not None or self.new_object.get('origin') is not None:
-            new_object_params['origin'] = self.new_object.get('origin') or \
-                self.new_object.get('origin')
-        if self.new_object.get('prefix') is not None or self.new_object.get('prefix') is not None:
+        if self.new_object.get('prefix') is not None or self.new_object.get(
+                'prefix') is not None:
             new_object_params['prefix'] = self.new_object.get('prefix') or \
                 self.new_object.get('prefix')
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
-        if self.new_object.get('staticDelegatedPrefixId') is not None or self.new_object.get('static_delegated_prefix_id') is not None:
-            new_object_params['staticDelegatedPrefixId'] = self.new_object.get('staticDelegatedPrefixId') or \
-                self.new_object.get('static_delegated_prefix_id')
+        if self.new_object.get('origin') is not None or self.new_object.get(
+                'origin') is not None:
+            new_object_params['origin'] = self.new_object.get('origin') or \
+                self.new_object.get('origin')
+        if self.new_object.get('description') is not None or self.new_object.get(
+                'description') is not None:
+            new_object_params['description'] = self.new_object.get(
+                'description') or self.new_object.get('description')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
+        if self.new_object.get('staticDelegatedPrefixId') is not None or self.new_object.get(
+                'static_delegated_prefix_id') is not None:
+            new_object_params['staticDelegatedPrefixId'] = self.new_object.get(
+                'staticDelegatedPrefixId') or self.new_object.get('static_delegated_prefix_id')
         return new_object_params
 
     def get_object_by_name(self, name):
@@ -190,17 +203,20 @@ class NetworksAppliancePrefixesDelegatedStatics(object):
         requested_obj = self.new_object
 
         obj_params = [
-            ("description", "description"),
-            ("origin", "origin"),
             ("prefix", "prefix"),
+            ("origin", "origin"),
+            ("description", "description"),
             ("networkId", "networkId"),
             ("staticDelegatedPrefixId", "staticDelegatedPrefixId"),
         ]
         # Method 1. Params present in request (Ansible) obj are the same as the current (DNAC) params
         # If any does not have eq params, it requires update
-        return any(not meraki_compare_equality2(current_obj.get(meraki_param),
-                                                requested_obj.get(ansible_param))
-                   for (meraki_param, ansible_param) in obj_params)
+        return any(
+            not meraki_compare_equality2(
+                current_obj.get(meraki_param),
+                requested_obj.get(ansible_param)) for (
+                meraki_param,
+                ansible_param) in obj_params)
 
     def create(self):
         result = self.meraki.exec_meraki(
