@@ -10,8 +10,7 @@ __metaclass__ = type
 from ansible.plugins.action import ActionBase
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
-        AnsibleArgSpecValidator,
-    )
+        AnsibleArgSpecValidator, )
 except ImportError:
     ANSIBLE_UTILS_IS_INSTALLED = False
 else:
@@ -20,7 +19,7 @@ from ansible.errors import AnsibleActionFail
 from ansible_collections.cisco.meraki.plugins.plugin_utils.meraki import (
     MERAKI,
     meraki_argument_spec,
-    meraki_compare_equality,
+    meraki_compare_equality2,
     get_dict_result,
 )
 from ansible_collections.cisco.meraki.plugins.plugin_utils.exceptions import (
@@ -32,16 +31,17 @@ argument_spec = meraki_argument_spec()
 # Add arguments specific for this module
 argument_spec.update(dict(
     state=dict(type="str", default="present", choices=["present", "absent"]),
-    bandwidth=dict(type="dict"),
-    bonjourForwarding=dict(type="dict"),
-    contentFiltering=dict(type="dict"),
-    firewallAndTrafficShaping=dict(type="dict"),
     name=dict(type="str"),
     scheduling=dict(type="dict"),
+    bandwidth=dict(type="dict"),
+    firewallAndTrafficShaping=dict(type="dict"),
+    contentFiltering=dict(type="dict"),
     splashAuthSettings=dict(type="str"),
     vlanTagging=dict(type="dict"),
+    bonjourForwarding=dict(type="dict"),
     networkId=dict(type="str"),
     groupPolicyId=dict(type="str"),
+    force=dict(type="bool"),
 ))
 
 required_if = [
@@ -57,108 +57,136 @@ class NetworksGroupPolicies(object):
     def __init__(self, params, meraki):
         self.meraki = meraki
         self.new_object = dict(
-            bandwidth=params.get("bandwidth"),
-            bonjourForwarding=params.get("bonjourForwarding"),
-            contentFiltering=params.get("contentFiltering"),
-            firewallAndTrafficShaping=params.get("firewallAndTrafficShaping"),
             name=params.get("name"),
             scheduling=params.get("scheduling"),
+            bandwidth=params.get("bandwidth"),
+            firewallAndTrafficShaping=params.get("firewallAndTrafficShaping"),
+            contentFiltering=params.get("contentFiltering"),
             splashAuthSettings=params.get("splashAuthSettings"),
             vlanTagging=params.get("vlanTagging"),
+            bonjourForwarding=params.get("bonjourForwarding"),
             networkId=params.get("networkId"),
             groupPolicyId=params.get("groupPolicyId"),
+            force=params.get("force"),
         )
 
     def get_all_params(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
         return new_object_params
 
     def get_params_by_id(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
-        if self.new_object.get('groupPolicyId') is not None or self.new_object.get('group_policy_id') is not None:
-            new_object_params['groupPolicyId'] = self.new_object.get('groupPolicyId') or \
-                self.new_object.get('group_policy_id')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
+        if self.new_object.get('groupPolicyId') is not None or self.new_object.get(
+                'group_policy_id') is not None:
+            new_object_params['groupPolicyId'] = self.new_object.get(
+                'groupPolicyId') or self.new_object.get('group_policy_id')
         return new_object_params
 
     def create_params(self):
         new_object_params = {}
-        if self.new_object.get('bandwidth') is not None or self.new_object.get('bandwidth') is not None:
-            new_object_params['bandwidth'] = self.new_object.get('bandwidth') or \
-                self.new_object.get('bandwidth')
-        if self.new_object.get('bonjourForwarding') is not None or self.new_object.get('bonjour_forwarding') is not None:
-            new_object_params['bonjourForwarding'] = self.new_object.get('bonjourForwarding') or \
-                self.new_object.get('bonjour_forwarding')
-        if self.new_object.get('contentFiltering') is not None or self.new_object.get('content_filtering') is not None:
-            new_object_params['contentFiltering'] = self.new_object.get('contentFiltering') or \
-                self.new_object.get('content_filtering')
-        if self.new_object.get('firewallAndTrafficShaping') is not None or self.new_object.get('firewall_and_traffic_shaping') is not None:
-            new_object_params['firewallAndTrafficShaping'] = self.new_object.get('firewallAndTrafficShaping') or \
-                self.new_object.get('firewall_and_traffic_shaping')
-        if self.new_object.get('name') is not None or self.new_object.get('name') is not None:
+        if self.new_object.get('name') is not None or self.new_object.get(
+                'name') is not None:
             new_object_params['name'] = self.new_object.get('name') or \
                 self.new_object.get('name')
-        if self.new_object.get('scheduling') is not None or self.new_object.get('scheduling') is not None:
-            new_object_params['scheduling'] = self.new_object.get('scheduling') or \
-                self.new_object.get('scheduling')
-        if self.new_object.get('splashAuthSettings') is not None or self.new_object.get('splash_auth_settings') is not None:
-            new_object_params['splashAuthSettings'] = self.new_object.get('splashAuthSettings') or \
-                self.new_object.get('splash_auth_settings')
-        if self.new_object.get('vlanTagging') is not None or self.new_object.get('vlan_tagging') is not None:
-            new_object_params['vlanTagging'] = self.new_object.get('vlanTagging') or \
-                self.new_object.get('vlan_tagging')
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
+        if self.new_object.get('scheduling') is not None or self.new_object.get(
+                'scheduling') is not None:
+            new_object_params['scheduling'] = self.new_object.get(
+                'scheduling') or self.new_object.get('scheduling')
+        if self.new_object.get('bandwidth') is not None or self.new_object.get(
+                'bandwidth') is not None:
+            new_object_params['bandwidth'] = self.new_object.get(
+                'bandwidth') or self.new_object.get('bandwidth')
+        if self.new_object.get('firewallAndTrafficShaping') is not None or self.new_object.get(
+                'firewall_and_traffic_shaping') is not None:
+            new_object_params['firewallAndTrafficShaping'] = self.new_object.get(
+                'firewallAndTrafficShaping') or self.new_object.get('firewall_and_traffic_shaping')
+        if self.new_object.get('contentFiltering') is not None or self.new_object.get(
+                'content_filtering') is not None:
+            new_object_params['contentFiltering'] = self.new_object.get(
+                'contentFiltering') or self.new_object.get('content_filtering')
+        if self.new_object.get('splashAuthSettings') is not None or self.new_object.get(
+                'splash_auth_settings') is not None:
+            new_object_params['splashAuthSettings'] = self.new_object.get(
+                'splashAuthSettings') or self.new_object.get('splash_auth_settings')
+        if self.new_object.get('vlanTagging') is not None or self.new_object.get(
+                'vlan_tagging') is not None:
+            new_object_params['vlanTagging'] = self.new_object.get(
+                'vlanTagging') or self.new_object.get('vlan_tagging')
+        if self.new_object.get('bonjourForwarding') is not None or self.new_object.get(
+                'bonjour_forwarding') is not None:
+            new_object_params['bonjourForwarding'] = self.new_object.get(
+                'bonjourForwarding') or self.new_object.get('bonjour_forwarding')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
         return new_object_params
 
     def delete_by_id_params(self):
         new_object_params = {}
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
-        if self.new_object.get('groupPolicyId') is not None or self.new_object.get('group_policy_id') is not None:
-            new_object_params['groupPolicyId'] = self.new_object.get('groupPolicyId') or \
-                self.new_object.get('group_policy_id')
+        if self.new_object.get('force') is not None or self.new_object.get(
+                'force') is not None:
+            new_object_params['force'] = self.new_object.get('force')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
+        if self.new_object.get('groupPolicyId') is not None or self.new_object.get(
+                'group_policy_id') is not None:
+            new_object_params['groupPolicyId'] = self.new_object.get(
+                'groupPolicyId') or self.new_object.get('group_policy_id')
         return new_object_params
 
     def update_by_id_params(self):
         new_object_params = {}
-        if self.new_object.get('bandwidth') is not None or self.new_object.get('bandwidth') is not None:
-            new_object_params['bandwidth'] = self.new_object.get('bandwidth') or \
-                self.new_object.get('bandwidth')
-        if self.new_object.get('bonjourForwarding') is not None or self.new_object.get('bonjour_forwarding') is not None:
-            new_object_params['bonjourForwarding'] = self.new_object.get('bonjourForwarding') or \
-                self.new_object.get('bonjour_forwarding')
-        if self.new_object.get('contentFiltering') is not None or self.new_object.get('content_filtering') is not None:
-            new_object_params['contentFiltering'] = self.new_object.get('contentFiltering') or \
-                self.new_object.get('content_filtering')
-        if self.new_object.get('firewallAndTrafficShaping') is not None or self.new_object.get('firewall_and_traffic_shaping') is not None:
-            new_object_params['firewallAndTrafficShaping'] = self.new_object.get('firewallAndTrafficShaping') or \
-                self.new_object.get('firewall_and_traffic_shaping')
-        if self.new_object.get('name') is not None or self.new_object.get('name') is not None:
+        if self.new_object.get('name') is not None or self.new_object.get(
+                'name') is not None:
             new_object_params['name'] = self.new_object.get('name') or \
                 self.new_object.get('name')
-        if self.new_object.get('scheduling') is not None or self.new_object.get('scheduling') is not None:
-            new_object_params['scheduling'] = self.new_object.get('scheduling') or \
-                self.new_object.get('scheduling')
-        if self.new_object.get('splashAuthSettings') is not None or self.new_object.get('splash_auth_settings') is not None:
-            new_object_params['splashAuthSettings'] = self.new_object.get('splashAuthSettings') or \
-                self.new_object.get('splash_auth_settings')
-        if self.new_object.get('vlanTagging') is not None or self.new_object.get('vlan_tagging') is not None:
-            new_object_params['vlanTagging'] = self.new_object.get('vlanTagging') or \
-                self.new_object.get('vlan_tagging')
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
-        if self.new_object.get('groupPolicyId') is not None or self.new_object.get('group_policy_id') is not None:
-            new_object_params['groupPolicyId'] = self.new_object.get('groupPolicyId') or \
-                self.new_object.get('group_policy_id')
+        if self.new_object.get('scheduling') is not None or self.new_object.get(
+                'scheduling') is not None:
+            new_object_params['scheduling'] = self.new_object.get(
+                'scheduling') or self.new_object.get('scheduling')
+        if self.new_object.get('bandwidth') is not None or self.new_object.get(
+                'bandwidth') is not None:
+            new_object_params['bandwidth'] = self.new_object.get(
+                'bandwidth') or self.new_object.get('bandwidth')
+        if self.new_object.get('firewallAndTrafficShaping') is not None or self.new_object.get(
+                'firewall_and_traffic_shaping') is not None:
+            new_object_params['firewallAndTrafficShaping'] = self.new_object.get(
+                'firewallAndTrafficShaping') or self.new_object.get('firewall_and_traffic_shaping')
+        if self.new_object.get('contentFiltering') is not None or self.new_object.get(
+                'content_filtering') is not None:
+            new_object_params['contentFiltering'] = self.new_object.get(
+                'contentFiltering') or self.new_object.get('content_filtering')
+        if self.new_object.get('splashAuthSettings') is not None or self.new_object.get(
+                'splash_auth_settings') is not None:
+            new_object_params['splashAuthSettings'] = self.new_object.get(
+                'splashAuthSettings') or self.new_object.get('splash_auth_settings')
+        if self.new_object.get('vlanTagging') is not None or self.new_object.get(
+                'vlan_tagging') is not None:
+            new_object_params['vlanTagging'] = self.new_object.get(
+                'vlanTagging') or self.new_object.get('vlan_tagging')
+        if self.new_object.get('bonjourForwarding') is not None or self.new_object.get(
+                'bonjour_forwarding') is not None:
+            new_object_params['bonjourForwarding'] = self.new_object.get(
+                'bonjourForwarding') or self.new_object.get('bonjour_forwarding')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
+        if self.new_object.get('groupPolicyId') is not None or self.new_object.get(
+                'group_policy_id') is not None:
+            new_object_params['groupPolicyId'] = self.new_object.get(
+                'groupPolicyId') or self.new_object.get('group_policy_id')
         return new_object_params
 
     def get_object_by_name(self, name):
@@ -230,22 +258,26 @@ class NetworksGroupPolicies(object):
         requested_obj = self.new_object
 
         obj_params = [
-            ("bandwidth", "bandwidth"),
-            ("bonjourForwarding", "bonjourForwarding"),
-            ("contentFiltering", "contentFiltering"),
-            ("firewallAndTrafficShaping", "firewallAndTrafficShaping"),
             ("name", "name"),
             ("scheduling", "scheduling"),
+            ("bandwidth", "bandwidth"),
+            ("firewallAndTrafficShaping", "firewallAndTrafficShaping"),
+            ("contentFiltering", "contentFiltering"),
             ("splashAuthSettings", "splashAuthSettings"),
             ("vlanTagging", "vlanTagging"),
+            ("bonjourForwarding", "bonjourForwarding"),
             ("networkId", "networkId"),
             ("groupPolicyId", "groupPolicyId"),
+            ("force", "force"),
         ]
         # Method 1. Params present in request (Ansible) obj are the same as the current (DNAC) params
         # If any does not have eq params, it requires update
-        return any(not meraki_compare_equality(current_obj.get(meraki_param),
-                                               requested_obj.get(ansible_param))
-                   for (meraki_param, ansible_param) in obj_params)
+        return any(
+            not meraki_compare_equality2(
+                current_obj.get(meraki_param),
+                requested_obj.get(ansible_param)) for (
+                meraki_param,
+                ansible_param) in obj_params)
 
     def create(self):
         result = self.meraki.exec_meraki(
