@@ -10,8 +10,7 @@ __metaclass__ = type
 from ansible.plugins.action import ActionBase
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
-        AnsibleArgSpecValidator,
-    )
+        AnsibleArgSpecValidator, )
 except ImportError:
     ANSIBLE_UTILS_IS_INSTALLED = False
 else:
@@ -20,7 +19,7 @@ from ansible.errors import AnsibleActionFail
 from ansible_collections.cisco.meraki.plugins.plugin_utils.meraki import (
     MERAKI,
     meraki_argument_spec,
-    meraki_compare_equality,
+    meraki_compare_equality2,
     get_dict_result,
 )
 from ansible_collections.cisco.meraki.plugins.plugin_utils.exceptions import (
@@ -49,6 +48,8 @@ argument_spec.update(dict(
     voiceVlanClients=dict(type="bool"),
     urlRedirectWalledGardenEnabled=dict(type="bool"),
     urlRedirectWalledGardenRanges=dict(type="list"),
+    guestGroupPolicyId=dict(type="str"),
+    guestSgtId=dict(type="int"),
     networkId=dict(type="str"),
     accessPolicyNumber=dict(type="str"),
 ))
@@ -81,158 +82,216 @@ class NetworksSwitchAccessPolicies(object):
             guestVlanId=params.get("guestVlanId"),
             dot1x=params.get("dot1x"),
             voiceVlanClients=params.get("voiceVlanClients"),
-            urlRedirectWalledGardenEnabled=params.get(
-                "urlRedirectWalledGardenEnabled"),
-            urlRedirectWalledGardenRanges=params.get(
-                "urlRedirectWalledGardenRanges"),
+            urlRedirectWalledGardenEnabled=params.get("urlRedirectWalledGardenEnabled"),
+            urlRedirectWalledGardenRanges=params.get("urlRedirectWalledGardenRanges"),
+            guestGroupPolicyId=params.get("guestGroupPolicyId"),
+            guestSgtId=params.get("guestSgtId"),
             networkId=params.get("networkId"),
             accessPolicyNumber=params.get("accessPolicyNumber"),
         )
 
     def get_all_params(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
         return new_object_params
 
     def get_params_by_id(self, name=None, id=None):
         new_object_params = {}
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
-        if self.new_object.get('accessPolicyNumber') is not None or self.new_object.get('access_policy_number') is not None:
-            new_object_params['accessPolicyNumber'] = self.new_object.get('accessPolicyNumber') or \
-                self.new_object.get('access_policy_number')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
+        if self.new_object.get('accessPolicyNumber') is not None or self.new_object.get(
+                'access_policy_number') is not None:
+            new_object_params['accessPolicyNumber'] = self.new_object.get(
+                'accessPolicyNumber') or self.new_object.get('access_policy_number')
         return new_object_params
 
     def create_params(self):
         new_object_params = {}
-        if self.new_object.get('name') is not None or self.new_object.get('name') is not None:
+        if self.new_object.get('name') is not None or self.new_object.get(
+                'name') is not None:
             new_object_params['name'] = self.new_object.get('name') or \
                 self.new_object.get('name')
-        if self.new_object.get('radiusServers') is not None or self.new_object.get('radius_servers') is not None:
-            new_object_params['radiusServers'] = self.new_object.get('radiusServers') or \
-                self.new_object.get('radius_servers')
-        if self.new_object.get('radius') is not None or self.new_object.get('radius') is not None:
+        if self.new_object.get('radiusServers') is not None or self.new_object.get(
+                'radius_servers') is not None:
+            new_object_params['radiusServers'] = self.new_object.get(
+                'radiusServers') or self.new_object.get('radius_servers')
+        if self.new_object.get('radius') is not None or self.new_object.get(
+                'radius') is not None:
             new_object_params['radius'] = self.new_object.get('radius') or \
                 self.new_object.get('radius')
-        if self.new_object.get('guestPortBouncing') is not None or self.new_object.get('guest_port_bouncing') is not None:
+        if self.new_object.get('guestPortBouncing') is not None or self.new_object.get(
+                'guest_port_bouncing') is not None:
             new_object_params['guestPortBouncing'] = self.new_object.get(
                 'guestPortBouncing')
-        if self.new_object.get('radiusTestingEnabled') is not None or self.new_object.get('radius_testing_enabled') is not None:
+        if self.new_object.get('radiusTestingEnabled') is not None or self.new_object.get(
+                'radius_testing_enabled') is not None:
             new_object_params['radiusTestingEnabled'] = self.new_object.get(
                 'radiusTestingEnabled')
-        if self.new_object.get('radiusCoaSupportEnabled') is not None or self.new_object.get('radius_coa_support_enabled') is not None:
+        if self.new_object.get('radiusCoaSupportEnabled') is not None or self.new_object.get(
+                'radius_coa_support_enabled') is not None:
             new_object_params['radiusCoaSupportEnabled'] = self.new_object.get(
                 'radiusCoaSupportEnabled')
-        if self.new_object.get('radiusAccountingEnabled') is not None or self.new_object.get('radius_accounting_enabled') is not None:
+        if self.new_object.get('radiusAccountingEnabled') is not None or self.new_object.get(
+                'radius_accounting_enabled') is not None:
             new_object_params['radiusAccountingEnabled'] = self.new_object.get(
                 'radiusAccountingEnabled')
-        if self.new_object.get('radiusAccountingServers') is not None or self.new_object.get('radius_accounting_servers') is not None:
-            new_object_params['radiusAccountingServers'] = self.new_object.get('radiusAccountingServers') or \
-                self.new_object.get('radius_accounting_servers')
-        if self.new_object.get('radiusGroupAttribute') is not None or self.new_object.get('radius_group_attribute') is not None:
-            new_object_params['radiusGroupAttribute'] = self.new_object.get('radiusGroupAttribute') or \
-                self.new_object.get('radius_group_attribute')
-        if self.new_object.get('hostMode') is not None or self.new_object.get('host_mode') is not None:
-            new_object_params['hostMode'] = self.new_object.get('hostMode') or \
-                self.new_object.get('host_mode')
-        if self.new_object.get('accessPolicyType') is not None or self.new_object.get('access_policy_type') is not None:
-            new_object_params['accessPolicyType'] = self.new_object.get('accessPolicyType') or \
-                self.new_object.get('access_policy_type')
-        if self.new_object.get('increaseAccessSpeed') is not None or self.new_object.get('increase_access_speed') is not None:
+        if self.new_object.get('radiusAccountingServers') is not None or self.new_object.get(
+                'radius_accounting_servers') is not None:
+            new_object_params['radiusAccountingServers'] = self.new_object.get(
+                'radiusAccountingServers') or self.new_object.get('radius_accounting_servers')
+        if self.new_object.get('radiusGroupAttribute') is not None or self.new_object.get(
+                'radius_group_attribute') is not None:
+            new_object_params['radiusGroupAttribute'] = self.new_object.get(
+                'radiusGroupAttribute') or self.new_object.get('radius_group_attribute')
+        if self.new_object.get('hostMode') is not None or self.new_object.get(
+                'host_mode') is not None:
+            new_object_params['hostMode'] = self.new_object.get(
+                'hostMode') or self.new_object.get('host_mode')
+        if self.new_object.get('accessPolicyType') is not None or self.new_object.get(
+                'access_policy_type') is not None:
+            new_object_params['accessPolicyType'] = self.new_object.get(
+                'accessPolicyType') or self.new_object.get('access_policy_type')
+        if self.new_object.get('increaseAccessSpeed') is not None or self.new_object.get(
+                'increase_access_speed') is not None:
             new_object_params['increaseAccessSpeed'] = self.new_object.get(
                 'increaseAccessSpeed')
-        if self.new_object.get('guestVlanId') is not None or self.new_object.get('guest_vlan_id') is not None:
-            new_object_params['guestVlanId'] = self.new_object.get('guestVlanId') or \
-                self.new_object.get('guest_vlan_id')
-        if self.new_object.get('dot1x') is not None or self.new_object.get('dot1x') is not None:
+        if self.new_object.get('guestVlanId') is not None or self.new_object.get(
+                'guest_vlan_id') is not None:
+            new_object_params['guestVlanId'] = self.new_object.get(
+                'guestVlanId') or self.new_object.get('guest_vlan_id')
+        if self.new_object.get('dot1x') is not None or self.new_object.get(
+                'dot1x') is not None:
             new_object_params['dot1x'] = self.new_object.get('dot1x') or \
                 self.new_object.get('dot1x')
-        if self.new_object.get('voiceVlanClients') is not None or self.new_object.get('voice_vlan_clients') is not None:
+        if self.new_object.get('voiceVlanClients') is not None or self.new_object.get(
+                'voice_vlan_clients') is not None:
             new_object_params['voiceVlanClients'] = self.new_object.get(
                 'voiceVlanClients')
-        if self.new_object.get('urlRedirectWalledGardenEnabled') is not None or self.new_object.get('url_redirect_walled_garden_enabled') is not None:
+        if self.new_object.get('urlRedirectWalledGardenEnabled') is not None or self.new_object.get(
+                'url_redirect_walled_garden_enabled') is not None:
             new_object_params['urlRedirectWalledGardenEnabled'] = self.new_object.get(
                 'urlRedirectWalledGardenEnabled')
-        if self.new_object.get('urlRedirectWalledGardenRanges') is not None or self.new_object.get('url_redirect_walled_garden_ranges') is not None:
-            new_object_params['urlRedirectWalledGardenRanges'] = self.new_object.get('urlRedirectWalledGardenRanges') or \
-                self.new_object.get('url_redirect_walled_garden_ranges')
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
+        if self.new_object.get('urlRedirectWalledGardenRanges') is not None or self.new_object.get(
+                'url_redirect_walled_garden_ranges') is not None:
+            new_object_params['urlRedirectWalledGardenRanges'] = self.new_object.get(
+                'urlRedirectWalledGardenRanges') or self.new_object.get('url_redirect_walled_garden_ranges')
+        if self.new_object.get('guestGroupPolicyId') is not None or self.new_object.get(
+                'guest_group_policy_id') is not None:
+            new_object_params['guestGroupPolicyId'] = self.new_object.get(
+                'guestGroupPolicyId') or self.new_object.get('guest_group_policy_id')
+        if self.new_object.get('guestSgtId') is not None or self.new_object.get(
+                'guest_sgt_id') is not None:
+            new_object_params['guestSgtId'] = self.new_object.get(
+                'guestSgtId') or self.new_object.get('guest_sgt_id')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
         return new_object_params
 
     def delete_by_id_params(self):
         new_object_params = {}
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
-        if self.new_object.get('accessPolicyNumber') is not None or self.new_object.get('access_policy_number') is not None:
-            new_object_params['accessPolicyNumber'] = self.new_object.get('accessPolicyNumber') or \
-                self.new_object.get('access_policy_number')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
+        if self.new_object.get('accessPolicyNumber') is not None or self.new_object.get(
+                'access_policy_number') is not None:
+            new_object_params['accessPolicyNumber'] = self.new_object.get(
+                'accessPolicyNumber') or self.new_object.get('access_policy_number')
         return new_object_params
 
     def update_by_id_params(self):
         new_object_params = {}
-        if self.new_object.get('name') is not None or self.new_object.get('name') is not None:
+        if self.new_object.get('name') is not None or self.new_object.get(
+                'name') is not None:
             new_object_params['name'] = self.new_object.get('name') or \
                 self.new_object.get('name')
-        if self.new_object.get('radiusServers') is not None or self.new_object.get('radius_servers') is not None:
-            new_object_params['radiusServers'] = self.new_object.get('radiusServers') or \
-                self.new_object.get('radius_servers')
-        if self.new_object.get('radius') is not None or self.new_object.get('radius') is not None:
+        if self.new_object.get('radiusServers') is not None or self.new_object.get(
+                'radius_servers') is not None:
+            new_object_params['radiusServers'] = self.new_object.get(
+                'radiusServers') or self.new_object.get('radius_servers')
+        if self.new_object.get('radius') is not None or self.new_object.get(
+                'radius') is not None:
             new_object_params['radius'] = self.new_object.get('radius') or \
                 self.new_object.get('radius')
-        if self.new_object.get('guestPortBouncing') is not None or self.new_object.get('guest_port_bouncing') is not None:
+        if self.new_object.get('guestPortBouncing') is not None or self.new_object.get(
+                'guest_port_bouncing') is not None:
             new_object_params['guestPortBouncing'] = self.new_object.get(
                 'guestPortBouncing')
-        if self.new_object.get('radiusTestingEnabled') is not None or self.new_object.get('radius_testing_enabled') is not None:
+        if self.new_object.get('radiusTestingEnabled') is not None or self.new_object.get(
+                'radius_testing_enabled') is not None:
             new_object_params['radiusTestingEnabled'] = self.new_object.get(
                 'radiusTestingEnabled')
-        if self.new_object.get('radiusCoaSupportEnabled') is not None or self.new_object.get('radius_coa_support_enabled') is not None:
+        if self.new_object.get('radiusCoaSupportEnabled') is not None or self.new_object.get(
+                'radius_coa_support_enabled') is not None:
             new_object_params['radiusCoaSupportEnabled'] = self.new_object.get(
                 'radiusCoaSupportEnabled')
-        if self.new_object.get('radiusAccountingEnabled') is not None or self.new_object.get('radius_accounting_enabled') is not None:
+        if self.new_object.get('radiusAccountingEnabled') is not None or self.new_object.get(
+                'radius_accounting_enabled') is not None:
             new_object_params['radiusAccountingEnabled'] = self.new_object.get(
                 'radiusAccountingEnabled')
-        if self.new_object.get('radiusAccountingServers') is not None or self.new_object.get('radius_accounting_servers') is not None:
-            new_object_params['radiusAccountingServers'] = self.new_object.get('radiusAccountingServers') or \
-                self.new_object.get('radius_accounting_servers')
-        if self.new_object.get('radiusGroupAttribute') is not None or self.new_object.get('radius_group_attribute') is not None:
-            new_object_params['radiusGroupAttribute'] = self.new_object.get('radiusGroupAttribute') or \
-                self.new_object.get('radius_group_attribute')
-        if self.new_object.get('hostMode') is not None or self.new_object.get('host_mode') is not None:
-            new_object_params['hostMode'] = self.new_object.get('hostMode') or \
-                self.new_object.get('host_mode')
-        if self.new_object.get('accessPolicyType') is not None or self.new_object.get('access_policy_type') is not None:
-            new_object_params['accessPolicyType'] = self.new_object.get('accessPolicyType') or \
-                self.new_object.get('access_policy_type')
-        if self.new_object.get('increaseAccessSpeed') is not None or self.new_object.get('increase_access_speed') is not None:
+        if self.new_object.get('radiusAccountingServers') is not None or self.new_object.get(
+                'radius_accounting_servers') is not None:
+            new_object_params['radiusAccountingServers'] = self.new_object.get(
+                'radiusAccountingServers') or self.new_object.get('radius_accounting_servers')
+        if self.new_object.get('radiusGroupAttribute') is not None or self.new_object.get(
+                'radius_group_attribute') is not None:
+            new_object_params['radiusGroupAttribute'] = self.new_object.get(
+                'radiusGroupAttribute') or self.new_object.get('radius_group_attribute')
+        if self.new_object.get('hostMode') is not None or self.new_object.get(
+                'host_mode') is not None:
+            new_object_params['hostMode'] = self.new_object.get(
+                'hostMode') or self.new_object.get('host_mode')
+        if self.new_object.get('accessPolicyType') is not None or self.new_object.get(
+                'access_policy_type') is not None:
+            new_object_params['accessPolicyType'] = self.new_object.get(
+                'accessPolicyType') or self.new_object.get('access_policy_type')
+        if self.new_object.get('increaseAccessSpeed') is not None or self.new_object.get(
+                'increase_access_speed') is not None:
             new_object_params['increaseAccessSpeed'] = self.new_object.get(
                 'increaseAccessSpeed')
-        if self.new_object.get('guestVlanId') is not None or self.new_object.get('guest_vlan_id') is not None:
-            new_object_params['guestVlanId'] = self.new_object.get('guestVlanId') or \
-                self.new_object.get('guest_vlan_id')
-        if self.new_object.get('dot1x') is not None or self.new_object.get('dot1x') is not None:
+        if self.new_object.get('guestVlanId') is not None or self.new_object.get(
+                'guest_vlan_id') is not None:
+            new_object_params['guestVlanId'] = self.new_object.get(
+                'guestVlanId') or self.new_object.get('guest_vlan_id')
+        if self.new_object.get('dot1x') is not None or self.new_object.get(
+                'dot1x') is not None:
             new_object_params['dot1x'] = self.new_object.get('dot1x') or \
                 self.new_object.get('dot1x')
-        if self.new_object.get('voiceVlanClients') is not None or self.new_object.get('voice_vlan_clients') is not None:
+        if self.new_object.get('voiceVlanClients') is not None or self.new_object.get(
+                'voice_vlan_clients') is not None:
             new_object_params['voiceVlanClients'] = self.new_object.get(
                 'voiceVlanClients')
-        if self.new_object.get('urlRedirectWalledGardenEnabled') is not None or self.new_object.get('url_redirect_walled_garden_enabled') is not None:
+        if self.new_object.get('urlRedirectWalledGardenEnabled') is not None or self.new_object.get(
+                'url_redirect_walled_garden_enabled') is not None:
             new_object_params['urlRedirectWalledGardenEnabled'] = self.new_object.get(
                 'urlRedirectWalledGardenEnabled')
-        if self.new_object.get('urlRedirectWalledGardenRanges') is not None or self.new_object.get('url_redirect_walled_garden_ranges') is not None:
-            new_object_params['urlRedirectWalledGardenRanges'] = self.new_object.get('urlRedirectWalledGardenRanges') or \
-                self.new_object.get('url_redirect_walled_garden_ranges')
-        if self.new_object.get('networkId') is not None or self.new_object.get('network_id') is not None:
-            new_object_params['networkId'] = self.new_object.get('networkId') or \
-                self.new_object.get('network_id')
-        if self.new_object.get('accessPolicyNumber') is not None or self.new_object.get('access_policy_number') is not None:
-            new_object_params['accessPolicyNumber'] = self.new_object.get('accessPolicyNumber') or \
-                self.new_object.get('access_policy_number')
+        if self.new_object.get('urlRedirectWalledGardenRanges') is not None or self.new_object.get(
+                'url_redirect_walled_garden_ranges') is not None:
+            new_object_params['urlRedirectWalledGardenRanges'] = self.new_object.get(
+                'urlRedirectWalledGardenRanges') or self.new_object.get('url_redirect_walled_garden_ranges')
+        if self.new_object.get('guestGroupPolicyId') is not None or self.new_object.get(
+                'guest_group_policy_id') is not None:
+            new_object_params['guestGroupPolicyId'] = self.new_object.get(
+                'guestGroupPolicyId') or self.new_object.get('guest_group_policy_id')
+        if self.new_object.get('guestSgtId') is not None or self.new_object.get(
+                'guest_sgt_id') is not None:
+            new_object_params['guestSgtId'] = self.new_object.get(
+                'guestSgtId') or self.new_object.get('guest_sgt_id')
+        if self.new_object.get('networkId') is not None or self.new_object.get(
+                'network_id') is not None:
+            new_object_params['networkId'] = self.new_object.get(
+                'networkId') or self.new_object.get('network_id')
+        if self.new_object.get('accessPolicyNumber') is not None or self.new_object.get(
+                'access_policy_number') is not None:
+            new_object_params['accessPolicyNumber'] = self.new_object.get(
+                'accessPolicyNumber') or self.new_object.get('access_policy_number')
         return new_object_params
 
     def get_object_by_name(self, name):
@@ -321,14 +380,19 @@ class NetworksSwitchAccessPolicies(object):
             ("voiceVlanClients", "voiceVlanClients"),
             ("urlRedirectWalledGardenEnabled", "urlRedirectWalledGardenEnabled"),
             ("urlRedirectWalledGardenRanges", "urlRedirectWalledGardenRanges"),
+            ("guestGroupPolicyId", "guestGroupPolicyId"),
+            ("guestSgtId", "guestSgtId"),
             ("networkId", "networkId"),
             ("accessPolicyNumber", "accessPolicyNumber"),
         ]
         # Method 1. Params present in request (Ansible) obj are the same as the current (DNAC) params
         # If any does not have eq params, it requires update
-        return any(not meraki_compare_equality(current_obj.get(meraki_param),
-                                               requested_obj.get(ansible_param))
-                   for (meraki_param, ansible_param) in obj_params)
+        return any(
+            not meraki_compare_equality2(
+                current_obj.get(meraki_param),
+                requested_obj.get(ansible_param)) for (
+                meraki_param,
+                ansible_param) in obj_params)
 
     def create(self):
         result = self.meraki.exec_meraki(
