@@ -8,8 +8,10 @@ DOCUMENTATION = r"""
 module: devices_wireless_radio_settings_info
 short_description: Information module for devices _wireless _radio _settings
 description:
+  - Information module for Devices Wireless Radio Settings Info.
   - Get all devices _wireless _radio _settings.
-  - Return the manually configured radio settings overrides of a device, which take precedence over RF profiles.
+  - Return the manually configured radio settings overrides of a device, which take
+    precedence over RF profiles.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.meraki.module_info
@@ -20,6 +22,7 @@ options:
     type: dict
   serial:
     description:
+      - Information module for Devices Wireless Radio Settings Info.
       - Serial path parameter.
     type: str
 requirements:
@@ -70,16 +73,16 @@ meraki_response:
   type: dict
   sample: >
     {
+      "serial": "string",
+      "rfProfileId": "string",
+      "twoFourGhzSettings": {
+        "channel": 0,
+        "targetPower": 0
+      },
       "fiveGhzSettings": {
         "channel": 0,
         "channelWidth": 0,
         "targetPower": 0
-      },
-      "rfProfileId": "string",
-      "serial": "string",
-      "twoFourGhzSettings": {
-        "channel": 0,
-        "targetPower": 0
       }
     }
 """
