@@ -5,16 +5,15 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
-author: Francisco Munoz (@fmunoz)
+module: networks_firmware_upgrades
+short_description: Resource module for networks _firmwareupgrades
 description:
-  - Manage operation update of the resource networks _firmware _upgrades.
+  - Manage operation update of the resource networks _firmwareupgrades.
   - Update firmware upgrade information for a network.
+version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.meraki.module
-module: networks_firmware_upgrades
-notes:
-  - SDK Method used are networks.Networks.update_network_firmware_upgrades,
-  - Paths used are put /networks/{networkId}/firmwareUpgrades,
+author: Francisco Munoz (@fmunoz)
 options:
   networkId:
     description: NetworkId path parameter. Network ID.
@@ -229,36 +228,40 @@ requirements:
   - meraki >= 2.4.9
   - python >= 3.5
 seealso:
-  - description: Complete reference of the updateNetworkFirmwareUpgrades API.
+  - name: Cisco Meraki documentation for networks updateNetworkFirmwareUpgrades
+    description: Complete reference of the updateNetworkFirmwareUpgrades API.
     link: https://developer.cisco.com/meraki/api-v1/#!update-network-firmware-upgrades
-    name: Cisco Meraki documentation for networks updateNetworkFirmwareUpgrades
-short_description: Resource module for networks _firmware _upgrades
-version_added: 2.16.0
+notes:
+  - SDK Method used are
+    networks.Networks.update_network_firmware_upgrades,
+  - Paths used are
+    put /networks/{networkId}/firmwareUpgrades,
 """
 
 EXAMPLES = r"""
 - name: Update all
   cisco.meraki.networks_firmware_upgrades:
-    meraki_api_key: '{{ meraki_api_key }}'
-    meraki_base_url: '{{ meraki_base_url }}'
-    meraki_single_request_timeout: '{{ meraki_single_request_timeout }}'
-    meraki_certificate_path: '{{ meraki_certificate_path }}'
-    meraki_requests_proxy: '{{ meraki_requests_proxy }}'
-    meraki_wait_on_rate_limit: '{{ meraki_wait_on_rate_limit }}'
-    meraki_nginx_429_retry_wait_time: '{{ meraki_nginx_429_retry_wait_time }}'
-    meraki_action_batch_retry_wait_time: '{{ meraki_action_batch_retry_wait_time }}'
-    meraki_retry_4xx_error: '{{ meraki_retry_4xx_error }}'
-    meraki_retry_4xx_error_wait_time: '{{ meraki_retry_4xx_error_wait_time }}'
-    meraki_maximum_retries: '{{ meraki_maximum_retries }}'
-    meraki_output_log: '{{ meraki_output_log }}'
-    meraki_log_file_prefix: '{{ meraki_log_file_prefix }}'
-    meraki_log_path: '{{ meraki_log_path }}'
-    meraki_print_console: '{{ meraki_print_console }}'
-    meraki_suppress_logging: '{{ meraki_suppress_logging }}'
-    meraki_simulate: '{{ meraki_simulate }}'
-    meraki_be_geo_id: '{{ meraki_be_geo_id }}'
-    meraki_use_iterator_for_get_pages: '{{ meraki_use_iterator_for_get_pages }}'
-    meraki_inherit_logging_config: '{{ meraki_inherit_logging_config }}'
+    meraki_api_key: "{{ meraki_api_key }}"
+    meraki_base_url: "{{ meraki_base_url }}"
+    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
+    meraki_certificate_path: "{{ meraki_certificate_path }}"
+    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
+    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
+    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
+    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
+    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
+    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
+    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
+    meraki_output_log: "{{ meraki_output_log }}"
+    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
+    meraki_log_path: "{{ meraki_log_path }}"
+    meraki_print_console: "{{ meraki_print_console }}"
+    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
+    meraki_simulate: "{{ meraki_simulate }}"
+    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
+    meraki_caller: "{{ meraki_caller }}"
+    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
+    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
     state: present
     networkId: string
     products:
@@ -284,7 +287,7 @@ EXAMPLES = r"""
         nextUpgrade:
           time: '2019-03-17T17:22:52Z'
           toVersion:
-            id: '1007'
+            id: '1008'
         participateInNextBetaRelease: false
       sensor:
         nextUpgrade:
@@ -328,380 +331,388 @@ meraki_response:
   type: dict
   sample: >
     {
-      "products": {
-        "appliance": {
-          "availableVersions": [
-            {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          ],
-          "currentVersion": {
-            "firmware": "string",
-            "id": "string",
-            "releaseDate": "string",
-            "releaseType": "string",
-            "shortName": "string"
-          },
-          "lastUpgrade": {
-            "fromVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            },
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "nextUpgrade": {
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "participateInNextBetaRelease": true
-        },
-        "camera": {
-          "availableVersions": [
-            {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          ],
-          "currentVersion": {
-            "firmware": "string",
-            "id": "string",
-            "releaseDate": "string",
-            "releaseType": "string",
-            "shortName": "string"
-          },
-          "lastUpgrade": {
-            "fromVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            },
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "nextUpgrade": {
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "participateInNextBetaRelease": true
-        },
-        "cellularGateway": {
-          "availableVersions": [
-            {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          ],
-          "currentVersion": {
-            "firmware": "string",
-            "id": "string",
-            "releaseDate": "string",
-            "releaseType": "string",
-            "shortName": "string"
-          },
-          "lastUpgrade": {
-            "fromVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            },
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "nextUpgrade": {
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "participateInNextBetaRelease": true
-        },
-        "secureConnect": {
-          "availableVersions": [
-            {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          ],
-          "currentVersion": {
-            "firmware": "string",
-            "id": "string",
-            "releaseDate": "string",
-            "releaseType": "string",
-            "shortName": "string"
-          },
-          "lastUpgrade": {
-            "fromVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            },
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "nextUpgrade": {
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "participateInNextBetaRelease": true
-        },
-        "sensor": {
-          "availableVersions": [
-            {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          ],
-          "currentVersion": {
-            "firmware": "string",
-            "id": "string",
-            "releaseDate": "string",
-            "releaseType": "string",
-            "shortName": "string"
-          },
-          "lastUpgrade": {
-            "fromVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            },
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "nextUpgrade": {
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "participateInNextBetaRelease": true
-        },
-        "switch": {
-          "availableVersions": [
-            {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          ],
-          "currentVersion": {
-            "firmware": "string",
-            "id": "string",
-            "releaseDate": "string",
-            "releaseType": "string",
-            "shortName": "string"
-          },
-          "lastUpgrade": {
-            "fromVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            },
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "nextUpgrade": {
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "participateInNextBetaRelease": true
-        },
-        "wireless": {
-          "availableVersions": [
-            {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          ],
-          "currentVersion": {
-            "firmware": "string",
-            "id": "string",
-            "releaseDate": "string",
-            "releaseType": "string",
-            "shortName": "string"
-          },
-          "lastUpgrade": {
-            "fromVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            },
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "nextUpgrade": {
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "participateInNextBetaRelease": true
-        },
-        "wirelessController": {
-          "availableVersions": [
-            {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          ],
-          "currentVersion": {
-            "firmware": "string",
-            "id": "string",
-            "releaseDate": "string",
-            "releaseType": "string",
-            "shortName": "string"
-          },
-          "lastUpgrade": {
-            "fromVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            },
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "nextUpgrade": {
-            "time": "string",
-            "toVersion": {
-              "firmware": "string",
-              "id": "string",
-              "releaseDate": "string",
-              "releaseType": "string",
-              "shortName": "string"
-            }
-          },
-          "participateInNextBetaRelease": true
-        }
-      },
-      "timezone": "string",
       "upgradeWindow": {
         "dayOfWeek": "string",
         "hourOfDay": "string"
+      },
+      "timezone": "string",
+      "products": {
+        "wireless": {
+          "currentVersion": {
+            "id": "string",
+            "firmware": "string",
+            "shortName": "string",
+            "releaseType": "string",
+            "releaseDate": "string"
+          },
+          "lastUpgrade": {
+            "time": "string",
+            "fromVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            },
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "nextUpgrade": {
+            "time": "string",
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "isUpgradeAvailable": true,
+          "availableVersions": [
+            {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          ],
+          "participateInNextBetaRelease": true
+        },
+        "appliance": {
+          "currentVersion": {
+            "id": "string",
+            "firmware": "string",
+            "shortName": "string",
+            "releaseType": "string",
+            "releaseDate": "string"
+          },
+          "lastUpgrade": {
+            "time": "string",
+            "fromVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            },
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "nextUpgrade": {
+            "time": "string",
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "isUpgradeAvailable": true,
+          "availableVersions": [
+            {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          ],
+          "participateInNextBetaRelease": true
+        },
+        "switch": {
+          "currentVersion": {
+            "id": "string",
+            "firmware": "string",
+            "shortName": "string",
+            "releaseType": "string",
+            "releaseDate": "string"
+          },
+          "lastUpgrade": {
+            "time": "string",
+            "fromVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            },
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "nextUpgrade": {
+            "time": "string",
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "isUpgradeAvailable": true,
+          "availableVersions": [
+            {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          ],
+          "participateInNextBetaRelease": true
+        },
+        "camera": {
+          "currentVersion": {
+            "id": "string",
+            "firmware": "string",
+            "shortName": "string",
+            "releaseType": "string",
+            "releaseDate": "string"
+          },
+          "lastUpgrade": {
+            "time": "string",
+            "fromVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            },
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "nextUpgrade": {
+            "time": "string",
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "isUpgradeAvailable": true,
+          "availableVersions": [
+            {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          ],
+          "participateInNextBetaRelease": true
+        },
+        "cellularGateway": {
+          "currentVersion": {
+            "id": "string",
+            "firmware": "string",
+            "shortName": "string",
+            "releaseType": "string",
+            "releaseDate": "string"
+          },
+          "lastUpgrade": {
+            "time": "string",
+            "fromVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            },
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "nextUpgrade": {
+            "time": "string",
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "isUpgradeAvailable": true,
+          "availableVersions": [
+            {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          ],
+          "participateInNextBetaRelease": true
+        },
+        "sensor": {
+          "currentVersion": {
+            "id": "string",
+            "firmware": "string",
+            "shortName": "string",
+            "releaseType": "string",
+            "releaseDate": "string"
+          },
+          "lastUpgrade": {
+            "time": "string",
+            "fromVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            },
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "nextUpgrade": {
+            "time": "string",
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "isUpgradeAvailable": true,
+          "availableVersions": [
+            {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          ],
+          "participateInNextBetaRelease": true
+        },
+        "wirelessController": {
+          "currentVersion": {
+            "id": "string",
+            "firmware": "string",
+            "shortName": "string",
+            "releaseType": "string",
+            "releaseDate": "string"
+          },
+          "lastUpgrade": {
+            "time": "string",
+            "fromVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            },
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "nextUpgrade": {
+            "time": "string",
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "isUpgradeAvailable": true,
+          "availableVersions": [
+            {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          ],
+          "participateInNextBetaRelease": true
+        },
+        "secureConnect": {
+          "currentVersion": {
+            "id": "string",
+            "firmware": "string",
+            "shortName": "string",
+            "releaseType": "string",
+            "releaseDate": "string"
+          },
+          "lastUpgrade": {
+            "time": "string",
+            "fromVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            },
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "nextUpgrade": {
+            "time": "string",
+            "toVersion": {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          },
+          "isUpgradeAvailable": true,
+          "availableVersions": [
+            {
+              "id": "string",
+              "firmware": "string",
+              "shortName": "string",
+              "releaseType": "string",
+              "releaseDate": "string"
+            }
+          ],
+          "participateInNextBetaRelease": true
+        }
       }
     }
 """
