@@ -5,15 +5,14 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
----
 module: networks_group_policies
 short_description: Resource module for networks _grouppolicies
 description:
-- Manage operations create, update and delete of the resource networks _grouppolicies.
-- Create a group policy.
-- Delete a group policy.
-- Update a group policy.
-version_added: '2.16.0'
+  - Manage operations create, update and delete of the resource networks _grouppolicies.
+  - Create a group policy.
+  - Delete a group policy.
+  - Update a group policy.
+version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.meraki.module
 author: Francisco Munoz (@fmunoz)
@@ -36,8 +35,8 @@ options:
             type: int
         type: dict
       settings:
-        description: How bandwidth limits are enforced. Can be 'network default', 'ignore'
-          or 'custom'.
+        description: How bandwidth limits are enforced. Can be 'network default',
+          'ignore' or 'custom'.
         type: str
     type: dict
   bonjourForwarding:
@@ -45,17 +44,18 @@ options:
       has a wireless configuration.
     suboptions:
       rules:
-        description: A list of the Bonjour forwarding rules for your group policy. If
-          'settings' is set to 'custom', at least one rule must be specified.
+        description: A list of the Bonjour forwarding rules for your group policy.
+          If 'settings' is set to 'custom', at least one rule must be specified.
         elements: dict
         suboptions:
           description:
             description: A description for your Bonjour forwarding rule. Optional.
             type: str
           services:
-            description: A list of Bonjour services. At least one service must be specified.
-              Available services are 'All Services', 'AirPlay', 'AFP', 'BitTorrent',
-              'FTP', 'iChat', 'iTunes', 'Printers', 'Samba', 'Scanners' and 'SSH'.
+            description: A list of Bonjour services. At least one service must be
+              specified. Available services are 'All Services', 'AFP', 'AirPlay',
+              'Apple screen share', 'BitTorrent', 'Chromecast', 'FTP', 'iChat', 'iTunes',
+              'Printers', 'Samba', 'Scanners', 'Spotify' and 'SSH'.
             elements: str
             type: list
           vlanId:
@@ -90,8 +90,8 @@ options:
             elements: str
             type: list
           settings:
-            description: How URL categories are applied. Can be 'network default', 'append'
-              or 'override'.
+            description: How URL categories are applied. Can be 'network default',
+              'append' or 'override'.
             type: str
         type: dict
       blockedUrlPatterns:
@@ -158,8 +158,8 @@ options:
         type: str
       trafficShapingRules:
         description: An array of traffic shaping rules. Rules are applied in the order
-          that they are specified in. An empty list (or null) means no rules. Note that
-          you are allowed a maximum of 8 rules.
+          that they are specified in. An empty list (or null) means no rules. Note
+          that you are allowed a maximum of 8 rules.
         elements: dict
         suboptions:
           definitions:
@@ -168,18 +168,18 @@ options:
             elements: dict
             suboptions:
               type:
-                description: The type of definition. Can be one of 'application', 'applicationCategory',
-                  'host', 'port', 'ipRange' or 'localNet'.
+                description: The type of definition. Can be one of 'application',
+                  'applicationCategory', 'host', 'port', 'ipRange' or 'localNet'.
                 type: str
               value:
-                description: If "type" is 'host', 'port', 'ipRange' or 'localNet', then
-                  "value" must be a string, matching either a hostname (e.g. "somesite.com"),
-                  a port (e.g. 8080), or an IP range ("192.1.0.0", "192.1.0.0/16", or
-                  "10.1.0.0/16 80"). 'localNet' also supports CIDR notation, excluding
-                  custom ports. If "type" is 'application' or 'applicationCategory',
-                  then "value" must be an object with the structure { "id" "meraki layer7/..."
-                  }, where "id" is the application category or application ID (for a
-                  list of IDs for your network, use the trafficShaping/applicationCategories
+                description: If "type" is 'host', 'port', 'ipRange' or 'localNet',
+                  then "value" must be a string, matching either a hostname (e.g.
+                  "somesite.com"), a port (e.g. 8080), or an IP range ("192.1.0.0",
+                  "192.1.0.0/16", or "10.1.0.0/16 80"). 'localNet' also supports CIDR
+                  notation, excluding custom ports. If "type" is 'application' or
+                  'applicationCategory', then "value" must be an object with the structure
+                  { "id" "meraki layer7/..." }, where "id" is the application category
+                  or application ID (for a list of IDs for your network, use the trafficShaping/applicationCategories
                   endpoint).
                 type: str
             type: list
@@ -208,16 +208,22 @@ options:
                     type: int
                 type: dict
               settings:
-                description: How bandwidth limits are applied by your rule. Can be one
-                  of 'network default', 'ignore' or 'custom'.
+                description: How bandwidth limits are applied by your rule. Can be
+                  one of 'network default', 'ignore' or 'custom'.
                 type: str
             type: dict
           priority:
-            description: A string, indicating the priority level for packets bound to
-              your rule. Can be 'low', 'normal' or 'high'.
+            description: A string, indicating the priority level for packets bound
+              to your rule. Can be 'low', 'normal' or 'high'.
             type: str
         type: list
     type: dict
+  force:
+    description: Force query parameter. If true, the system deletes the GP even if
+      there are active clients using the GP. After deletion, active clients that were
+      assigned to that Group Policy will be left without any policy applied. Default
+      is false.
+    type: bool
   groupPolicyId:
     description: GroupPolicyId path parameter. Group policy ID.
     type: str
@@ -228,25 +234,25 @@ options:
     description: NetworkId path parameter. Network ID.
     type: str
   scheduling:
-    description: The schedule for the group policy. Schedules are applied to days of
-      the week.
+    description: The schedule for the group policy. Schedules are applied to days
+      of the week.
     suboptions:
       enabled:
         description: Whether scheduling is enabled (true) or disabled (false). Defaults
-          to false. If true, the schedule objects for each day of the week (monday -
-          sunday) are parsed.
+          to false. If true, the schedule objects for each day of the week (monday
+          - sunday) are parsed.
         type: bool
       friday:
         description: The schedule object for Friday.
         suboptions:
           active:
-            description: Whether the schedule is active (true) or inactive (false) during
-              the time specified between 'from' and 'to'. Defaults to true.
+            description: Whether the schedule is active (true) or inactive (false)
+              during the time specified between 'from' and 'to'. Defaults to true.
             type: bool
           from:
-            description: The time, from '00 00' to '24 00'. Must be less than the time
-              specified in 'to'. Defaults to '00 00'. Only 30 minute increments are
-              allowed.
+            description: The time, from '00 00' to '24 00'. Must be less than the
+              time specified in 'to'. Defaults to '00 00'. Only 30 minute increments
+              are allowed.
             type: str
           to:
             description: The time, from '00 00' to '24 00'. Must be greater than the
@@ -258,13 +264,13 @@ options:
         description: The schedule object for Monday.
         suboptions:
           active:
-            description: Whether the schedule is active (true) or inactive (false) during
-              the time specified between 'from' and 'to'. Defaults to true.
+            description: Whether the schedule is active (true) or inactive (false)
+              during the time specified between 'from' and 'to'. Defaults to true.
             type: bool
           from:
-            description: The time, from '00 00' to '24 00'. Must be less than the time
-              specified in 'to'. Defaults to '00 00'. Only 30 minute increments are
-              allowed.
+            description: The time, from '00 00' to '24 00'. Must be less than the
+              time specified in 'to'. Defaults to '00 00'. Only 30 minute increments
+              are allowed.
             type: str
           to:
             description: The time, from '00 00' to '24 00'. Must be greater than the
@@ -276,13 +282,13 @@ options:
         description: The schedule object for Saturday.
         suboptions:
           active:
-            description: Whether the schedule is active (true) or inactive (false) during
-              the time specified between 'from' and 'to'. Defaults to true.
+            description: Whether the schedule is active (true) or inactive (false)
+              during the time specified between 'from' and 'to'. Defaults to true.
             type: bool
           from:
-            description: The time, from '00 00' to '24 00'. Must be less than the time
-              specified in 'to'. Defaults to '00 00'. Only 30 minute increments are
-              allowed.
+            description: The time, from '00 00' to '24 00'. Must be less than the
+              time specified in 'to'. Defaults to '00 00'. Only 30 minute increments
+              are allowed.
             type: str
           to:
             description: The time, from '00 00' to '24 00'. Must be greater than the
@@ -294,13 +300,13 @@ options:
         description: The schedule object for Sunday.
         suboptions:
           active:
-            description: Whether the schedule is active (true) or inactive (false) during
-              the time specified between 'from' and 'to'. Defaults to true.
+            description: Whether the schedule is active (true) or inactive (false)
+              during the time specified between 'from' and 'to'. Defaults to true.
             type: bool
           from:
-            description: The time, from '00 00' to '24 00'. Must be less than the time
-              specified in 'to'. Defaults to '00 00'. Only 30 minute increments are
-              allowed.
+            description: The time, from '00 00' to '24 00'. Must be less than the
+              time specified in 'to'. Defaults to '00 00'. Only 30 minute increments
+              are allowed.
             type: str
           to:
             description: The time, from '00 00' to '24 00'. Must be greater than the
@@ -312,13 +318,13 @@ options:
         description: The schedule object for Thursday.
         suboptions:
           active:
-            description: Whether the schedule is active (true) or inactive (false) during
-              the time specified between 'from' and 'to'. Defaults to true.
+            description: Whether the schedule is active (true) or inactive (false)
+              during the time specified between 'from' and 'to'. Defaults to true.
             type: bool
           from:
-            description: The time, from '00 00' to '24 00'. Must be less than the time
-              specified in 'to'. Defaults to '00 00'. Only 30 minute increments are
-              allowed.
+            description: The time, from '00 00' to '24 00'. Must be less than the
+              time specified in 'to'. Defaults to '00 00'. Only 30 minute increments
+              are allowed.
             type: str
           to:
             description: The time, from '00 00' to '24 00'. Must be greater than the
@@ -330,13 +336,13 @@ options:
         description: The schedule object for Tuesday.
         suboptions:
           active:
-            description: Whether the schedule is active (true) or inactive (false) during
-              the time specified between 'from' and 'to'. Defaults to true.
+            description: Whether the schedule is active (true) or inactive (false)
+              during the time specified between 'from' and 'to'. Defaults to true.
             type: bool
           from:
-            description: The time, from '00 00' to '24 00'. Must be less than the time
-              specified in 'to'. Defaults to '00 00'. Only 30 minute increments are
-              allowed.
+            description: The time, from '00 00' to '24 00'. Must be less than the
+              time specified in 'to'. Defaults to '00 00'. Only 30 minute increments
+              are allowed.
             type: str
           to:
             description: The time, from '00 00' to '24 00'. Must be greater than the
@@ -348,13 +354,13 @@ options:
         description: The schedule object for Wednesday.
         suboptions:
           active:
-            description: Whether the schedule is active (true) or inactive (false) during
-              the time specified between 'from' and 'to'. Defaults to true.
+            description: Whether the schedule is active (true) or inactive (false)
+              during the time specified between 'from' and 'to'. Defaults to true.
             type: bool
           from:
-            description: The time, from '00 00' to '24 00'. Must be less than the time
-              specified in 'to'. Defaults to '00 00'. Only 30 minute increments are
-              allowed.
+            description: The time, from '00 00' to '24 00'. Must be less than the
+              time specified in 'to'. Defaults to '00 00'. Only 30 minute increments
+              are allowed.
             type: str
           to:
             description: The time, from '00 00' to '24 00'. Must be greater than the
@@ -365,8 +371,8 @@ options:
     type: dict
   splashAuthSettings:
     description: Whether clients bound to your policy will bypass splash authorization
-      or behave according to the network's rules. Can be one of 'network default' or
-      'bypass'. Only available if your network has a wireless configuration.
+      or behave according to the network's rules. Can be one of 'network default'
+      or 'bypass'. Only available if your network has a wireless configuration.
     type: str
   vlanTagging:
     description: The VLAN tagging settings for your group policy. Only available if
@@ -382,24 +388,23 @@ options:
         type: str
     type: dict
 requirements:
-- meraki >= 2.4.9
-- python >= 3.5
+  - meraki >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco Meraki documentation for networks createNetworkGroupPolicy
-  description: Complete reference of the createNetworkGroupPolicy API.
-  link: https://developer.cisco.com/meraki/api-v1/#!create-network-group-policy
-- name: Cisco Meraki documentation for networks deleteNetworkGroupPolicy
-  description: Complete reference of the deleteNetworkGroupPolicy API.
-  link: https://developer.cisco.com/meraki/api-v1/#!delete-network-group-policy
-- name: Cisco Meraki documentation for networks updateNetworkGroupPolicy
-  description: Complete reference of the updateNetworkGroupPolicy API.
-  link: https://developer.cisco.com/meraki/api-v1/#!update-network-group-policy
+  - name: Cisco Meraki documentation for networks createNetworkGroupPolicy
+    description: Complete reference of the createNetworkGroupPolicy API.
+    link: https://developer.cisco.com/meraki/api-v1/#!create-network-group-policy
+  - name: Cisco Meraki documentation for networks deleteNetworkGroupPolicy
+    description: Complete reference of the deleteNetworkGroupPolicy API.
+    link: https://developer.cisco.com/meraki/api-v1/#!delete-network-group-policy
+  - name: Cisco Meraki documentation for networks updateNetworkGroupPolicy
+    description: Complete reference of the updateNetworkGroupPolicy API.
+    link: https://developer.cisco.com/meraki/api-v1/#!update-network-group-policy
 notes:
   - SDK Method used are
     networks.Networks.create_network_group_policy,
     networks.Networks.delete_network_group_policy,
     networks.Networks.update_network_group_policy,
-
   - Paths used are
     post /networks/{networkId}/groupPolicies,
     delete /networks/{networkId}/groupPolicies/{groupPolicyId},
@@ -409,26 +414,27 @@ notes:
 EXAMPLES = r"""
 - name: Create
   cisco.meraki.networks_group_policies:
-    meraki_api_key: "{{meraki_api_key}}"
-    meraki_base_url: "{{meraki_base_url}}"
-    meraki_single_request_timeout: "{{meraki_single_request_timeout}}"
-    meraki_certificate_path: "{{meraki_certificate_path}}"
-    meraki_requests_proxy: "{{meraki_requests_proxy}}"
-    meraki_wait_on_rate_limit: "{{meraki_wait_on_rate_limit}}"
-    meraki_nginx_429_retry_wait_time: "{{meraki_nginx_429_retry_wait_time}}"
-    meraki_action_batch_retry_wait_time: "{{meraki_action_batch_retry_wait_time}}"
-    meraki_retry_4xx_error: "{{meraki_retry_4xx_error}}"
-    meraki_retry_4xx_error_wait_time: "{{meraki_retry_4xx_error_wait_time}}"
-    meraki_maximum_retries: "{{meraki_maximum_retries}}"
-    meraki_output_log: "{{meraki_output_log}}"
-    meraki_log_file_prefix: "{{meraki_log_file_prefix}}"
-    meraki_log_path: "{{meraki_log_path}}"
-    meraki_print_console: "{{meraki_print_console}}"
-    meraki_suppress_logging: "{{meraki_suppress_logging}}"
-    meraki_simulate: "{{meraki_simulate}}"
-    meraki_be_geo_id: "{{meraki_be_geo_id}}"
-    meraki_use_iterator_for_get_pages: "{{meraki_use_iterator_for_get_pages}}"
-    meraki_inherit_logging_config: "{{meraki_inherit_logging_config}}"
+    meraki_api_key: "{{ meraki_api_key }}"
+    meraki_base_url: "{{ meraki_base_url }}"
+    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
+    meraki_certificate_path: "{{ meraki_certificate_path }}"
+    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
+    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
+    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
+    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
+    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
+    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
+    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
+    meraki_output_log: "{{ meraki_output_log }}"
+    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
+    meraki_log_path: "{{ meraki_log_path }}"
+    meraki_print_console: "{{ meraki_print_console }}"
+    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
+    meraki_simulate: "{{ meraki_simulate }}"
+    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
+    meraki_caller: "{{ meraki_caller }}"
+    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
+    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
     state: present
     bandwidth:
       bandwidthLimits:
@@ -437,10 +443,10 @@ EXAMPLES = r"""
       settings: custom
     bonjourForwarding:
       rules:
-      - description: A simple bonjour rule
-        services:
-        - All Services
-        vlanId: '1'
+        - description: A simple bonjour rule
+          services:
+            - All Services
+          vlanId: '1'
       settings: custom
     contentFiltering:
       allowedUrlPatterns:
@@ -448,38 +454,38 @@ EXAMPLES = r"""
         settings: network default
       blockedUrlCategories:
         categories:
-        - meraki:contentFiltering/category/1
-        - meraki:contentFiltering/category/7
+          - meraki:contentFiltering/category/1
+          - meraki:contentFiltering/category/7
         settings: override
       blockedUrlPatterns:
         patterns:
-        - http://www.example.com
-        - http://www.betting.com
+          - http://www.example.com
+          - http://www.betting.com
         settings: append
     firewallAndTrafficShaping:
       l3FirewallRules:
-      - comment: Allow TCP traffic to subnet with HTTP servers.
-        destCidr: 192.168.1.0/24
-        destPort: '443'
-        policy: allow
-        protocol: tcp
+        - comment: Allow TCP traffic to subnet with HTTP servers.
+          destCidr: 192.168.1.0/24
+          destPort: '443'
+          policy: allow
+          protocol: tcp
       l7FirewallRules:
-      - policy: deny
-        type: host
-        value: google.com
+        - policy: deny
+          type: host
+          value: google.com
       settings: custom
       trafficShapingRules:
-      - definitions:
-        - type: host
-          value: google.com
-        dscpTagValue: 0
-        pcpTagValue: 0
-        perClientBandwidthLimits:
-          bandwidthLimits:
-            limitDown: 1000000
-            limitUp: 1000000
-          settings: custom
-        priority: normal
+        - definitions:
+            - type: host
+              value: google.com
+          dscpTagValue: 0
+          pcpTagValue: 0
+          perClientBandwidthLimits:
+            bandwidthLimits:
+              limitDown: 1000000
+              limitUp: 1000000
+            settings: custom
+          priority: normal
     name: No video streaming
     networkId: string
     scheduling:
@@ -516,55 +522,29 @@ EXAMPLES = r"""
     vlanTagging:
       settings: custom
       vlanId: '1'
-
-- name: Delete by id
-  cisco.meraki.networks_group_policies:
-    meraki_api_key: "{{meraki_api_key}}"
-    meraki_base_url: "{{meraki_base_url}}"
-    meraki_single_request_timeout: "{{meraki_single_request_timeout}}"
-    meraki_certificate_path: "{{meraki_certificate_path}}"
-    meraki_requests_proxy: "{{meraki_requests_proxy}}"
-    meraki_wait_on_rate_limit: "{{meraki_wait_on_rate_limit}}"
-    meraki_nginx_429_retry_wait_time: "{{meraki_nginx_429_retry_wait_time}}"
-    meraki_action_batch_retry_wait_time: "{{meraki_action_batch_retry_wait_time}}"
-    meraki_retry_4xx_error: "{{meraki_retry_4xx_error}}"
-    meraki_retry_4xx_error_wait_time: "{{meraki_retry_4xx_error_wait_time}}"
-    meraki_maximum_retries: "{{meraki_maximum_retries}}"
-    meraki_output_log: "{{meraki_output_log}}"
-    meraki_log_file_prefix: "{{meraki_log_file_prefix}}"
-    meraki_log_path: "{{meraki_log_path}}"
-    meraki_print_console: "{{meraki_print_console}}"
-    meraki_suppress_logging: "{{meraki_suppress_logging}}"
-    meraki_simulate: "{{meraki_simulate}}"
-    meraki_be_geo_id: "{{meraki_be_geo_id}}"
-    meraki_use_iterator_for_get_pages: "{{meraki_use_iterator_for_get_pages}}"
-    meraki_inherit_logging_config: "{{meraki_inherit_logging_config}}"
-    state: absent
-    groupPolicyId: string
-    networkId: string
-
 - name: Update by id
   cisco.meraki.networks_group_policies:
-    meraki_api_key: "{{meraki_api_key}}"
-    meraki_base_url: "{{meraki_base_url}}"
-    meraki_single_request_timeout: "{{meraki_single_request_timeout}}"
-    meraki_certificate_path: "{{meraki_certificate_path}}"
-    meraki_requests_proxy: "{{meraki_requests_proxy}}"
-    meraki_wait_on_rate_limit: "{{meraki_wait_on_rate_limit}}"
-    meraki_nginx_429_retry_wait_time: "{{meraki_nginx_429_retry_wait_time}}"
-    meraki_action_batch_retry_wait_time: "{{meraki_action_batch_retry_wait_time}}"
-    meraki_retry_4xx_error: "{{meraki_retry_4xx_error}}"
-    meraki_retry_4xx_error_wait_time: "{{meraki_retry_4xx_error_wait_time}}"
-    meraki_maximum_retries: "{{meraki_maximum_retries}}"
-    meraki_output_log: "{{meraki_output_log}}"
-    meraki_log_file_prefix: "{{meraki_log_file_prefix}}"
-    meraki_log_path: "{{meraki_log_path}}"
-    meraki_print_console: "{{meraki_print_console}}"
-    meraki_suppress_logging: "{{meraki_suppress_logging}}"
-    meraki_simulate: "{{meraki_simulate}}"
-    meraki_be_geo_id: "{{meraki_be_geo_id}}"
-    meraki_use_iterator_for_get_pages: "{{meraki_use_iterator_for_get_pages}}"
-    meraki_inherit_logging_config: "{{meraki_inherit_logging_config}}"
+    meraki_api_key: "{{ meraki_api_key }}"
+    meraki_base_url: "{{ meraki_base_url }}"
+    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
+    meraki_certificate_path: "{{ meraki_certificate_path }}"
+    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
+    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
+    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
+    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
+    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
+    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
+    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
+    meraki_output_log: "{{ meraki_output_log }}"
+    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
+    meraki_log_path: "{{ meraki_log_path }}"
+    meraki_print_console: "{{ meraki_print_console }}"
+    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
+    meraki_simulate: "{{ meraki_simulate }}"
+    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
+    meraki_caller: "{{ meraki_caller }}"
+    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
+    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
     state: present
     bandwidth:
       bandwidthLimits:
@@ -573,10 +553,10 @@ EXAMPLES = r"""
       settings: custom
     bonjourForwarding:
       rules:
-      - description: A simple bonjour rule
-        services:
-        - All Services
-        vlanId: '1'
+        - description: A simple bonjour rule
+          services:
+            - All Services
+          vlanId: '1'
       settings: custom
     contentFiltering:
       allowedUrlPatterns:
@@ -584,38 +564,38 @@ EXAMPLES = r"""
         settings: network default
       blockedUrlCategories:
         categories:
-        - meraki:contentFiltering/category/1
-        - meraki:contentFiltering/category/7
+          - meraki:contentFiltering/category/1
+          - meraki:contentFiltering/category/7
         settings: override
       blockedUrlPatterns:
         patterns:
-        - http://www.example.com
-        - http://www.betting.com
+          - http://www.example.com
+          - http://www.betting.com
         settings: append
     firewallAndTrafficShaping:
       l3FirewallRules:
-      - comment: Allow TCP traffic to subnet with HTTP servers.
-        destCidr: 192.168.1.0/24
-        destPort: '443'
-        policy: allow
-        protocol: tcp
+        - comment: Allow TCP traffic to subnet with HTTP servers.
+          destCidr: 192.168.1.0/24
+          destPort: '443'
+          policy: allow
+          protocol: tcp
       l7FirewallRules:
-      - policy: deny
-        type: host
-        value: google.com
+        - policy: deny
+          type: host
+          value: google.com
       settings: custom
       trafficShapingRules:
-      - definitions:
-        - type: host
-          value: google.com
-        dscpTagValue: 0
-        pcpTagValue: 0
-        perClientBandwidthLimits:
-          bandwidthLimits:
-            limitDown: 1000000
-            limitUp: 1000000
-          settings: custom
-        priority: normal
+        - definitions:
+            - type: host
+              value: google.com
+          dscpTagValue: 0
+          pcpTagValue: 0
+          perClientBandwidthLimits:
+            bandwidthLimits:
+              limitDown: 1000000
+              limitUp: 1000000
+            settings: custom
+          priority: normal
     groupPolicyId: string
     name: No video streaming
     networkId: string
@@ -653,7 +633,33 @@ EXAMPLES = r"""
     vlanTagging:
       settings: custom
       vlanId: '1'
-
+- name: Delete by id
+  cisco.meraki.networks_group_policies:
+    meraki_api_key: "{{ meraki_api_key }}"
+    meraki_base_url: "{{ meraki_base_url }}"
+    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
+    meraki_certificate_path: "{{ meraki_certificate_path }}"
+    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
+    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
+    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
+    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
+    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
+    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
+    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
+    meraki_output_log: "{{ meraki_output_log }}"
+    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
+    meraki_log_path: "{{ meraki_log_path }}"
+    meraki_print_console: "{{ meraki_print_console }}"
+    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
+    meraki_simulate: "{{ meraki_simulate }}"
+    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
+    meraki_caller: "{{ meraki_caller }}"
+    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
+    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
+    state: absent
+    force: true
+    groupPolicyId: string
+    networkId: string
 """
 RETURN = r"""
 meraki_response:
@@ -662,112 +668,14 @@ meraki_response:
   type: dict
   sample: >
     {
-      "bandwidth": {
-        "bandwidthLimits": {
-          "limitDown": 0,
-          "limitUp": 0
-        },
-        "settings": "string"
-      },
-      "bonjourForwarding": {
-        "rules": [
-          {
-            "description": "string",
-            "services": [
-              "string"
-            ],
-            "vlanId": "string"
-          }
-        ],
-        "settings": "string"
-      },
-      "contentFiltering": {
-        "allowedUrlPatterns": {
-          "patterns": [
-            "string"
-          ],
-          "settings": "string"
-        },
-        "blockedUrlCategories": {
-          "categories": [
-            "string"
-          ],
-          "settings": "string"
-        },
-        "blockedUrlPatterns": {
-          "patterns": [
-            "string"
-          ],
-          "settings": "string"
-        }
-      },
-      "firewallAndTrafficShaping": {
-        "l3FirewallRules": [
-          {
-            "comment": "string",
-            "destCidr": "string",
-            "destPort": "string",
-            "policy": "string",
-            "protocol": "string"
-          }
-        ],
-        "l7FirewallRules": [
-          {
-            "policy": "string",
-            "type": "string",
-            "value": "string"
-          }
-        ],
-        "settings": "string",
-        "trafficShapingRules": [
-          {
-            "definitions": [
-              {
-                "type": "string",
-                "value": "string"
-              }
-            ],
-            "dscpTagValue": 0,
-            "pcpTagValue": 0,
-            "perClientBandwidthLimits": {
-              "bandwidthLimits": {
-                "limitDown": 0,
-                "limitUp": 0
-              },
-              "settings": "string"
-            },
-            "priority": "string"
-          }
-        ]
-      },
       "groupPolicyId": "string",
       "scheduling": {
         "enabled": true,
-        "friday": {
-          "active": true,
-          "from": "string",
-          "to": "string"
-        },
         "monday": {
           "active": true,
           "from": "string",
           "to": "string"
         },
-        "saturday": {
-          "active": true,
-          "from": "string",
-          "to": "string"
-        },
-        "sunday": {
-          "active": true,
-          "from": "string",
-          "to": "string"
-        },
-        "thursday": {
-          "active": true,
-          "from": "string",
-          "to": "string"
-        },
         "tuesday": {
           "active": true,
           "from": "string",
@@ -777,12 +685,110 @@ meraki_response:
           "active": true,
           "from": "string",
           "to": "string"
+        },
+        "thursday": {
+          "active": true,
+          "from": "string",
+          "to": "string"
+        },
+        "friday": {
+          "active": true,
+          "from": "string",
+          "to": "string"
+        },
+        "saturday": {
+          "active": true,
+          "from": "string",
+          "to": "string"
+        },
+        "sunday": {
+          "active": true,
+          "from": "string",
+          "to": "string"
+        }
+      },
+      "bandwidth": {
+        "settings": "string",
+        "bandwidthLimits": {
+          "limitUp": 0,
+          "limitDown": 0
+        }
+      },
+      "firewallAndTrafficShaping": {
+        "settings": "string",
+        "trafficShapingRules": [
+          {
+            "definitions": [
+              {
+                "type": "string",
+                "value": "string"
+              }
+            ],
+            "perClientBandwidthLimits": {
+              "settings": "string",
+              "bandwidthLimits": {
+                "limitUp": 0,
+                "limitDown": 0
+              }
+            },
+            "dscpTagValue": 0,
+            "pcpTagValue": 0,
+            "priority": "string"
+          }
+        ],
+        "l3FirewallRules": [
+          {
+            "comment": "string",
+            "policy": "string",
+            "protocol": "string",
+            "destPort": "string",
+            "destCidr": "string"
+          }
+        ],
+        "l7FirewallRules": [
+          {
+            "policy": "string",
+            "type": "string",
+            "value": "string"
+          }
+        ]
+      },
+      "contentFiltering": {
+        "allowedUrlPatterns": {
+          "settings": "string",
+          "patterns": [
+            "string"
+          ]
+        },
+        "blockedUrlPatterns": {
+          "settings": "string",
+          "patterns": [
+            "string"
+          ]
+        },
+        "blockedUrlCategories": {
+          "settings": "string",
+          "categories": [
+            "string"
+          ]
         }
       },
       "splashAuthSettings": "string",
       "vlanTagging": {
         "settings": "string",
         "vlanId": "string"
+      },
+      "bonjourForwarding": {
+        "settings": "string",
+        "rules": [
+          {
+            "description": "string",
+            "vlanId": "string",
+            "services": [
+              "string"
+            ]
+          }
+        ]
       }
     }
 """
