@@ -113,19 +113,10 @@ meraki_response:
   sample: >
     {
       "id": "string",
-      "isMonitorOnly": true,
-      "members": [
-        {
-          "mac": "string",
-          "model": "string",
-          "name": "string",
-          "role": "string",
-          "serial": "string"
-        }
-      ],
       "name": "string",
       "serials": [
         "string"
-      ]
+      ],
+      "workflowId": "string"
     }
 """
