@@ -5,16 +5,15 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
-author: Francisco Munoz (@fmunoz)
+module: networks_wireless_ssids
+short_description: Resource module for networks _wireless _ssids
 description:
   - Manage operation update of the resource networks _wireless _ssids.
   - Update the attributes of an MR SSID.
+version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.meraki.module
-module: networks_wireless_ssids
-notes:
-  - SDK Method used are wireless.Wireless.update_network_wireless_ssid,
-  - Paths used are put /networks/{networkId}/wireless/ssids/{number},
+author: Francisco Munoz (@fmunoz)
 options:
   activeDirectory:
     description: The current setting for Active Directory. Only valid if splashPage
@@ -46,6 +45,9 @@ options:
             type: int
         type: list
     type: dict
+  adaptivePolicyGroupId:
+    description: Adaptive policy group ID this SSID is assigned to.
+    type: str
   adultContentFilteringEnabled:
     description: Boolean indicating whether or not adult content will be blocked.
     type: bool
@@ -65,8 +67,8 @@ options:
   authMode:
     description: The association control method for the SSID ('open', 'open-enhanced',
       'psk', 'open-with-radius', 'open-with-nac', '8021x-meraki', '8021x-nac', '8021x-radius',
-      '8021x-google', '8021x-entra', '8021x-localradius', 'ipsk-with-radius', 'ipsk-without-radius'
-      or 'ipsk-with-nac').
+      '8021x-google', '8021x-entra', '8021x-localradius', 'ipsk-with-radius', 'ipsk-without-radius',
+      'ipsk-with-nac' or 'ipsk-with-radius-easy-psk').
     type: str
   availabilityTags:
     description: Accepts a list of tags for this SSID. If availableOnAllAps is false,
@@ -159,7 +161,8 @@ options:
     type: dict
   ipAssignmentMode:
     description: The client IP assignment mode ('NAT mode', 'Bridge mode', 'Layer
-      3 roaming', 'Ethernet over GRE', 'Layer 3 roaming with a concentrator' or 'VPN').
+      3 roaming', 'Ethernet over GRE', 'Layer 3 roaming with a concentrator', 'VPN'
+      or 'Campus Gateway').
     type: str
   lanIsolationEnabled:
     description: Boolean indicating whether Layer 2 LAN isolation should be enabled
@@ -205,6 +208,29 @@ options:
             type: int
         type: list
     type: dict
+  localAuthFallback:
+    description: The current configuration for Local Authentication Fallback. Enables
+      the Access Point (AP) to store client authentication data for a specified duration
+      that can be adjusted as needed.
+    suboptions:
+      cacheTimeout:
+        description: The duration (in seconds) for which auths are cached. The timeout
+          is measured from the user's most recent non-cached authentication to the
+          network. Between 3600 (1 hour) and 86400 (1 day).
+        type: int
+      enabled:
+        description: If true, MR devices will cache authentication credentials for
+          EAP-TLS or for MAC based authentication.
+        type: bool
+      serverCaCertificate:
+        description: The Server CA Certificate used to sign the client certificate.
+        suboptions:
+          contents:
+            description: The contents of the Server CA Certificate. Must be in PEM
+              or DER format.
+            type: str
+        type: dict
+    type: dict
   localRadius:
     description: The current setting for Local Authentication, a built-in RADIUS server
       on the access point. Only valid if authMode is '8021x-localradius'.
@@ -372,6 +398,10 @@ options:
           RADIUS server.
         type: str
     type: list
+  radiusAccountingStartDelay:
+    description: The delay (in seconds) before sending the first RADIUS accounting
+      start message. Must be between 0 and 60 seconds.
+    type: int
   radiusAttributeForGroupPolicies:
     description: Specify the RADIUS attribute used to look up group policies ('Filter-Id',
       'Reply-Message', 'Airespace-ACL-Name' or 'Aruba-User-Role'). Access points must
@@ -422,6 +452,18 @@ options:
     description: If true, Meraki devices will proxy RADIUS messages through the Meraki
       cloud to the configured RADIUS auth and accounting servers.
     type: bool
+  radiusRadsec:
+    description: The current settings for RADIUS RADSec.
+    suboptions:
+      tlsTunnel:
+        description: RADSec TLS tunnel settings.
+        suboptions:
+          timeout:
+            description: The interval (in seconds) to determines how long a TLS session
+              can remain idle for a RADSec server before it is automatically terminated.
+            type: int
+        type: dict
+    type: dict
   radiusServerAttemptsLimit:
     description: The maximum number of transmit attempts after which a RADIUS server
       is failed over (must be between 1-5).
@@ -485,7 +527,7 @@ options:
       with custom RADIUS', 'Password-protected with Active Directory', 'Password-protected
       with LDAP', 'SMS authentication', 'Systems Manager Sentry', 'Facebook Wi-Fi',
       'Google OAuth', 'Microsoft Entra ID', 'Sponsored guest', 'Cisco ISE' or 'Google
-      Apps domain'). This attribute is not supported for template children.
+      Apps domain').This attribute is not supported for template children.
     type: str
   useVlanTagging:
     description: Whether or not traffic should be directed to use specific VLANs.
@@ -519,36 +561,40 @@ requirements:
   - meraki >= 2.4.9
   - python >= 3.5
 seealso:
-  - description: Complete reference of the updateNetworkWirelessSsid API.
+  - name: Cisco Meraki documentation for wireless updateNetworkWirelessSsid
+    description: Complete reference of the updateNetworkWirelessSsid API.
     link: https://developer.cisco.com/meraki/api-v1/#!update-network-wireless-ssid
-    name: Cisco Meraki documentation for wireless updateNetworkWirelessSsid
-short_description: Resource module for networks _wireless _ssids
-version_added: 2.16.0
+notes:
+  - SDK Method used are
+    wireless.Wireless.update_network_wireless_ssid,
+  - Paths used are
+    put /networks/{networkId}/wireless/ssids/{number},
 """
 
 EXAMPLES = r"""
 - name: Update by id
   cisco.meraki.networks_wireless_ssids:
-    meraki_api_key: '{{ meraki_api_key }}'
-    meraki_base_url: '{{ meraki_base_url }}'
-    meraki_single_request_timeout: '{{ meraki_single_request_timeout }}'
-    meraki_certificate_path: '{{ meraki_certificate_path }}'
-    meraki_requests_proxy: '{{ meraki_requests_proxy }}'
-    meraki_wait_on_rate_limit: '{{ meraki_wait_on_rate_limit }}'
-    meraki_nginx_429_retry_wait_time: '{{ meraki_nginx_429_retry_wait_time }}'
-    meraki_action_batch_retry_wait_time: '{{ meraki_action_batch_retry_wait_time }}'
-    meraki_retry_4xx_error: '{{ meraki_retry_4xx_error }}'
-    meraki_retry_4xx_error_wait_time: '{{ meraki_retry_4xx_error_wait_time }}'
-    meraki_maximum_retries: '{{ meraki_maximum_retries }}'
-    meraki_output_log: '{{ meraki_output_log }}'
-    meraki_log_file_prefix: '{{ meraki_log_file_prefix }}'
-    meraki_log_path: '{{ meraki_log_path }}'
-    meraki_print_console: '{{ meraki_print_console }}'
-    meraki_suppress_logging: '{{ meraki_suppress_logging }}'
-    meraki_simulate: '{{ meraki_simulate }}'
-    meraki_be_geo_id: '{{ meraki_be_geo_id }}'
-    meraki_use_iterator_for_get_pages: '{{ meraki_use_iterator_for_get_pages }}'
-    meraki_inherit_logging_config: '{{ meraki_inherit_logging_config }}'
+    meraki_api_key: "{{ meraki_api_key }}"
+    meraki_base_url: "{{ meraki_base_url }}"
+    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
+    meraki_certificate_path: "{{ meraki_certificate_path }}"
+    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
+    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
+    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
+    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
+    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
+    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
+    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
+    meraki_output_log: "{{ meraki_output_log }}"
+    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
+    meraki_log_path: "{{ meraki_log_path }}"
+    meraki_print_console: "{{ meraki_print_console }}"
+    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
+    meraki_simulate: "{{ meraki_simulate }}"
+    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
+    meraki_caller: "{{ meraki_caller }}"
+    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
+    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
     state: present
     activeDirectory:
       credentials:
@@ -557,6 +603,7 @@ EXAMPLES = r"""
       servers:
         - host: 127.0.0.1
           port: 3268
+    adaptivePolicyGroupId: '1234'
     adultContentFilteringEnabled: false
     apTagsAndVlanIds:
       - tags:
@@ -604,7 +651,7 @@ EXAMPLES = r"""
           YXNwYWNlczpVUzELMAkGA1UEBhMCVVMxCzAJBgNVBAgTAkNBMQ4wDAYDVQQKEwVD aXNjbzEcMBoGA1UECxMTV0JBOldSSVggRW5kLUVudGl0eTE8MDoGA1UEAxMzNjQ3
           MDcwNDM4NDQ5NjQxMjAwMDAuMTg4MzQuaHMuY2lzY28ub3BlbnJvYW1pbmcub3Jn MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoqjP9QgRGyUO3p7SH9QK
           uTq6UYK7nAyjImgS4yQxeBkyZ5f2EUkX8m/AOcewpPxxPBhjPKRwxGeX3S50ksiA ayFomUeslR0S0Z7RN9rzJa+CFyi9MwWIHMbLgXpB8tsSpgTAqwrzoTzOGq9fgC6u
-          pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM
+          pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM2
           aEMddOeOTtz+i/rgjkp/RGMt011EdCsso0/cTo9qqX/bxOOCE4/Mne/ChMkQPnNU CwIDAQABo3IwcDAJBgNVHRMEAjAAMB8GA1UdIwQYMBaAFIG+4l5yiB01gP0sw4ML
           USopqYcuMB0GA1UdDgQWBBSby1T9leYVOVVdOZXiHCSaDDEMiDAOBgNVHQ8BAf8E BAMCBaAwEwYDVR0lBAwwCgYIKwYBBQUHAwIwDQYJKoZIhvcNAQELBQADggEBAEyE
           1mjSUyY6uNp6W4l20w7SskALSJDRKkOeZxAgF3VMxlsCuEl70s9oEfntwIpyQtSa jON/9yJHbwm/Az824bmk8Dc7AXIPhay+dftXb8j529gPuYB9AKoPNg0NctkyYCQh
@@ -614,6 +661,23 @@ EXAMPLES = r"""
       servers:
         - host: 127.0.0.1
           port: 389
+    localAuthFallback:
+      cacheTimeout: 6500
+      enabled: true
+      serverCaCertificate:
+        contents: '-----BEGIN CERTIFICATE----- MIIEKjCCAxKgAwIBAgIRANb+lsED3eb4+6YKLFFYqEkwDQYJKoZIhvcNAQELBQAw
+          gYcxCzAJBgNVBAYTAlVTMRMwEQYDVQQIDApDYWxpZm9ybmlhMREwDwYDVQQHDAhT YW4gSm9zZTEcMBoGA1UECgwTQ2lzY28gU3lzdGVtcywgSW5jLjESMBAGA1UECwwJ
+          RE5BU3BhY2VzMR4wHAYDVQQDDBVjaXNjby5vcGVucm9hbWluZy5vcmcwHhcNMjAx MTA1MjEzMzM1WhcNMjExMTA1MjIzMzM1WjCBpDEcMBoGCgmSJomT8ixkAQETDGRu
+          YXNwYWNlczpVUzELMAkGA1UEBhMCVVMxCzAJBgNVBAgTAkNBMQ4wDAYDVQQKEwVD aXNjbzEcMBoGA1UECxMTV0JBOldSSVggRW5kLUVudGl0eTE8MDoGA1UEAxMzNjQ3
+          MDcwNDM4NDQ5NjQxMjAwMDAuMTg4MzQuaHMuY2lzY28ub3BlbnJvYW1pbmcub3Jn MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoqjP9QgRGyUO3p7SH9QK
+          uTq6UYK7nAyjImgS4yQxeBkyZ5f2EUkX8m/AOcewpPxxPBhjPKRwxGeX3S50ksiA ayFomUeslR0S0Z7RN9rzJa+CFyi9MwWIHMbLgXpB8tsSpgTAqwrzoTzOGq9fgC6u
+          pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM2
+          aEMddOeOTtz+i/rgjkp/RGMt011EdCsso0/cTo9qqX/bxOOCE4/Mne/ChMkQPnNU CwIDAQABo3IwcDAJBgNVHRMEAjAAMB8GA1UdIwQYMBaAFIG+4l5yiB01gP0sw4ML
+          USopqYcuMB0GA1UdDgQWBBSby1T9leYVOVVdOZXiHCSaDDEMiDAOBgNVHQ8BAf8E BAMCBaAwEwYDVR0lBAwwCgYIKwYBBQUHAwIwDQYJKoZIhvcNAQELBQADggEBAEyE
+          1mjSUyY6uNp6W4l20w7SskALSJDRKkOeZxAgF3VMxlsCuEl70s9oEfntwIpyQtSa jON/9yJHbwm/Az824bmk8Dc7AXIPhay+dftXb8j529gPuYB9AKoPNg0NctkyYCQh
+          a/3YQVdDWX7XgmEiXkL57M7G6+IdcPDONLArfjOcT9qHdkVVq1AIjlMSx3OQQmm/ uoLb/G9q/97QA2/l8shG/Na8HjVqGLcl5TNZdbNhs2w9ogxr/GNzqdvym6RQ8vT/
+          UR2n+uwH4n1MUxmHYYeyot5dnIV1IJ6hQ54JAncM9HvCLFk1WHz6RKshQUCuPBiJ wTw70BVktzJnb0VLeDg=
+          -----END CERTIFICATE-----'
     localRadius:
       cacheTimeout: 60
       certificateAuthentication:
@@ -624,7 +688,7 @@ EXAMPLES = r"""
             YXNwYWNlczpVUzELMAkGA1UEBhMCVVMxCzAJBgNVBAgTAkNBMQ4wDAYDVQQKEwVD aXNjbzEcMBoGA1UECxMTV0JBOldSSVggRW5kLUVudGl0eTE8MDoGA1UEAxMzNjQ3
             MDcwNDM4NDQ5NjQxMjAwMDAuMTg4MzQuaHMuY2lzY28ub3BlbnJvYW1pbmcub3Jn MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoqjP9QgRGyUO3p7SH9QK
             uTq6UYK7nAyjImgS4yQxeBkyZ5f2EUkX8m/AOcewpPxxPBhjPKRwxGeX3S50ksiA ayFomUeslR0S0Z7RN9rzJa+CFyi9MwWIHMbLgXpB8tsSpgTAqwrzoTzOGq9fgC6u
-            pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM
+            pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM2
             aEMddOeOTtz+i/rgjkp/RGMt011EdCsso0/cTo9qqX/bxOOCE4/Mne/ChMkQPnNU CwIDAQABo3IwcDAJBgNVHRMEAjAAMB8GA1UdIwQYMBaAFIG+4l5yiB01gP0sw4ML
             USopqYcuMB0GA1UdDgQWBBSby1T9leYVOVVdOZXiHCSaDDEMiDAOBgNVHQ8BAf8E BAMCBaAwEwYDVR0lBAwwCgYIKwYBBQUHAwIwDQYJKoZIhvcNAQELBQADggEBAEyE
             1mjSUyY6uNp6W4l20w7SskALSJDRKkOeZxAgF3VMxlsCuEl70s9oEfntwIpyQtSa jON/9yJHbwm/Az824bmk8Dc7AXIPhay+dftXb8j529gPuYB9AKoPNg0NctkyYCQh
@@ -672,7 +736,7 @@ EXAMPLES = r"""
           YXNwYWNlczpVUzELMAkGA1UEBhMCVVMxCzAJBgNVBAgTAkNBMQ4wDAYDVQQKEwVD aXNjbzEcMBoGA1UECxMTV0JBOldSSVggRW5kLUVudGl0eTE8MDoGA1UEAxMzNjQ3
           MDcwNDM4NDQ5NjQxMjAwMDAuMTg4MzQuaHMuY2lzY28ub3BlbnJvYW1pbmcub3Jn MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoqjP9QgRGyUO3p7SH9QK
           uTq6UYK7nAyjImgS4yQxeBkyZ5f2EUkX8m/AOcewpPxxPBhjPKRwxGeX3S50ksiA ayFomUeslR0S0Z7RN9rzJa+CFyi9MwWIHMbLgXpB8tsSpgTAqwrzoTzOGq9fgC6u
-          pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM
+          pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM2
           aEMddOeOTtz+i/rgjkp/RGMt011EdCsso0/cTo9qqX/bxOOCE4/Mne/ChMkQPnNU CwIDAQABo3IwcDAJBgNVHRMEAjAAMB8GA1UdIwQYMBaAFIG+4l5yiB01gP0sw4ML
           USopqYcuMB0GA1UdDgQWBBSby1T9leYVOVVdOZXiHCSaDDEMiDAOBgNVHQ8BAf8E BAMCBaAwEwYDVR0lBAwwCgYIKwYBBQUHAwIwDQYJKoZIhvcNAQELBQADggEBAEyE
           1mjSUyY6uNp6W4l20w7SskALSJDRKkOeZxAgF3VMxlsCuEl70s9oEfntwIpyQtSa jON/9yJHbwm/Az824bmk8Dc7AXIPhay+dftXb8j529gPuYB9AKoPNg0NctkyYCQh
@@ -683,6 +747,7 @@ EXAMPLES = r"""
         port: 3000
         radsecEnabled: true
         secret: secret-string
+    radiusAccountingStartDelay: 0
     radiusAttributeForGroupPolicies: Filter-Id
     radiusAuthenticationNasId: 00-11-22-33-44-55:AP1
     radiusCalledStationId: 00-11-22-33-44-55:AP1
@@ -694,6 +759,9 @@ EXAMPLES = r"""
     radiusLoadBalancingPolicy: Round robin
     radiusOverride: false
     radiusProxyEnabled: false
+    radiusRadsec:
+      tlsTunnel:
+        timeout: 600
     radiusServerAttemptsLimit: 5
     radiusServerTimeout: 5
     radiusServers:
@@ -703,7 +771,7 @@ EXAMPLES = r"""
           YXNwYWNlczpVUzELMAkGA1UEBhMCVVMxCzAJBgNVBAgTAkNBMQ4wDAYDVQQKEwVD aXNjbzEcMBoGA1UECxMTV0JBOldSSVggRW5kLUVudGl0eTE8MDoGA1UEAxMzNjQ3
           MDcwNDM4NDQ5NjQxMjAwMDAuMTg4MzQuaHMuY2lzY28ub3BlbnJvYW1pbmcub3Jn MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoqjP9QgRGyUO3p7SH9QK
           uTq6UYK7nAyjImgS4yQxeBkyZ5f2EUkX8m/AOcewpPxxPBhjPKRwxGeX3S50ksiA ayFomUeslR0S0Z7RN9rzJa+CFyi9MwWIHMbLgXpB8tsSpgTAqwrzoTzOGq9fgC6u
-          pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM
+          pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM2
           aEMddOeOTtz+i/rgjkp/RGMt011EdCsso0/cTo9qqX/bxOOCE4/Mne/ChMkQPnNU CwIDAQABo3IwcDAJBgNVHRMEAjAAMB8GA1UdIwQYMBaAFIG+4l5yiB01gP0sw4ML
           USopqYcuMB0GA1UdDgQWBBSby1T9leYVOVVdOZXiHCSaDDEMiDAOBgNVHQ8BAf8E BAMCBaAwEwYDVR0lBAwwCgYIKwYBBQUHAwIwDQYJKoZIhvcNAQELBQADggEBAEyE
           1mjSUyY6uNp6W4l20w7SskALSJDRKkOeZxAgF3VMxlsCuEl70s9oEfntwIpyQtSa jON/9yJHbwm/Az824bmk8Dc7AXIPhay+dftXb8j529gPuYB9AKoPNg0NctkyYCQh
@@ -738,54 +806,54 @@ meraki_response:
   type: dict
   sample: >
     {
-      "adminSplashUrl": "string",
-      "authMode": "string",
-      "availabilityTags": [
-        "string"
-      ],
-      "availableOnAllAps": true,
-      "bandSelection": "string",
-      "enabled": true,
-      "encryptionMode": "string",
-      "ipAssignmentMode": "string",
-      "localAuth": true,
-      "mandatoryDhcpEnabled": true,
-      "minBitrate": 0,
-      "name": "string",
       "number": 0,
-      "perClientBandwidthLimitDown": 0,
-      "perClientBandwidthLimitUp": 0,
-      "perSsidBandwidthLimitDown": 0,
-      "perSsidBandwidthLimitUp": 0,
-      "radiusAccountingEnabled": true,
-      "radiusAccountingServers": [
-        {
-          "caCertificate": "string",
-          "host": "string",
-          "openRoamingCertificateId": 0,
-          "port": 0
-        }
-      ],
-      "radiusAttributeForGroupPolicies": "string",
-      "radiusEnabled": true,
-      "radiusFailoverPolicy": "string",
-      "radiusLoadBalancingPolicy": "string",
+      "name": "string",
+      "enabled": true,
+      "splashPage": "string",
+      "ssidAdminAccessible": true,
+      "localAuth": true,
+      "authMode": "string",
+      "encryptionMode": "string",
+      "wpaEncryptionMode": "string",
       "radiusServers": [
         {
-          "caCertificate": "string",
           "host": "string",
+          "port": 0,
           "openRoamingCertificateId": 0,
-          "port": 0
+          "caCertificate": "string"
         }
       ],
-      "splashPage": "string",
+      "radiusAccountingServers": [
+        {
+          "host": "string",
+          "port": 0,
+          "openRoamingCertificateId": 0,
+          "caCertificate": "string"
+        }
+      ],
+      "radiusAccountingEnabled": true,
+      "radiusEnabled": true,
+      "radiusAttributeForGroupPolicies": "string",
+      "radiusFailoverPolicy": "string",
+      "radiusLoadBalancingPolicy": "string",
+      "ipAssignmentMode": "string",
+      "adminSplashUrl": "string",
       "splashTimeout": "string",
-      "ssidAdminAccessible": true,
-      "visible": true,
       "walledGardenEnabled": true,
       "walledGardenRanges": [
         "string"
       ],
-      "wpaEncryptionMode": "string"
+      "minBitrate": 0,
+      "bandSelection": "string",
+      "perClientBandwidthLimitUp": 0,
+      "perClientBandwidthLimitDown": 0,
+      "visible": true,
+      "availableOnAllAps": true,
+      "availabilityTags": [
+        "string"
+      ],
+      "perSsidBandwidthLimitUp": 0,
+      "perSsidBandwidthLimitDown": 0,
+      "mandatoryDhcpEnabled": true
     }
 """
