@@ -6,8 +6,10 @@
 
 DOCUMENTATION = r"""
 module: organizations_assurance_alerts_overview_by_type_info
-short_description: Information module for organizations _assurance _alerts _overview _by _type
+short_description: Information module for organizations _assurance _alerts _overview
+  _by _type
 description:
+  - Information module for Organizations Assurance Alerts Overview By Type Info.
   - Get all organizations _assurance _alerts _overview _by _type.
   - Return a Summary of Alerts grouped by type and severity.
 version_added: '1.0.0'
@@ -21,100 +23,133 @@ options:
     type: dict
   organizationId:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - OrganizationId path parameter. Organization ID.
     type: str
   perPage:
     description:
-      - PerPage query parameter. The number of entries per page returned. Acceptable range is 3 - 1000. Default is 1000.
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
+      - PerPage query parameter. The number of entries per page returned. Acceptable
+        range is 3 - 1000. Default is 1000.
     type: int
   startingAfter:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - >
-        StartingAfter query parameter. A token used by the server to indicate the start of the page. Often this is a timestamp or an ID but it
-        is not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page
-        in the HTTP Link header should define it.
+        StartingAfter query parameter. A token used by the server to indicate the
+        start of the page. Often this is a timestamp or an ID but it is not limited
+        to those. This parameter should not be defined by client applications. The
+        link for the first, last, prev, or next page in the HTTP Link header should
+        define it.
     type: str
   endingBefore:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - >
-        EndingBefore query parameter. A token used by the server to indicate the end of the page. Often this is a timestamp or an ID but it is
-        not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page in
-        the HTTP Link header should define it.
+        EndingBefore query parameter. A token used by the server to indicate the end
+        of the page. Often this is a timestamp or an ID but it is not limited to those.
+        This parameter should not be defined by client applications. The link for
+        the first, last, prev, or next page in the HTTP Link header should define
+        it.
     type: str
   sortOrder:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - >
-        SortOrder query parameter. Sorted order of entries. Order options are 'ascending' and 'descending'. Default is 'ascending'.
+        SortOrder query parameter. Sorted order of entries. Order options are 'ascending'
+        and 'descending'. Default is 'ascending'.
     type: str
   networkId:
     description:
-      - NetworkId query parameter. Optional parameter to filter alerts overview by network ids.
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
+      - NetworkId query parameter. Optional parameter to filter alerts overview by
+        network ids.
     type: str
   severity:
     description:
-      - Severity query parameter. Optional parameter to filter alerts overview by severity type.
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
+      - Severity query parameter. Optional parameter to filter alerts overview by
+        severity type.
     type: str
   types:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - Types query parameter. Optional parameter to filter by alert type.
     elements: str
     type: list
   tsStart:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - TsStart query parameter. Optional parameter to filter by starting timestamp.
     type: str
   tsEnd:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - TsEnd query parameter. Optional parameter to filter by end timestamp.
     type: str
   category:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - Category query parameter. Optional parameter to filter by category.
     type: str
   sortBy:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - SortBy query parameter. Optional parameter to set column to sort by.
     type: str
   serials:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - Serials query parameter. Optional parameter to filter by primary device serial.
     elements: str
     type: list
   deviceTypes:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - DeviceTypes query parameter. Optional parameter to filter by device types.
     elements: str
     type: list
   deviceTags:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - DeviceTags query parameter. Optional parameter to filter by device tags.
     elements: str
     type: list
   active:
     description:
-      - Active query parameter. Optional parameter to filter by active alerts defaults to true.
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
+      - Active query parameter. Optional parameter to filter by active alerts defaults
+        to true.
     type: bool
   dismissed:
     description:
-      - Dismissed query parameter. Optional parameter to filter by dismissed alerts defaults to false.
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
+      - Dismissed query parameter. Optional parameter to filter by dismissed alerts
+        defaults to false.
     type: bool
   resolved:
     description:
-      - Resolved query parameter. Optional parameter to filter by resolved alerts defaults to false.
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
+      - Resolved query parameter. Optional parameter to filter by resolved alerts
+        defaults to false.
     type: bool
   suppressAlertsForOfflineNodes:
     description:
+      - Information module for Organizations Assurance Alerts Overview By Type Info.
       - >
-        SuppressAlertsForOfflineNodes query parameter. When set to true the api will only return connectivity alerts for a given device if that
-        device is in an offline state. This only applies to devices. This is ignored when resolved is true. Example If a Switch has a VLan Mismatch
-        and is Unreachable. Only the Unreachable alert will be returned. Defaults to false.
+        SuppressAlertsForOfflineNodes query parameter. When set to true the api will
+        only return connectivity alerts for a given device if that device is in an
+        offline state. This only applies to devices. This is ignored when resolved
+        is true. Example If a Switch has a VLan Mismatch and is Unreachable. Only
+        the Unreachable alert will be returned. Defaults to false.
     type: bool
 requirements:
   - meraki >= 2.4.9
   - python >= 3.5
 seealso:
   - name: Cisco Meraki documentation for organizations getOrganizationAssuranceAlertsOverviewByType
-    description: Complete reference of the getOrganizationAssuranceAlertsOverviewByType API.
+    description: Complete reference of the getOrganizationAssuranceAlertsOverviewByType
+      API.
     link: https://developer.cisco.com/meraki/api-v1/#!get-organization-assurance-alerts-overview-by-type
 notes:
   - SDK Method used are
@@ -179,8 +214,9 @@ meraki_response:
     {
       "items": [
         {
-          "count": 0,
-          "type": "string"
+          "type": "string",
+          "lastResolvedAt": "string",
+          "count": 0
         }
       ],
       "meta": {
