@@ -125,15 +125,14 @@ compose:
 """
 
 from ansible.errors import AnsibleError
-from ansible.plugins.inventory import BaseInventoryPlugin, Constructable, Cacheable
+from ansible.plugins.inventory import BaseInventoryPlugin, Cacheable, Constructable
 
 from ansible_collections.community.general.plugins.plugin_utils.unsafe import make_unsafe
 
-
 try:
     from linode_api4 import LinodeClient
-    from linode_api4.objects.linode import Instance
     from linode_api4.errors import ApiError as LinodeApiError
+    from linode_api4.objects.linode import Instance
 
     HAS_LINODE = True
 except ImportError:
@@ -203,7 +202,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                 ips += [instance.ips.ipv6.slaac, instance.ips.ipv6.link_local]
                 ips += instance.ips.ipv6.pools
 
-                for ip_type in set(ip.type for ip in ips):
+                for ip_type in {ip.type for ip in ips}:
                     self.inventory.set_variable(
                         hostname, ip_type, make_unsafe(self._ip_data([ip for ip in ips if ip.type == ip_type]))
                     )
