@@ -79,12 +79,11 @@ _result:
 
 import os
 import subprocess
-from subprocess import PIPE
-from subprocess import Popen
+from subprocess import PIPE, Popen
 
 from ansible.errors import AnsibleError
-from ansible.plugins.lookup import LookupBase
 from ansible.module_utils.common.text.converters import to_bytes, to_native
+from ansible.plugins.lookup import LookupBase
 from ansible.utils.display import Display
 
 display = Display()
@@ -164,11 +163,11 @@ class CyberarkPassword:
                     result_dict[output_names[i]] = to_native(output_values[i])
 
         except subprocess.CalledProcessError as e:
-            raise AnsibleError(e.output)
+            raise AnsibleError(e.output) from e
         except OSError as e:
             raise AnsibleError(
                 f"ERROR - AIM not installed or clipasswordsdk not in standard location. ERROR=({e.errno}) => {e.strerror} "
-            )
+            ) from e
 
         return [result_dict]
 
