@@ -12,12 +12,15 @@
 
 from __future__ import annotations
 
-
 import os
 import traceback
+import typing as t
 
 from ansible.module_utils.basic import missing_required_lib
 
+if t.TYPE_CHECKING:
+    from ansible.module_utils.basic import AnsibleModule
+
 CLIENT_IMP_ERR = None
 try:
     from manageiq_client.api import ManageIQClient
@@ -28,7 +31,7 @@ except ImportError:
     HAS_CLIENT = False
 
 
-def manageiq_argument_spec():
+def manageiq_argument_spec() -> dict[str, t.Any]:
     options = dict(
         url=dict(default=os.environ.get("MIQ_URL", None)),
         username=dict(default=os.environ.get("MIQ_USERNAME", None)),
@@ -43,27 +46,28 @@ def manageiq_argument_spec():
     )
 
 
-def check_client(module):
+def check_client(module: AnsibleModule) -> None:
     if not HAS_CLIENT:
         module.fail_json(msg=missing_required_lib("manageiq-client"), exception=CLIENT_IMP_ERR)
 
 
-def validate_connection_params(module):
-    params = module.params["manageiq_connection"]
+def validate_connection_params(module: AnsibleModule) -> dict[str, t.Any]:
+    params: dict[str, t.Any] = module.params["manageiq_connection"]
     error_str = "missing required argument: manageiq_connection[{}]"
-    url = params["url"]
-    token = params["token"]
-    username = params["username"]
-    password = params["password"]
+    url: str | None = params["url"]
+    token: str | None = params["token"]
+    username: str | None = params["username"]
+    password: str | None = params["password"]
 
     if (url and username and password) or (url and token):
         return params
     for arg in ["url", "username", "password"]:
         if params[arg] in (None, ""):
             module.fail_json(msg=error_str.format(arg))
+    raise AssertionError("should be unreachable")
 
 
-def manageiq_entities():
+def manageiq_entities() -> dict[str, str]:
     return {
         "provider": "providers",
         "host": "hosts",
@@ -87,7 +91,7 @@ class ManageIQ:
     class encapsulating ManageIQ API client.
     """
 
-    def __init__(self, module):
+    def __init__(self, module: AnsibleModule) -> None:
         # handle import errors
         check_client(module)
 
@@ -111,7 +115,7 @@ class ManageIQ:
             self.module.fail_json(msg=f"failed to open connection ({url}): {e}")
 
     @property
-    def module(self):
+    def module(self) -> AnsibleModule:
         """Ansible module module
 
         Returns:
@@ -120,7 +124,7 @@ class ManageIQ:
         return self._module
 
     @property
-    def api_url(self):
+    def api_url(self) -> str:
         """Base ManageIQ API
 
         Returns:
@@ -192,7 +196,7 @@ class ManageIQPolicies:
     Object to execute policies management operations of manageiq resources.
     """
 
-    def __init__(self, manageiq, resource_type, resource_id):
+    def __init__(self, manageiq: ManageIQ, resource_type, resource_id):
         self.manageiq = manageiq
 
         self.module = self.manageiq.module
@@ -287,7 +291,7 @@ class ManageIQPolicies:
 
         # make a list of assigned full profile names strings
         # e.g. ['openscap profile', ...]
-        assigned_profiles_set = set(profile["profile_name"] for profile in assigned_profiles)
+        assigned_profiles_set = {profile["profile_name"] for profile in assigned_profiles}
 
         for profile in profiles:
             assigned = profile.get("name") in assigned_profiles_set
@@ -330,7 +334,7 @@ class ManageIQTags:
     Object to execute tags management operations of manageiq resources.
     """
 
-    def __init__(self, manageiq, resource_type, resource_id):
+    def __init__(self, manageiq: ManageIQ, resource_type, resource_id):
         self.manageiq = manageiq
 
         self.module = self.manageiq.module
@@ -393,7 +397,7 @@ class ManageIQTags:
 
         # make a list of assigned full tag names strings
         # e.g. ['/managed/environment/prod', ...]
-        assigned_tags_set = set(tag["full_name"] for tag in assigned_tags)
+        assigned_tags_set = {tag["full_name"] for tag in assigned_tags}
 
         for tag in tags:
             assigned = self.full_tag_name(tag) in assigned_tags_set
