@@ -193,7 +193,6 @@ from zlib import crc32
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.common.text.converters import to_bytes, to_native
 
-
 STATE_ABSENT = "absent"
 STATE_ARCHIVED = "archive"
 STATE_COMPRESSED = "compress"
@@ -321,7 +320,7 @@ class Archive(metaclass=abc.ABCMeta):
                 f_out.close()
                 self.successes.append(path)
                 self.destination_state = STATE_COMPRESSED
-            except (IOError, OSError) as e:
+            except OSError as e:
                 self.module.fail_json(
                     path=_to_native(path),
                     dest=_to_native(self.destination),
@@ -506,7 +505,7 @@ class ZipArchive(Archive):
     def _get_checksums(self, path):
         try:
             archive = zipfile.ZipFile(_to_native_ascii(path), "r")
-            checksums = set((info.filename, info.CRC) for info in archive.infolist())
+            checksums = {(info.filename, info.CRC) for info in archive.infolist()}
             archive.close()
         except BadZipFile:
             checksums = set()
@@ -558,11 +557,11 @@ class TarArchive(Archive):
             if self.format == "xz":
                 with lzma.open(_to_native_ascii(path), "r") as f:
                     archive = tarfile.open(fileobj=f)
-                    checksums = set((info.name, info.chksum) for info in archive.getmembers())
+                    checksums = {(info.name, info.chksum) for info in archive.getmembers()}
                     archive.close()
             else:
                 archive = tarfile.open(_to_native_ascii(path), f"r|{self.format}")
-                checksums = set((info.name, info.chksum) for info in archive.getmembers())
+                checksums = {(info.name, info.chksum) for info in archive.getmembers()}
                 archive.close()
         except (LZMAError, tarfile.ReadError, tarfile.CompressionError):
             try:
@@ -575,7 +574,7 @@ class TarArchive(Archive):
                     if not chunk:
                         break
                     checksum = crc32(chunk, checksum)
-                checksums = set([(b"", checksum)])
+                checksums = {(b"", checksum)}
                 f.close()
             except Exception:
                 checksums = set()
