@@ -1,13 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright (c) Ansible project
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
-
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: github_deploy_key
@@ -28,7 +25,6 @@ options:
   github_url:
     description:
       - The base URL of the GitHub API.
-    required: false
     type: str
     version_added: '0.2.0'
     default: https://api.github.com
@@ -57,8 +53,8 @@ options:
     type: str
   read_only:
     description:
-      - If V(true), the deploy key will only be able to read repository contents. Otherwise, the deploy key will be able to
-        read and write.
+      - If V(true), the deploy key is only able to read repository contents. Otherwise, the deploy key is able to read and
+        write.
     type: bool
     default: true
   state:
@@ -181,42 +177,43 @@ id:
   sample: 24381901
 """
 
-from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.urls import fetch_url
 from re import findall
 
+from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.urls import fetch_url
 
-class GithubDeployKey(object):
+
+class GithubDeployKey:
     def __init__(self, module):
         self.module = module
 
-        self.github_url = self.module.params['github_url']
-        self.name = module.params['name']
-        self.key = module.params['key']
-        self.state = module.params['state']
-        self.read_only = module.params.get('read_only', True)
-        self.force = module.params.get('force', False)
-        self.username = module.params.get('username', None)
-        self.password = module.params.get('password', None)
-        self.token = module.params.get('token', None)
-        self.otp = module.params.get('otp', None)
+        self.github_url = self.module.params["github_url"]
+        self.name = module.params["name"]
+        self.key = module.params["key"]
+        self.state = module.params["state"]
+        self.read_only = module.params.get("read_only", True)
+        self.force = module.params.get("force", False)
+        self.username = module.params.get("username", None)
+        self.password = module.params.get("password", None)
+        self.token = module.params.get("token", None)
+        self.otp = module.params.get("otp", None)
 
     @property
     def url(self):
-        owner = self.module.params['owner']
-        repo = self.module.params['repo']
-        return "{0}/repos/{1}/{2}/keys".format(self.github_url, owner, repo)
+        owner = self.module.params["owner"]
+        repo = self.module.params["repo"]
+        return f"{self.github_url}/repos/{owner}/{repo}/keys"
 
     @property
     def headers(self):
         if self.username is not None and self.password is not None:
-            self.module.params['url_username'] = self.username
-            self.module.params['url_password'] = self.password
-            self.module.params['force_basic_auth'] = True
+            self.module.params["url_username"] = self.username
+            self.module.params["url_password"] = self.password
+            self.module.params["force_basic_auth"] = True
             if self.otp is not None:
                 return {"X-GitHub-OTP": self.otp}
         elif self.token is not None:
-            return {"Authorization": "token {0}".format(self.token)}
+            return {"Authorization": f"token {self.token}"}
         else:
             return None
 
@@ -228,10 +225,10 @@ class GithubDeployKey(object):
                 yield self.module.from_json(resp.read())
 
                 links = {}
-                for x, y in findall(r'<([^>]+)>;\s*rel="(\w+)"', info.get("link", '')):
+                for x, y in findall(r'<([^>]+)>;\s*rel="(\w+)"', info.get("link", "")):
                     links[y] = x
 
-                url = links.get('next')
+                url = links.get("next")
             else:
                 self.handle_error(method="GET", info=info)
 
@@ -242,7 +239,7 @@ class GithubDeployKey(object):
                     existing_key_id = str(i["id"])
                     if i["key"].split() == self.key.split()[:2]:
                         return existing_key_id
-                    elif i['title'] == self.name and self.force:
+                    elif i["title"] == self.name and self.force:
                         return existing_key_id
             else:
                 return None
@@ -250,7 +247,14 @@ class GithubDeployKey(object):
     def add_new_key(self):
         request_body = {"title": self.name, "key": self.key, "read_only": self.read_only}
 
-        resp, info = fetch_url(self.module, self.url, data=self.module.jsonify(request_body), headers=self.headers, method="POST", timeout=30)
+        resp, info = fetch_url(
+            self.module,
+            self.url,
+            data=self.module.jsonify(request_body),
+            headers=self.headers,
+            method="POST",
+            timeout=30,
+        )
 
         status_code = info["status"]
 
@@ -269,61 +273,64 @@ class GithubDeployKey(object):
             self.handle_error(method="POST", info=info)
 
     def remove_existing_key(self, key_id):
-        resp, info = fetch_url(self.module, "{0}/{1}".format(self.url, key_id), headers=self.headers, method="DELETE")
+        resp, info = fetch_url(self.module, f"{self.url}/{key_id}", headers=self.headers, method="DELETE")
 
         status_code = info["status"]
 
         if status_code == 204:
-            if self.state == 'absent':
+            if self.state == "absent":
                 self.module.exit_json(changed=True, msg="Deploy key successfully deleted", id=key_id)
         else:
             self.handle_error(method="DELETE", info=info, key_id=key_id)
 
     def handle_error(self, method, info, key_id=None):
-        status_code = info['status']
-        body = info.get('body')
+        status_code = info["status"]
+        body = info.get("body")
         if body:
-            err = self.module.from_json(body)['message']
+            err = self.module.from_json(body)["message"]
+        else:
+            err = None
 
         if status_code == 401:
-            self.module.fail_json(msg="Failed to connect to {0} due to invalid credentials".format(self.github_url), http_status_code=status_code, error=err)
+            self.module.fail_json(
+                msg=f"Failed to connect to {self.github_url} due to invalid credentials",
+                http_status_code=status_code,
+                error=err,
+            )
         elif status_code == 404:
             self.module.fail_json(msg="GitHub repository does not exist", http_status_code=status_code, error=err)
         else:
             if method == "GET":
-                self.module.fail_json(msg="Failed to retrieve existing deploy keys", http_status_code=status_code, error=err)
+                self.module.fail_json(
+                    msg="Failed to retrieve existing deploy keys", http_status_code=status_code, error=err
+                )
             elif method == "POST":
                 self.module.fail_json(msg="Failed to add deploy key", http_status_code=status_code, error=err)
             elif method == "DELETE":
-                self.module.fail_json(msg="Failed to delete existing deploy key", id=key_id, http_status_code=status_code, error=err)
+                self.module.fail_json(
+                    msg="Failed to delete existing deploy key", id=key_id, http_status_code=status_code, error=err
+                )
 
 
 def main():
     module = AnsibleModule(
         argument_spec=dict(
-            github_url=dict(required=False, type='str', default="https://api.github.com"),
-            owner=dict(required=True, type='str', aliases=['account', 'organization']),
-            repo=dict(required=True, type='str', aliases=['repository']),
-            name=dict(required=True, type='str', aliases=['title', 'label']),
-            key=dict(required=True, type='str', no_log=False),
-            read_only=dict(required=False, type='bool', default=True),
-            state=dict(default='present', choices=['present', 'absent']),
-            force=dict(required=False, type='bool', default=False),
-            username=dict(required=False, type='str'),
-            password=dict(required=False, type='str', no_log=True),
-            otp=dict(required=False, type='int', no_log=True),
-            token=dict(required=False, type='str', no_log=True)
+            github_url=dict(type="str", default="https://api.github.com"),
+            owner=dict(required=True, type="str", aliases=["account", "organization"]),
+            repo=dict(required=True, type="str", aliases=["repository"]),
+            name=dict(required=True, type="str", aliases=["title", "label"]),
+            key=dict(required=True, type="str", no_log=False),
+            read_only=dict(type="bool", default=True),
+            state=dict(default="present", choices=["present", "absent"]),
+            force=dict(type="bool", default=False),
+            username=dict(type="str"),
+            password=dict(type="str", no_log=True),
+            otp=dict(type="int", no_log=True),
+            token=dict(type="str", no_log=True),
         ),
-        mutually_exclusive=[
-            ['password', 'token']
-        ],
-        required_together=[
-            ['username', 'password'],
-            ['otp', 'username', 'password']
-        ],
-        required_one_of=[
-            ['username', 'token']
-        ],
+        mutually_exclusive=[["password", "token"]],
+        required_together=[["username", "password"], ["otp", "username", "password"]],
+        required_one_of=[["username", "token"]],
         supports_check_mode=True,
     )
 
@@ -337,17 +344,17 @@ def main():
             module.exit_json(changed=False)
 
     # to forcefully modify an existing key, the existing key must be deleted first
-    if deploy_key.state == 'absent' or deploy_key.force:
+    if deploy_key.state == "absent" or deploy_key.force:
         key_id = deploy_key.get_existing_key()
 
         if key_id is not None:
             deploy_key.remove_existing_key(key_id)
-        elif deploy_key.state == 'absent':
+        elif deploy_key.state == "absent":
             module.exit_json(changed=False, msg="Deploy key does not exist")
 
     if deploy_key.state == "present":
         deploy_key.add_new_key()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
