@@ -137,16 +137,16 @@ issue:
   type: dict
 """
 
-from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.api import basic_auth_argument_spec
+from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.common.text.converters import to_text
 
 from ansible_collections.community.general.plugins.module_utils.gitlab import (
     auth_argument_spec,
-    gitlab_authentication,
-    gitlab,
-    find_project,
     find_group,
+    find_project,
+    gitlab,
+    gitlab_authentication,
 )
 
 
@@ -358,7 +358,7 @@ def main():
             try:
                 with open(description_path, "rb") as f:
                     description = to_text(f.read(), errors="surrogate_or_strict")
-            except IOError as e:
+            except OSError as e:
                 module.fail_json(msg=f"Cannot open {description_path}: {e}")
 
         # sorting necessary in order to properly detect changes, as we don't want to get false positive
