@@ -163,8 +163,8 @@ from ansible.module_utils.basic import AnsibleModule
 
 from ansible_collections.community.general.plugins.module_utils.gitlab import (
     auth_argument_spec,
-    gitlab_authentication,
     gitlab,
+    gitlab_authentication,
 )
 
 
@@ -205,10 +205,7 @@ class GitLabProjectMembers:
 
     # check if the user is a member of the project
     def is_user_a_member(self, members, gitlab_user_id):
-        for member in members:
-            if member.id == gitlab_user_id:
-                return True
-        return False
+        return any(member.id == gitlab_user_id for member in members)
 
     # add user to a project
     def add_member_to_project(self, gitlab_user_id, gitlab_project_id, access_level):
