@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright 2014 Benjamin Curtis <benjamin.curtis@gmail.com>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: honeybadger_deployment
@@ -70,19 +68,17 @@ EXAMPLES = r"""
 RETURN = """#"""
 
 import traceback
+from urllib.parse import urlencode
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.six.moves.urllib.parse import urlencode
-from ansible.module_utils.common.text.converters import to_native
 from ansible.module_utils.urls import fetch_url
 
-
 # ===========================================
 # Module execution.
 #
 
-def main():
 
+def main():
     module = AnsibleModule(
         argument_spec=dict(
             token=dict(required=True, no_log=True),
@@ -90,10 +86,10 @@ def main():
             user=dict(required=False),
             repo=dict(),
             revision=dict(),
-            url=dict(default='https://api.honeybadger.io/v1/deploys'),
-            validate_certs=dict(default=True, type='bool'),
+            url=dict(default="https://api.honeybadger.io/v1/deploys"),
+            validate_certs=dict(default=True, type="bool"),
         ),
-        supports_check_mode=True
+        supports_check_mode=True,
     )
 
     params = {}
@@ -112,7 +108,7 @@ def main():
 
     params["api_key"] = module.params["token"]
 
-    url = module.params.get('url')
+    url = module.params.get("url")
 
     # If we're in check mode, just exit pretending like we succeeded
     if module.check_mode:
@@ -122,13 +118,13 @@ def main():
         data = urlencode(params)
         response, info = fetch_url(module, url, data=data)
     except Exception as e:
-        module.fail_json(msg='Unable to notify Honeybadger: %s' % to_native(e), exception=traceback.format_exc())
+        module.fail_json(msg=f"Unable to notify Honeybadger: {e}", exception=traceback.format_exc())
     else:
-        if info['status'] == 201:
+        if info["status"] == 201:
             module.exit_json(changed=True)
         else:
-            module.fail_json(msg="HTTP result code: %d connecting to %s" % (info['status'], url))
+            module.fail_json(msg=f"HTTP result code: {info['status']} connecting to {url}")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
