@@ -5,7 +5,6 @@
 
 from __future__ import annotations
 
-
 DOCUMENTATION = r"""
 module: imc_rest
 short_description: Manage Cisco IMC hardware through its REST API
@@ -398,7 +397,7 @@ def main():
         if content:
             rawdata = content.replace("\n", "")
         elif file_exists:
-            with open(path, "r") as config_object:
+            with open(path) as config_object:
                 rawdata = config_object.read().replace("\n", "")
 
         # Wrap the XML documents in a <root> element
