@@ -7,7 +7,6 @@
 
 from __future__ import annotations
 
-
 DOCUMENTATION = r"""
 module: influxdb_user
 short_description: Manage InfluxDB users
@@ -102,9 +101,9 @@ RETURN = r"""#"""
 
 import json
 
-from ansible.module_utils.urls import ConnectionError
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.common.text.converters import to_native
+from ansible.module_utils.urls import ConnectionError
+
 import ansible_collections.community.general.plugins.module_utils.influxdb as influx
 
 
@@ -118,7 +117,7 @@ def find_user(module, client, user_name):
                 user_result = user
                 break
     except ConnectionError as e:
-        module.fail_json(msg=to_native(e))
+        module.fail_json(msg=f"{e}")
     return user_result
 
 
@@ -130,7 +129,7 @@ def check_user_password(module, client, user_name, user_password):
         if e.code == 401:
             return False
     except ConnectionError as e:
-        module.fail_json(msg=to_native(e))
+        module.fail_json(msg=f"{e}")
     finally:
         # restore previous user
         client.switch_user(module.params["username"], module.params["password"])
@@ -142,7 +141,7 @@ def set_user_password(module, client, user_name, user_password):
         try:
             client.set_user_password(user_name, user_password)
         except ConnectionError as e:
-            module.fail_json(msg=to_native(e))
+            module.fail_json(msg=f"{e}")
 
 
 def create_user(module, client, user_name, user_password, admin):
@@ -150,7 +149,7 @@ def create_user(module, client, user_name, user_password, admin):
         try:
             client.create_user(user_name, user_password, admin)
         except ConnectionError as e:
-            module.fail_json(msg=to_native(e))
+            module.fail_json(msg=f"{e}")
 
 
 def drop_user(module, client, user_name):
@@ -176,7 +175,7 @@ def set_user_grants(module, client, user_name, grants):
     try:
         parsed_grants = []
         # Fix privileges wording
-        for i, v in enumerate(current_grants):
+        for v in current_grants:
             if v["privilege"] != "NO PRIVILEGES":
                 if v["privilege"] == "ALL PRIVILEGES":
                     v["privilege"] = "ALL"
@@ -234,12 +233,12 @@ def main():
                 msg = json.loads(e.content)
                 reason = msg["error"]
             except (KeyError, ValueError):
-                module.fail_json(msg=to_native(e))
+                module.fail_json(msg=f"{e}")
 
             if reason != INFLUX_AUTH_FIRST_USER_REQUIRED:
-                module.fail_json(msg=to_native(e))
+                module.fail_json(msg=f"{e}")
         else:
-            module.fail_json(msg=to_native(e))
+            module.fail_json(msg=f"{e}")
 
     changed = False
 
@@ -259,7 +258,7 @@ def main():
                         client.revoke_admin_privileges(user_name)
                     changed = True
             except influx.exceptions.InfluxDBClientError as e:
-                module.fail_json(msg=to_native(e))
+                module.fail_json(msg=f"{e}")
 
         else:
             user_password = user_password or ""
