@@ -6,7 +6,6 @@
 
 from __future__ import annotations
 
-
 DOCUMENTATION = r"""
 module: jenkins_plugin
 author: Jiri Tyr (@jtyr)
@@ -341,7 +340,7 @@ from http import cookiejar
 from urllib.parse import urlencode
 
 from ansible.module_utils.basic import AnsibleModule, to_bytes
-from ansible.module_utils.urls import fetch_url, url_argument_spec, basic_auth_header
+from ansible.module_utils.urls import basic_auth_header, fetch_url, url_argument_spec
 
 from ansible_collections.community.general.plugins.module_utils.jenkins import download_updates_file
 
@@ -688,7 +687,7 @@ class JenkinsPlugin:
                 with open(cache_path, "w") as f:
                     json.dump(plugin_data, f)
 
-            with open(cache_path, "r") as f:
+            with open(cache_path) as f:
                 plugin_data = json.load(f)
 
         except Exception as e:
@@ -759,7 +758,7 @@ class JenkinsPlugin:
 
             try:
                 os.close(tmp_update_fd)
-            except IOError as e:
+            except OSError as e:
                 self.module.fail_json(msg=f"Cannot close the tmp updates file {tmp_updates_file}.", details=f"{e}")
         else:
             tmp_updates_file = updates_file
@@ -771,7 +770,7 @@ class JenkinsPlugin:
             # Read only the second line
             dummy = f.readline()
             data = json.loads(f.readline())
-        except IOError as e:
+        except OSError as e:
             self.module.fail_json(
                 msg=f"Cannot open{' temporary' if tmp_updates_file != updates_file else ''} updates file.",
                 details=f"{e}",
@@ -808,7 +807,7 @@ class JenkinsPlugin:
 
         try:
             os.close(tmp_f_fd)
-        except IOError as e:
+        except OSError as e:
             self.module.fail_json(msg=f"Cannot close the temporal plugin file {tmp_f}.", details=f"{e}")
 
         # Move the file onto the right place
