@@ -1,13 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 # Copyright (c) 2017, Daniel Korn <korndaniel1@gmail.com>
 # Copyright (c) 2017, Yaacov Zamir <yzamir@redhat.com>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
-
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: manageiq_policies
@@ -45,8 +42,21 @@ options:
     description:
       - The type of the resource to which the profile should be [un]assigned.
     required: true
-    choices: ['provider', 'host', 'vm', 'blueprint', 'category', 'cluster', 'data store', 'group', 'resource pool', 'service',
-      'service template', 'template', 'tenant', 'user']
+    choices:
+      - provider
+      - host
+      - vm
+      - blueprint
+      - category
+      - cluster
+      - data store
+      - group
+      - resource pool
+      - service
+      - service template
+      - template
+      - tenant
+      - user
   resource_name:
     type: str
     description:
@@ -89,52 +99,56 @@ EXAMPLES = r"""
 
 RETURN = r"""
 manageiq_policies:
-    description:
-      - List current policy_profile and policies for a provider in ManageIQ.
-    returned: always
-    type: dict
-    sample: {
-        "changed": false,
-        "profiles": [
+  description:
+    - List current policy_profile and policies for a provider in ManageIQ.
+  returned: always
+  type: dict
+  sample:
+    {
+      "changed": false,
+      "profiles": [
+        {
+          "policies": [
             {
-                "policies": [
-                    {
-                        "active": true,
-                        "description": "OpenSCAP",
-                        "name": "openscap policy"
-                    },
-                    {
-                        "active": true,
-                        "description": "Analyse incoming container images",
-                        "name": "analyse incoming container images"
-                    },
-                    {
-                        "active": true,
-                        "description": "Schedule compliance after smart state analysis",
-                        "name": "schedule compliance after smart state analysis"
-                    }
-                ],
-                "profile_description": "OpenSCAP profile",
-                "profile_name": "openscap profile"
+              "active": true,
+              "description": "OpenSCAP",
+              "name": "openscap policy"
+            },
+            {
+              "active": true,
+              "description": "Analyse incoming container images",
+              "name": "analyse incoming container images"
+            },
+            {
+              "active": true,
+              "description": "Schedule compliance after smart state analysis",
+              "name": "schedule compliance after smart state analysis"
             }
-        ]
+          ],
+          "profile_description": "OpenSCAP profile",
+          "profile_name": "openscap profile"
+        }
+      ]
     }
 """
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.general.plugins.module_utils.manageiq import ManageIQ, manageiq_argument_spec, manageiq_entities
+
+from ansible_collections.community.general.plugins.module_utils.manageiq import (
+    ManageIQ,
+    manageiq_argument_spec,
+    manageiq_entities,
+)
 
 
 def main():
-    actions = {'present': 'assign', 'absent': 'unassign'}
+    actions = {"present": "assign", "absent": "unassign"}
     argument_spec = dict(
-        policy_profiles=dict(type='list', elements='dict'),
-        resource_id=dict(type='int'),
-        resource_name=dict(type='str'),
-        resource_type=dict(required=True, type='str',
-                           choices=list(manageiq_entities().keys())),
-        state=dict(required=False, type='str',
-                   choices=['present', 'absent'], default='present'),
+        policy_profiles=dict(type="list", elements="dict"),
+        resource_id=dict(type="int"),
+        resource_name=dict(type="str"),
+        resource_type=dict(required=True, type="str", choices=list(manageiq_entities().keys())),
+        state=dict(type="str", choices=["present", "absent"], default="present"),
     )
     # add the manageiq connection arguments to the arguments
     argument_spec.update(manageiq_argument_spec())
@@ -143,17 +157,14 @@ def main():
         argument_spec=argument_spec,
         mutually_exclusive=[["resource_id", "resource_name"]],
         required_one_of=[["resource_id", "resource_name"]],
-        required_if=[
-            ('state', 'present', ['policy_profiles']),
-            ('state', 'absent', ['policy_profiles'])
-        ],
+        required_if=[("state", "present", ["policy_profiles"]), ("state", "absent", ["policy_profiles"])],
     )
 
-    policy_profiles = module.params['policy_profiles']
-    resource_id = module.params['resource_id']
-    resource_type_key = module.params['resource_type']
-    resource_name = module.params['resource_name']
-    state = module.params['state']
+    policy_profiles = module.params["policy_profiles"]
+    resource_id = module.params["resource_id"]
+    resource_type_key = module.params["resource_type"]
+    resource_name = module.params["resource_name"]
+    state = module.params["state"]
 
     # get the action and resource type
     action = actions[state]
