@@ -108,9 +108,8 @@ memset_api:
 """
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.general.plugins.module_utils.memset import check_zone
-from ansible_collections.community.general.plugins.module_utils.memset import get_zone_id
-from ansible_collections.community.general.plugins.module_utils.memset import memset_api_call
+
+from ansible_collections.community.general.plugins.module_utils.memset import check_zone, get_zone_id, memset_api_call
 
 
 def api_validation(args=None):
