@@ -10,9 +10,14 @@ __metaclass__ = type
 import sys
 
 from ansible.module_utils.common.text.converters import to_native
-from ansible.module_utils.six.moves.urllib.error import HTTPError
 from ansible.module_utils.urls import fetch_url, open_url
 
+try:
+    from urllib.error import HTTPError
+except ImportError:
+    # Python 2.x fallback:
+    from urllib2 import HTTPError
+
 import json
 import time
 
@@ -33,6 +38,12 @@ _ROBOT_DEFAULT_ARGUMENT_SPEC_COMPAT = dict(
     hetzner_password=dict(type='str', required=False, no_log=True),
 )
 
+_ROBOT_DEFAULT_ARGUMENT_SPEC_COMPAT_DEPRECATED = dict(
+    hetzner_user=dict(type='str', required=False, removed_in_version="3.0.0", removed_from_collection="community.hrobot"),
+    hetzner_password=dict(type='str', required=False, no_log=True, removed_in_version="3.0.0", removed_from_collection="community.hrobot"),
+)
+
+
 # The API endpoint is fixed.
 BASE_URL = "https://robot-ws.your-server.de"
 
