@@ -57,7 +57,7 @@ def load_mongocnf():
     mongocnf = os.path.expanduser('~/.mongodb.cnf')
 
     try:
-        config.readfp(open(mongocnf))
+        config.read_file(open(mongocnf))
     except (configparser.NoOptionError, IOError):
         return False
 
@@ -291,8 +291,12 @@ def is_auth_enabled(module):
         connection_params = rename_ssl_option_for_pymongo4(connection_params)
     try:
         myclient = MongoClient(**connection_params)
-        myclient['admin'].command('listDatabases', 1.0)
-        auth_is_enabled = False
+        hello_response = myclient.admin.command('hello')
+        if 'arbiterOnly' in hello_response and hello_response['arbiterOnly']:
+            auth_is_enabled = False  # Arbiters cannot login with a user
+        else:
+            myclient['admin'].command('listDatabases', 1.0)
+            auth_is_enabled = False
     except Exception as excep:
         if hasattr(excep, 'code') and excep.code in [13]:
             auth_is_enabled = True
@@ -396,7 +400,7 @@ def member_dicts_different(conf, member_config):
         "priority": {"nonarbiter": 1.0, "arbiter": 0},
         "tags": {},
         "horizons": {},
-        "secondardDelaySecs": 0,
+        "secondaryDelaySecs": 0,
         "votes": 1
     }
     different = False
