@@ -70,7 +70,7 @@ options:
     type: str
   size:
     description:
-      - Desired volume size in GB to allocate when O(state=present) (specify O(size) without suffix).
+      - Desired volume size in GiB to allocate when O(state=present) (specify O(size) without suffix).
       - New (or additional) size of volume when O(state=resized). With the V(+) sign the value is added to the actual size
         of the volume and without it, the value is taken as an absolute one.
     type: str
@@ -163,6 +163,7 @@ options:
       - Import volume from this existing one.
       - Volume string format.
       - V(<STORAGE>:<VMID>/<FULL_NAME>) or V(<ABSOLUTE_PATH>/<FULL_NAME>).
+      - V(<STORAGE>:import/<FULL_NAME>) for PVE 9.x and later, to use storage's import directory.
       - Attention! Only root can use absolute paths.
       - This parameter is mutually exclusive with O(size).
       - Increase O(timeout) parameter when importing large disk images or using slow storage.
