@@ -124,7 +124,7 @@ options:
           - Required when O(backings[].backing_type=file).
         type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 author:
   - Anusha Hegde (@anusha94)
 '''
@@ -214,7 +214,7 @@ serial_port_data:
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, wait_for_task
-from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 from ansible.module_utils.common.text.converters import to_native
 try:
     from pyVmomi import vim
