@@ -52,7 +52,7 @@ options:
     - This parameter is required if O(esxi_hostname) is not specified.
     type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -69,6 +69,18 @@ EXAMPLES = r'''
     ad_state: present
   delegate_to: localhost
 
+- name: Join an AD domain in a specific OU
+  community.vmware.vmware_host_active_directory:
+    hostname: '{{ vcenter_hostname }}'
+    username: '{{ vcenter_username }}'
+    password: '{{ vcenter_password }}'
+    esxi_hostname: '{{ esxi_hostname }}'
+    ad_domain: "example.local/Some-OU/Some-SubOU/"
+    ad_user: adjoin
+    ad_password: Password123$
+    ad_state: present
+  delegate_to: localhost
+
 - name: Leave AD domain
   community.vmware.vmware_host_active_directory:
     hostname: '{{ vcenter_hostname }}'
@@ -104,8 +116,8 @@ except ImportError:
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, TaskError, wait_for_task
-from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
-from ansible.module_utils._text import to_native
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VmwareHostAdAuthentication(PyVmomi):
