@@ -84,7 +84,7 @@ options:
       default: 3600
       version_added: '3.4.0'
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -165,20 +165,20 @@ datastore:
 '''
 
 try:
-    from pyVmomi import vim, VmomiSupport
+    from pyVmomi import vim, VmomiJSONEncoder
 except ImportError:
     pass
 
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     PyVmomi, find_hostsystem_by_name,
     find_vm_by_id, find_datastore_by_name,
-    find_resource_pool_by_name,
+    find_resource_pool_by_cluster,
     find_datacenter_by_name,
     find_cluster_by_name, get_all_objs,
     wait_for_task, TaskError)
-from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class VmotionManager(PyVmomi):
@@ -392,8 +392,8 @@ class VmotionManager(PyVmomi):
         dest_resourcepool = self.params.get('destination_resourcepool', None)
         self.resourcepool_object = None
         if dest_resourcepool:
-            self.resourcepool_object = find_resource_pool_by_name(content=self.content,
-                                                                  resource_pool_name=dest_resourcepool)
+            self.resourcepool_object = find_resource_pool_by_cluster(content=self.content,
+                                                                     resource_pool_name=dest_resourcepool)
             if self.resourcepool_object is None:
                 self.module.fail_json(msg="Unable to find destination resource pool object for %s" % dest_resourcepool)
         elif not dest_resourcepool and self.host_object:
@@ -511,7 +511,7 @@ class VmotionManager(PyVmomi):
                     vms.append(temp_vm_object.obj)
                     break
         elif self.moid:
-            vm_obj = VmomiSupport.templateOf('VirtualMachine')(self.moid, self.si._stub)
+            vm_obj = VmomiJSONEncoder.templateOf('VirtualMachine')(self.moid, self.si._stub)
             if vm_obj:
                 vms.append(vm_obj)
 
