@@ -16,7 +16,6 @@ short_description: Filters for remote system server.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "1.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -102,14 +101,15 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            exclude-list:
+            exclude_list:
+                aliases: ['exclude-list']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to exclude_list.
+                description: Exclude list.
                 suboptions:
                     category:
                         type: str
-                        description: No description.
+                        description: Category.
                         choices:
                             - 'app-ctrl'
                             - 'attack'
@@ -126,33 +126,35 @@ options:
                     fields:
                         type: list
                         elements: dict
-                        description: No description.
+                        description: Fields.
                         suboptions:
                             args:
                                 type: raw
-                                description: (list) No description.
+                                description: (list) Args.
                             field:
                                 type: str
-                                description: No description.
+                                description: Field.
                             negate:
                                 type: str
-                                description: No description.
+                                description: Negate.
                                 choices:
                                     - 'disable'
                                     - 'enable'
                     id:
                         type: int
-                        description: No description.
-            forward-traffic:
+                        description: Id.
+            forward_traffic:
+                aliases: ['forward-traffic']
                 type: str
-                description: Deprecated, please rename it to forward_traffic. Enable/disable forward traffic logging.
+                description: Enable/disable forward traffic logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            free-style:
+            free_style:
+                aliases: ['free-style']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to free_style.
+                description: Free style.
                 suboptions:
                     category:
                         type: str
@@ -177,12 +179,14 @@ options:
                             - 'icap'
                             - 'ztna'
                             - 'virtual-patch'
+                            - 'debug'
                     filter:
                         type: str
                         description: Free style filter string.
-                    filter-type:
+                    filter_type:
+                        aliases: ['filter-type']
                         type: str
-                        description: Deprecated, please rename it to filter_type. Include/exclude logs that match the filter.
+                        description: Include/exclude logs that match the filter.
                         choices:
                             - 'include'
                             - 'exclude'
@@ -195,21 +199,24 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            local-traffic:
+            local_traffic:
+                aliases: ['local-traffic']
                 type: str
-                description: Deprecated, please rename it to local_traffic. Enable/disable local in or out traffic logging.
+                description: Enable/disable local in or out traffic logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            multicast-traffic:
+            multicast_traffic:
+                aliases: ['multicast-traffic']
                 type: str
-                description: Deprecated, please rename it to multicast_traffic. Enable/disable multicast traffic logging.
+                description: Enable/disable multicast traffic logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            sniffer-traffic:
+            sniffer_traffic:
+                aliases: ['sniffer-traffic']
                 type: str
-                description: Deprecated, please rename it to sniffer_traffic. Enable/disable sniffer traffic logging.
+                description: Enable/disable sniffer traffic logging.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -219,15 +226,17 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            ztna-traffic:
+            ztna_traffic:
+                aliases: ['ztna-traffic']
                 type: str
-                description: Deprecated, please rename it to ztna_traffic. Enable/disable ztna traffic logging.
+                description: Enable/disable ztna traffic logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            filter-type:
+            filter_type:
+                aliases: ['filter-type']
                 type: str
-                description: Deprecated, please rename it to filter_type. Include/exclude logs that match the filter.
+                description: Include/exclude logs that match the filter.
                 choices:
                     - 'include'
                     - 'exclude'
@@ -236,13 +245,13 @@ options:
                 description: Syslog filter.
             cifs:
                 type: str
-                description: No description.
+                description: Cifs.
                 choices:
                     - 'disable'
                     - 'enable'
             ssl:
                 type: str
-                description: No description.
+                description: Ssl.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -258,21 +267,37 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            netscan-discovery:
+            netscan_discovery:
+                aliases: ['netscan-discovery']
                 type: str
-                description: Deprecated, please rename it to netscan_discovery. Enable/disable netscan discovery event logging.
+                description: Enable/disable netscan discovery event logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            netscan-vulnerability:
+            netscan_vulnerability:
+                aliases: ['netscan-vulnerability']
                 type: str
-                description: Deprecated, please rename it to netscan_vulnerability. Enable/disable netscan vulnerability event logging.
+                description: Enable/disable netscan vulnerability event logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            forti-switch:
+            forti_switch:
+                aliases: ['forti-switch']
                 type: str
-                description: Deprecated, please rename it to forti_switch. Enable/disable Forti-Switch logging.
+                description: Enable/disable Forti-Switch logging.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            http_transaction:
+                aliases: ['http-transaction']
+                type: str
+                description: Enable/disable log HTTP transaction messages.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            debug:
+                type: str
+                description: Enable/disable debug logging.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -282,6 +307,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -290,46 +316,45 @@ EXAMPLES = '''
     - name: Filters for remote system server.
       fortinet.fortimanager.fmgr_devprof_log_syslogd_filter:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         devprof: <your own value>
         devprof_log_syslogd_filter:
-          severity: <value in [emergency, alert, critical, ...]>
-          anomaly: <value in [disable, enable]>
-          exclude_list:
-            -
-              category: <value in [app-ctrl, attack, dlp, ...]>
-              fields:
-                -
-                  args: <list or string>
-                  field: <string>
-                  negate: <value in [disable, enable]>
-              id: <integer>
-          forward_traffic: <value in [disable, enable]>
-          free_style:
-            -
-              category: <value in [traffic, event, virus, ...]>
-              filter: <string>
-              filter_type: <value in [include, exclude]>
-              id: <integer>
-          gtp: <value in [disable, enable]>
-          local_traffic: <value in [disable, enable]>
-          multicast_traffic: <value in [disable, enable]>
-          sniffer_traffic: <value in [disable, enable]>
-          voip: <value in [disable, enable]>
-          ztna_traffic: <value in [disable, enable]>
-          filter_type: <value in [include, exclude]>
-          filter: <string>
-          cifs: <value in [disable, enable]>
-          ssl: <value in [disable, enable]>
-          dns: <value in [disable, enable]>
-          ssh: <value in [disable, enable]>
-          netscan_discovery: <value in [disable, enable]>
-          netscan_vulnerability: <value in [disable, enable]>
-          forti_switch: <value in [disable, enable]>
+          # severity: <value in [emergency, alert, critical, ...]>
+          # anomaly: <value in [disable, enable]>
+          # exclude_list:
+          #   - category: <value in [app-ctrl, attack, dlp, ...]>
+          #     fields:
+          #       - args: <list or string>
+          #         field: <string>
+          #         negate: <value in [disable, enable]>
+          #     id: <integer>
+          # forward_traffic: <value in [disable, enable]>
+          # free_style:
+          #   - category: <value in [traffic, event, virus, ...]>
+          #     filter: <string>
+          #     filter_type: <value in [include, exclude]>
+          #     id: <integer>
+          # gtp: <value in [disable, enable]>
+          # local_traffic: <value in [disable, enable]>
+          # multicast_traffic: <value in [disable, enable]>
+          # sniffer_traffic: <value in [disable, enable]>
+          # voip: <value in [disable, enable]>
+          # ztna_traffic: <value in [disable, enable]>
+          # filter_type: <value in [include, exclude]>
+          # filter: <string>
+          # cifs: <value in [disable, enable]>
+          # ssl: <value in [disable, enable]>
+          # dns: <value in [disable, enable]>
+          # ssh: <value in [disable, enable]>
+          # netscan_discovery: <value in [disable, enable]>
+          # netscan_vulnerability: <value in [disable, enable]>
+          # forti_switch: <value in [disable, enable]>
+          # http_transaction: <value in [disable, enable]>
+          # debug: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -373,21 +398,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/devprof/{devprof}/log/syslogd/filter'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/devprof/{devprof}/log/syslogd/filter/{filter}'
-    ]
-
     url_params = ['adom', 'devprof']
     module_primary_key = None
     module_arg_spec = {
@@ -402,68 +420,69 @@ def main():
                     'choices': ['emergency', 'alert', 'critical', 'error', 'warning', 'notification', 'information', 'debug'],
                     'type': 'str'
                 },
-                'anomaly': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'anomaly': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'exclude-list': {
-                    'v_range': [['7.0.4', '7.0.12']],
+                    'v_range': [['7.0.4', '7.0.15']],
                     'type': 'list',
                     'options': {
                         'category': {
-                            'v_range': [['7.0.4', '7.0.12']],
+                            'v_range': [['7.0.4', '7.0.15']],
                             'choices': [
                                 'app-ctrl', 'attack', 'dlp', 'event', 'traffic', 'virus', 'voip', 'webfilter', 'netscan', 'spam', 'anomaly', 'waf'
                             ],
                             'type': 'str'
                         },
                         'fields': {
-                            'v_range': [['7.0.4', '7.0.12']],
+                            'v_range': [['7.0.4', '7.0.15']],
                             'type': 'list',
                             'options': {
-                                'args': {'v_range': [['7.0.4', '7.0.12']], 'type': 'raw'},
-                                'field': {'v_range': [['7.0.4', '7.0.12']], 'type': 'str'},
-                                'negate': {'v_range': [['7.0.4', '7.0.12']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                                'args': {'v_range': [['7.0.4', '7.0.15']], 'type': 'raw'},
+                                'field': {'v_range': [['7.0.4', '7.0.15']], 'type': 'str'},
+                                'negate': {'v_range': [['7.0.4', '7.0.15']], 'choices': ['disable', 'enable'], 'type': 'str'}
                             },
                             'elements': 'dict'
                         },
-                        'id': {'v_range': [['7.0.4', '7.0.12']], 'type': 'int'}
+                        'id': {'v_range': [['7.0.4', '7.0.15']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
-                'forward-traffic': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'forward-traffic': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'free-style': {
-                    'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']],
+                    'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']],
                     'type': 'list',
                     'options': {
                         'category': {
-                            'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']],
+                            'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']],
                             'choices': [
                                 'traffic', 'event', 'virus', 'webfilter', 'attack', 'spam', 'voip', 'dlp', 'app-ctrl', 'anomaly', 'waf', 'gtp', 'dns',
-                                'ssh', 'ssl', 'file-filter', 'icap', 'ztna', 'virtual-patch'
+                                'ssh', 'ssl', 'file-filter', 'icap', 'ztna', 'virtual-patch', 'debug'
                             ],
                             'type': 'str'
                         },
-                        'filter': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'type': 'str'},
-                        'filter-type': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['include', 'exclude'], 'type': 'str'},
-                        'id': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'type': 'int'}
+                        'filter': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'type': 'str'},
+                        'filter-type': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['include', 'exclude'], 'type': 'str'},
+                        'id': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
-                'gtp': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'local-traffic': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'multicast-traffic': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'sniffer-traffic': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'voip': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'ztna-traffic': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'filter-type': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['include', 'exclude'], 'type': 'str'},
-                'filter': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'type': 'str'},
-                'cifs': {'v_range': [['7.0.4', '7.0.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'ssl': {'v_range': [['7.0.4', '7.0.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'dns': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'ssh': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'netscan-discovery': {'v_range': [['7.0.4', '7.0.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'netscan-vulnerability': {'v_range': [['7.0.4', '7.0.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'forti-switch': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'gtp': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'local-traffic': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'multicast-traffic': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'sniffer-traffic': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'voip': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ztna-traffic': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'filter-type': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['include', 'exclude'], 'type': 'str'},
+                'filter': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'type': 'str'},
+                'cifs': {'v_range': [['7.0.4', '7.0.15']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ssl': {'v_range': [['7.0.4', '7.0.15']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'dns': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '7.2.1'], ['7.4.8', '7.4.8']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ssh': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '7.2.1'], ['7.4.8', '7.4.8']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'netscan-discovery': {'v_range': [['7.0.4', '7.0.15']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'netscan-vulnerability': {'v_range': [['7.0.4', '7.0.15']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'forti-switch': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'http-transaction': {'v_range': [['7.4.8', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'debug': {'v_range': [['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -472,17 +491,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'devprof_log_syslogd_filter'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
