@@ -16,7 +16,6 @@ short_description: Configure DNS domain filter profiles.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "1.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -89,28 +91,32 @@ options:
         required: false
         type: dict
         suboptions:
-            block-action:
+            block_action:
+                aliases: ['block-action']
                 type: str
-                description: Deprecated, please rename it to block_action. Action to take for blocked domains.
+                description: Action to take for blocked domains.
                 choices:
                     - 'block'
                     - 'redirect'
                     - 'block-sevrfail'
-            block-botnet:
+            block_botnet:
+                aliases: ['block-botnet']
                 type: str
-                description: Deprecated, please rename it to block_botnet. Enable/disable blocking botnet C&C DNS lookups.
+                description: Enable/disable blocking botnet C&C DNS lookups.
                 choices:
                     - 'disable'
                     - 'enable'
             comment:
                 type: str
                 description: Comment.
-            external-ip-blocklist:
+            external_ip_blocklist:
+                aliases: ['external-ip-blocklist']
                 type: raw
-                description: (list or str) Deprecated, please rename it to external_ip_blocklist. One or more external IP block lists.
-            log-all-domain:
+                description: (list or str) One or more external IP block lists.
+            log_all_domain:
+                aliases: ['log-all-domain']
                 type: str
-                description: Deprecated, please rename it to log_all_domain. Enable/disable logging of all domains visited
+                description: Enable/disable logging of all domains visited
                 choices:
                     - 'disable'
                     - 'enable'
@@ -118,37 +124,44 @@ options:
                 type: str
                 description: Profile name.
                 required: true
-            redirect-portal:
+            redirect_portal:
+                aliases: ['redirect-portal']
                 type: str
-                description: Deprecated, please rename it to redirect_portal. IP address of the SDNS redirect portal.
-            safe-search:
+                description: IP address of the SDNS redirect portal.
+            safe_search:
+                aliases: ['safe-search']
                 type: str
-                description: Deprecated, please rename it to safe_search. Enable/disable Google, Bing, and YouTube safe search.
+                description: Enable/disable Google, Bing, and YouTube safe search.
                 choices:
                     - 'disable'
                     - 'enable'
-            sdns-domain-log:
+            sdns_domain_log:
+                aliases: ['sdns-domain-log']
                 type: str
-                description: Deprecated, please rename it to sdns_domain_log. Enable/disable domain filtering and botnet domain logging.
+                description: Enable/disable domain filtering and botnet domain logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            sdns-ftgd-err-log:
+            sdns_ftgd_err_log:
+                aliases: ['sdns-ftgd-err-log']
                 type: str
-                description: Deprecated, please rename it to sdns_ftgd_err_log. Enable/disable FortiGuard SDNS rating error logging.
+                description: Enable/disable FortiGuard SDNS rating error logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            youtube-restrict:
+            youtube_restrict:
+                aliases: ['youtube-restrict']
                 type: str
-                description: Deprecated, please rename it to youtube_restrict. Set safe search for YouTube restriction level.
+                description: Set safe search for YouTube restriction level.
                 choices:
                     - 'strict'
                     - 'moderate'
-            dns-translation:
+                    - 'none'
+            dns_translation:
+                aliases: ['dns-translation']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to dns_translation. Dns-Translation.
+                description: Dns translation.
                 suboptions:
                     dst:
                         type: str
@@ -168,9 +181,10 @@ options:
                         choices:
                             - 'disable'
                             - 'enable'
-                    addr-type:
+                    addr_type:
+                        aliases: ['addr-type']
                         type: str
-                        description: Deprecated, please rename it to addr_type. DNS translation type
+                        description: DNS translation type
                         choices:
                             - 'ipv4'
                             - 'ipv6'
@@ -183,31 +197,37 @@ options:
                     src6:
                         type: str
                         description: IPv6 address or subnet on the internal network to compare with the resolved address in DNS query replies.
-            redirect-portal6:
+            redirect_portal6:
+                aliases: ['redirect-portal6']
                 type: str
-                description: Deprecated, please rename it to redirect_portal6. IPv6 address of the SDNS redirect portal.
-            log-all-url:
+                description: IPv6 address of the SDNS redirect portal.
+            log_all_url:
+                aliases: ['log-all-url']
                 type: str
-                description: Deprecated, please rename it to log_all_url. Enable/disable log all URLs visited.
+                description: Enable/disable log all URLs visited.
                 choices:
                     - 'disable'
                     - 'enable'
-            sdns-url-log:
+            sdns_url_log:
+                aliases: ['sdns-url-log']
                 type: str
-                description: Deprecated, please rename it to sdns_url_log. Enable/disable logging of URL filtering and botnet domains.
+                description: Enable/disable logging of URL filtering and botnet domains.
                 choices:
                     - 'disable'
                     - 'enable'
-            domain-filter:
+            domain_filter:
+                aliases: ['domain-filter']
                 type: dict
-                description: Deprecated, please rename it to domain_filter.
+                description: Domain filter.
                 suboptions:
-                    domain-filter-table:
+                    domain_filter_table:
+                        aliases: ['domain-filter-table']
                         type: int
-                        description: Deprecated, please rename it to domain_filter_table. DNS domain filter table ID.
-            ftgd-dns:
+                        description: DNS domain filter table ID.
+            ftgd_dns:
+                aliases: ['ftgd-dns']
                 type: dict
-                description: Deprecated, please rename it to ftgd_dns.
+                description: Ftgd dns.
                 suboptions:
                     filters:
                         type: list
@@ -241,19 +261,29 @@ options:
                             - 'ftgd-disable'
             urlfilter:
                 type: dict
-                description: No description.
+                description: Urlfilter.
                 suboptions:
-                    urlfilter-table:
+                    urlfilter_table:
+                        aliases: ['urlfilter-table']
                         type: int
-                        description: Deprecated, please rename it to urlfilter_table. DNS URL filter table ID.
-            transparent-dns-database:
+                        description: DNS URL filter table ID.
+            transparent_dns_database:
+                aliases: ['transparent-dns-database']
                 type: raw
-                description: (list) Deprecated, please rename it to transparent_dns_database.
+                description: (list) Transparent DNS database zones.
+            strip_ech:
+                aliases: ['strip-ech']
+                type: str
+                description: Enable/disable removal of the encrypted client hello service parameter from supporting DNS RRs.
+                choices:
+                    - 'disable'
+                    - 'enable'
 '''
 
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -266,10 +296,10 @@ EXAMPLES = '''
         adom: ansible
         state: present
         dnsfilter_profile:
-          block-action: redirect
-          block-botnet: disable
+          block_action: redirect
+          block_botnet: disable
           comment: "ansible-test-comment"
-          log-all-domain: disable
+          log_all_domain: disable
           name: "ansible-test"
 
 - name: Gathering fortimanager facts
@@ -331,27 +361,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/dnsfilter/profile',
         '/pm/config/global/obj/dnsfilter/profile'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/dnsfilter/profile/{profile}',
-        '/pm/config/global/obj/dnsfilter/profile/{profile}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'dnsfilter_profile': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -366,7 +389,7 @@ def main():
                 'safe-search': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'sdns-domain-log': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'sdns-ftgd-err-log': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'youtube-restrict': {'choices': ['strict', 'moderate'], 'type': 'str'},
+                'youtube-restrict': {'choices': ['strict', 'moderate', 'none'], 'type': 'str'},
                 'dns-translation': {
                     'v_range': [['6.2.0', '']],
                     'type': 'list',
@@ -384,35 +407,44 @@ def main():
                     'elements': 'dict'
                 },
                 'redirect-portal6': {'v_range': [['6.2.0', '']], 'type': 'str'},
-                'log-all-url': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'sdns-url-log': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'domain-filter': {'type': 'dict', 'options': {'domain-filter-table': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'type': 'int'}}},
+                'log-all-url': {'v_range': [['6.2.0', '6.2.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'sdns-url-log': {'v_range': [['6.2.0', '6.2.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'domain-filter': {
+                    'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']],
+                    'type': 'dict',
+                    'options': {'domain-filter-table': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'type': 'int'}}
+                },
                 'ftgd-dns': {
+                    'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']],
                     'type': 'dict',
                     'options': {
                         'filters': {
-                            'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']],
+                            'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']],
                             'type': 'list',
                             'options': {
-                                'action': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'choices': ['monitor', 'block'], 'type': 'str'},
-                                'category': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'type': 'str'},
-                                'id': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'type': 'int'},
-                                'log': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                                'action': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'choices': ['monitor', 'block'], 'type': 'str'},
+                                'category': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'type': 'str'},
+                                'id': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'type': 'int'},
+                                'log': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
                             },
                             'elements': 'dict'
                         },
                         'options': {
-                            'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']],
+                            'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '']],
                             'type': 'list',
                             'choices': ['error-allow', 'ftgd-disable'],
                             'elements': 'str'
                         }
                     }
                 },
-                'urlfilter': {'type': 'dict', 'options': {'urlfilter-table': {'v_range': [['6.2.8', '6.2.12']], 'type': 'int'}}},
-                'transparent-dns-database': {'v_range': [['7.4.1', '']], 'type': 'raw'}
+                'urlfilter': {
+                    'v_range': [['6.2.8', '6.2.13']],
+                    'type': 'dict',
+                    'options': {'urlfilter-table': {'v_range': [['6.2.8', '6.2.13']], 'type': 'int'}}
+                },
+                'transparent-dns-database': {'v_range': [['7.4.1', '']], 'type': 'raw'},
+                'strip-ech': {'v_range': [['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -421,17 +453,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'dnsfilter_profile'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
