@@ -16,7 +16,6 @@ short_description: ADOM revision table.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -114,6 +113,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -122,19 +122,19 @@ EXAMPLES = '''
     - name: ADOM revision table.
       fortinet.fortimanager.fmgr_dvmdb_revision:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         dvmdb_revision:
-          created_by: <string>
-          created_time: <integer>
-          desc: <string>
-          locked: <integer>
-          name: <string>
-          version: <integer>
+          name: "your value" # Required variable, string
+          # created_by: <string>
+          # created_time: <integer>
+          # desc: <string>
+          # locked: <integer>
+          # version: <integer>
 '''
 
 RETURN = '''
