@@ -16,7 +16,6 @@ short_description: Configure IPv6 firewall addresses.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "1.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -180,6 +179,7 @@ options:
                             - 'mac'
                             - 'geography'
                             - 'route-tag'
+                            - 'wildcard'
                     uuid:
                         type: str
                         description: Uuid.
@@ -262,6 +262,9 @@ options:
                             - 'all'
                             - 'private'
                             - 'public'
+                    wildcard:
+                        type: str
+                        description: IPv6 address and wildcard netmask.
             end_ip:
                 aliases: ['end-ip']
                 type: str
@@ -363,6 +366,7 @@ options:
                     - 'mac'
                     - 'geography'
                     - 'route-tag'
+                    - 'wildcard'
             uuid:
                 type: str
                 description: Universally Unique Identifier
@@ -440,6 +444,9 @@ options:
                     - 'all'
                     - 'private'
                     - 'public'
+            wildcard:
+                type: str
+                description: IPv6 address and wildcard netmask.
 '''
 
 EXAMPLES = '''
@@ -560,7 +567,10 @@ def main():
                         'start-ip': {'type': 'str'},
                         'tags': {'type': 'raw'},
                         'template': {'type': 'str'},
-                        'type': {'choices': ['ipprefix', 'iprange', 'nsx', 'dynamic', 'fqdn', 'template', 'mac', 'geography', 'route-tag'], 'type': 'str'},
+                        'type': {
+                            'choices': ['ipprefix', 'iprange', 'nsx', 'dynamic', 'fqdn', 'template', 'mac', 'geography', 'route-tag', 'wildcard'],
+                            'type': 'str'
+                        },
                         'uuid': {'type': 'str'},
                         'visibility': {'choices': ['disable', 'enable'], 'type': 'str'},
                         'subnet-segment': {
@@ -584,8 +594,9 @@ def main():
                         'sdn-tag': {'v_range': [['7.2.1', '']], 'type': 'str'},
                         'tenant': {'v_range': [['7.2.1', '']], 'type': 'str'},
                         'route-tag': {'v_range': [['7.4.0', '']], 'type': 'int'},
-                        'filter': {'v_range': [['7.4.4', '7.4.7'], ['7.6.2', '']], 'type': 'str'},
-                        'sdn-addr-type': {'v_range': [['7.4.4', '7.4.7'], ['7.6.2', '']], 'choices': ['all', 'private', 'public'], 'type': 'str'}
+                        'filter': {'v_range': [['7.4.4', '7.4.8'], ['7.6.2', '']], 'type': 'str'},
+                        'sdn-addr-type': {'v_range': [['7.4.4', '7.4.8'], ['7.6.2', '']], 'choices': ['all', 'private', 'public'], 'type': 'str'},
+                        'wildcard': {'v_range': [['7.6.4', '']], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
@@ -618,10 +629,13 @@ def main():
                     'elements': 'dict'
                 },
                 'template': {'type': 'str'},
-                'type': {'choices': ['ipprefix', 'iprange', 'nsx', 'dynamic', 'fqdn', 'template', 'mac', 'geography', 'route-tag'], 'type': 'str'},
+                'type': {
+                    'choices': ['ipprefix', 'iprange', 'nsx', 'dynamic', 'fqdn', 'template', 'mac', 'geography', 'route-tag', 'wildcard'],
+                    'type': 'str'
+                },
                 'uuid': {'type': 'str'},
                 'visibility': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'tags': {'v_range': [['6.2.0', '6.4.15']], 'type': 'str'},
+                'tags': {'v_range': [['6.2.0', '6.4.15'], ['7.4.8', '7.4.8'], ['7.6.4', '']], 'type': 'str'},
                 'profile-list': {
                     'v_range': [['6.2.0', '6.2.13']],
                     'type': 'list',
@@ -639,8 +653,9 @@ def main():
                 'sdn-tag': {'v_range': [['7.2.1', '']], 'type': 'str'},
                 'tenant': {'v_range': [['7.2.1', '']], 'type': 'str'},
                 'route-tag': {'v_range': [['7.4.0', '']], 'type': 'int'},
-                'filter': {'v_range': [['7.4.4', '7.4.7'], ['7.6.2', '']], 'type': 'str'},
-                'sdn-addr-type': {'v_range': [['7.4.4', '7.4.7'], ['7.6.2', '']], 'choices': ['all', 'private', 'public'], 'type': 'str'}
+                'filter': {'v_range': [['7.4.4', '7.4.8'], ['7.6.2', '']], 'type': 'str'},
+                'sdn-addr-type': {'v_range': [['7.4.4', '7.4.8'], ['7.6.2', '']], 'choices': ['all', 'private', 'public'], 'type': 'str'},
+                'wildcard': {'v_range': [['7.6.4', '']], 'type': 'str'}
             }
         }
     }
