@@ -16,7 +16,6 @@ short_description: Policy package or folder.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -79,59 +78,69 @@ options:
             name:
                 type: str
                 description: Name.
-            obj ver:
+            obj_ver:
+                aliases: ['obj ver']
                 type: int
-                description: Deprecated, please rename it to obj_ver. Obj ver.
+                description: Obj ver.
             oid:
                 type: int
                 description: Oid.
-            package setting:
+            package_setting:
+                aliases: ['package setting']
                 type: dict
-                description: Deprecated, please rename it to package_setting. Package setting.
+                description: Package setting.
                 suboptions:
-                    central-nat:
+                    central_nat:
+                        aliases: ['central-nat']
                         type: str
-                        description: Deprecated, please rename it to central_nat. Central nat.
+                        description: Central nat.
                         choices:
                             - 'disable'
                             - 'enable'
-                    consolidated-firewall-mode:
+                    consolidated_firewall_mode:
+                        aliases: ['consolidated-firewall-mode']
                         type: str
-                        description: Deprecated, please rename it to consolidated_firewall_mode. Consolidated firewall mode.
+                        description: Consolidated firewall mode.
                         choices:
                             - 'disable'
                             - 'enable'
-                    fwpolicy-implicit-log:
+                    fwpolicy_implicit_log:
+                        aliases: ['fwpolicy-implicit-log']
                         type: str
-                        description: Deprecated, please rename it to fwpolicy_implicit_log. Fwpolicy implicit log.
+                        description: Fwpolicy implicit log.
                         choices:
                             - 'disable'
                             - 'enable'
-                    fwpolicy6-implicit-log:
+                    fwpolicy6_implicit_log:
+                        aliases: ['fwpolicy6-implicit-log']
                         type: str
-                        description: Deprecated, please rename it to fwpolicy6_implicit_log. Fwpolicy6 implicit log.
+                        description: Fwpolicy6 implicit log.
                         choices:
                             - 'disable'
                             - 'enable'
-                    inspection-mode:
+                    inspection_mode:
+                        aliases: ['inspection-mode']
                         type: str
-                        description: Deprecated, please rename it to inspection_mode. Inspection mode.
+                        description: Inspection mode.
                         choices:
                             - 'proxy'
                             - 'flow'
-                    ngfw-mode:
+                    ngfw_mode:
+                        aliases: ['ngfw-mode']
                         type: str
-                        description: Deprecated, please rename it to ngfw_mode. Ngfw mode.
+                        description: Ngfw mode.
                         choices:
                             - 'profile-based'
                             - 'policy-based'
-                    ssl-ssh-profile:
+                    ssl_ssh_profile:
+                        aliases: ['ssl-ssh-profile']
                         type: str
-                        description: Deprecated, please rename it to ssl_ssh_profile. Ssl ssh profile.
-            scope member:
+                        description: Ssl ssh profile.
+            scope_member:
+                aliases: ['scope member']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to scope_member. Scope member.
+                description: Scope member.
                 suboptions:
                     name:
                         type: str
@@ -145,70 +154,71 @@ options:
                 choices:
                     - 'pkg'
                     - 'folder'
-            package settings:
+            package_settings:
+                aliases: ['package settings']
                 type: dict
-                description: Deprecated, please rename it to package_settings. Package settings.
+                description: Package settings.
                 suboptions:
-                    central-nat:
+                    central_nat:
+                        aliases: ['central-nat']
                         type: str
                         description:
-                            - Deprecated, please rename it to central_nat.
                             - disable -
                             - enable -
                         choices:
                             - 'disable'
                             - 'enable'
-                    consolidated-firewall-mode:
+                    consolidated_firewall_mode:
+                        aliases: ['consolidated-firewall-mode']
                         type: str
                         description:
-                            - Deprecated, please rename it to consolidated_firewall_mode.
                             - For flow-based policy package.
                             - disable -
                             - enable -
                         choices:
                             - 'disable'
                             - 'enable'
-                    fwpolicy-implicit-log:
+                    fwpolicy_implicit_log:
+                        aliases: ['fwpolicy-implicit-log']
                         type: str
                         description:
-                            - Deprecated, please rename it to fwpolicy_implicit_log.
                             - disable -
                             - enable -
                         choices:
                             - 'disable'
                             - 'enable'
-                    fwpolicy6-implicit-log:
+                    fwpolicy6_implicit_log:
+                        aliases: ['fwpolicy6-implicit-log']
                         type: str
                         description:
-                            - Deprecated, please rename it to fwpolicy6_implicit_log.
                             - disable -
                             - enable -
                         choices:
                             - 'disable'
                             - 'enable'
-                    inspection-mode:
+                    inspection_mode:
+                        aliases: ['inspection-mode']
                         type: str
                         description:
-                            - Deprecated, please rename it to inspection_mode.
                             - proxy -
                             - flow -
                         choices:
                             - 'proxy'
                             - 'flow'
-                    ngfw-mode:
+                    ngfw_mode:
+                        aliases: ['ngfw-mode']
                         type: str
                         description:
-                            - Deprecated, please rename it to ngfw_mode.
                             - For flow-based policy package.
                             - profile-based -
                             - policy-based -
                         choices:
                             - 'profile-based'
                             - 'policy-based'
-                    policy-offload-level:
+                    policy_offload_level:
+                        aliases: ['policy-offload-level']
                         type: str
                         description:
-                            - Deprecated, please rename it to policy_offload_level.
                             - disable -
                             - default -
                             - dos-offload -
@@ -218,14 +228,16 @@ options:
                             - 'default'
                             - 'dos-offload'
                             - 'full-offload'
-                    ssl-ssh-profile:
+                    ssl_ssh_profile:
+                        aliases: ['ssl-ssh-profile']
                         type: str
-                        description: Deprecated, please rename it to ssl_ssh_profile. SSL-SSH profile required for NGFW-mode policy package.
+                        description: SSL-SSH profile required for NGFW-mode policy package.
 '''
 
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -287,21 +299,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/pkg/global'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/pkg/global/{global}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -332,25 +337,24 @@ def main():
                 'scope member': {'type': 'list', 'options': {'name': {'type': 'str'}, 'vdom': {'type': 'str'}}, 'elements': 'dict'},
                 'type': {'choices': ['pkg', 'folder'], 'type': 'str'},
                 'package settings': {
-                    'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'type': 'dict',
                     'options': {
-                        'central-nat': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'consolidated-firewall-mode': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'fwpolicy-implicit-log': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'fwpolicy6-implicit-log': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'inspection-mode': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['proxy', 'flow'], 'type': 'str'},
-                        'ngfw-mode': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['profile-based', 'policy-based'], 'type': 'str'},
+                        'central-nat': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'consolidated-firewall-mode': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'fwpolicy-implicit-log': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'fwpolicy6-implicit-log': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'inspection-mode': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['proxy', 'flow'], 'type': 'str'},
+                        'ngfw-mode': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['profile-based', 'policy-based'], 'type': 'str'},
                         'policy-offload-level': {
-                            'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']],
+                            'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                             'choices': ['disable', 'default', 'dos-offload', 'full-offload'],
                             'type': 'str'
                         },
-                        'ssl-ssh-profile': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'type': 'str'}
+                        'ssl-ssh-profile': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'type': 'str'}
                     }
                 }
             }
-
         }
     }
 
@@ -359,14 +363,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pm_pkg_global'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
