@@ -16,7 +16,6 @@ short_description: NPU DoS configurations.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.2.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -64,6 +63,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -80,21 +82,24 @@ options:
         required: false
         type: dict
         suboptions:
-            npu-dos-meter-mode:
+            npu_dos_meter_mode:
+                aliases: ['npu-dos-meter-mode']
                 type: str
-                description: Deprecated, please rename it to npu_dos_meter_mode. Set DoS meter NPU offloading mode.
+                description: Set DoS meter NPU offloading mode.
                 choices:
                     - 'local'
                     - 'global'
-            npu-dos-synproxy-mode:
+            npu_dos_synproxy_mode:
+                aliases: ['npu-dos-synproxy-mode']
                 type: str
-                description: Deprecated, please rename it to npu_dos_synproxy_mode. Set NPU DoS SYNPROXY mode.
+                description: Set NPU DoS SYNPROXY mode.
                 choices:
                     - 'synack2ack'
                     - 'pass-synack'
-            npu-dos-tpe-mode:
+            npu_dos_tpe_mode:
+                aliases: ['npu-dos-tpe-mode']
                 type: str
-                description: Deprecated, please rename it to npu_dos_tpe_mode. Enable/disable insertion of DoS meter ID to session table.
+                description: Enable/disable insertion of DoS meter ID to session table.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -104,6 +109,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -112,15 +118,15 @@ EXAMPLES = '''
     - name: NPU DoS configurations.
       fortinet.fortimanager.fmgr_system_npu_dosoptions:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         system_npu_dosoptions:
-          npu_dos_meter_mode: <value in [local, global]>
-          npu_dos_synproxy_mode: <value in [synack2ack, pass-synack]>
-          npu_dos_tpe_mode: <value in [disable, enable]>
+          # npu_dos_meter_mode: <value in [local, global]>
+          # npu_dos_synproxy_mode: <value in [synack2ack, pass-synack]>
+          # npu_dos_tpe_mode: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -164,36 +170,28 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/npu/dos-options',
         '/pm/config/global/obj/system/npu/dos-options'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/npu/dos-options/{dos-options}',
-        '/pm/config/global/obj/system/npu/dos-options/{dos-options}'
-    ]
-
     url_params = ['adom']
     module_primary_key = None
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_npu_dosoptions': {
             'type': 'dict',
-            'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']],
+            'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
             'options': {
-                'npu-dos-meter-mode': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['local', 'global'], 'type': 'str'},
-                'npu-dos-synproxy-mode': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['synack2ack', 'pass-synack'], 'type': 'str'},
-                'npu-dos-tpe-mode': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'npu-dos-meter-mode': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['local', 'global'], 'type': 'str'},
+                'npu-dos-synproxy-mode': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['synack2ack', 'pass-synack'], 'type': 'str'},
+                'npu-dos-tpe-mode': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -202,14 +200,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_npu_dosoptions'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
