@@ -16,7 +16,6 @@ short_description: Report estimated browse time settings
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -95,6 +94,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -103,13 +103,13 @@ EXAMPLES = '''
     - name: Report estimated browse time settings
       fortinet.fortimanager.fmgr_system_report_estbrowsetime:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_report_estbrowsetime:
-          max_read_time: <integer>
-          status: <value in [disable, enable]>
+          # max_read_time: <integer>
+          # status: <value in [disable, enable]>
 '''
 
 RETURN = '''
