@@ -16,7 +16,6 @@ short_description: FortiGuard Web Filter settings.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -64,6 +63,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -195,6 +197,14 @@ options:
                     value:
                         type: int
                         description: Traffic quota value.
+                    reset_frequency:
+                        aliases: ['reset-frequency']
+                        type: str
+                        description: Quota reset frequency
+                        choices:
+                            - 'daily'
+                            - 'weekly'
+                            - 'monthly'
             rate_crl_urls:
                 aliases: ['rate-crl-urls']
                 type: str
@@ -257,6 +267,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -265,8 +276,8 @@ EXAMPLES = '''
     - name: FortiGuard Web Filter settings.
       fortinet.fortimanager.fmgr_webfilter_profile_ftgdwf:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -303,6 +314,7 @@ EXAMPLES = '''
           #     type: <value in [time, traffic]>
           #     unit: <value in [B, KB, MB, ...]>
           #     value: <integer>
+          #     reset_frequency: <value in [daily, weekly, monthly]>
           # rate_crl_urls: <value in [disable, enable]>
           # rate_css_urls: <value in [disable, enable]>
           # rate_image_urls: <value in [disable, enable]>
@@ -370,6 +382,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'webfilter_profile_ftgdwf': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -409,7 +422,8 @@ def main():
                         'override-replacemsg': {'type': 'str'},
                         'type': {'choices': ['time', 'traffic'], 'type': 'str'},
                         'unit': {'choices': ['B', 'KB', 'MB', 'GB'], 'type': 'str'},
-                        'value': {'type': 'int'}
+                        'value': {'type': 'int'},
+                        'reset-frequency': {'v_range': [['7.4.8', '7.4.8']], 'choices': ['daily', 'weekly', 'monthly'], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
@@ -419,13 +433,13 @@ def main():
                 'rate-javascript-urls': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'category-override': {'v_range': [['6.2.0', '6.4.15']], 'type': 'str'},
                 'risk': {
-                    'v_range': [['7.6.2', '']],
+                    'v_range': [['7.4.8', '7.4.8'], ['7.6.2', '']],
                     'type': 'list',
                     'options': {
-                        'action': {'v_range': [['7.6.2', '']], 'choices': ['block', 'monitor'], 'type': 'str'},
-                        'id': {'v_range': [['7.6.2', '']], 'type': 'int'},
-                        'log': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'risk-level': {'v_range': [['7.6.2', '']], 'type': 'raw'}
+                        'action': {'v_range': [['7.4.8', '7.4.8'], ['7.6.2', '']], 'choices': ['block', 'monitor'], 'type': 'str'},
+                        'id': {'v_range': [['7.4.8', '7.4.8'], ['7.6.2', '']], 'type': 'int'},
+                        'log': {'v_range': [['7.4.8', '7.4.8'], ['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'risk-level': {'v_range': [['7.4.8', '7.4.8'], ['7.6.2', '']], 'type': 'raw'}
                     },
                     'elements': 'dict'
                 }
