@@ -102,6 +102,7 @@ options:
   hostvars_prefix:
     description:
       - The prefix for host variables names coming from Hetzner Cloud.
+    default: hcloud_
     type: str
     version_added: 2.5.0
   hostvars_suffix:
@@ -134,7 +135,7 @@ plugin: hetzner.hcloud.hcloud
 locations:
   - nbg1
 types:
-  - cx22
+  - cpx22
 status:
   - running
 
@@ -144,11 +145,11 @@ status:
 # and status with prefix e.g. "server_status_running"
 plugin: hetzner.hcloud.hcloud
 keyed_groups:
-  - key: location
+  - key: hcloud_location
     prefix: hcloud_location
   - key: image_os_flavor
     separator: ""
-  - key: status
+  - key: hcloud_status
     prefix: server_status
 
 ---
@@ -157,37 +158,41 @@ plugin: hetzner.hcloud.hcloud
 
 # Available variables are for example:
 ## Server
-#   id: 42984895
-#   name: "my-server"
-#   labels:
+#   hcloud_id: 42984895
+#   hcloud_name: "my-server"
+#   hcloud_labels:
 #     foo: "bar"
-#   status: "running"
+#   hcloud_status: "running"
 ## Server Type
-#   type: "cx22"
-#   server_type: "cx22"
-#   architecture: "x86"
+#   hcloud_type: "cpx22"
+#   hcloud_server_type: "cpx22"
+#   hcloud_architecture: "x86"
 ## Image
-#   image_id: 114690387
-#   image_name: "debian-12"
-#   image_os_flavor: "debian"
-## Datacenter
-#   datacenter: "hel1-dc2"
-#   location: "hel1"
+#   hcloud_image_id: 114690387
+#   hcloud_image_name: "debian-12"
+#   hcloud_image_os_flavor: "debian"
+## Location
+#   hcloud_location: "hel1"
+#   # The hcloud_datacenter variable is deprecated and will be removed after 1 July 2026.
+#   # Please use the hcloud_location variable instead.
+#   # See https://docs.hetzner.cloud/changelog#2025-12-16-phasing-out-datacenters.
+#   hcloud_datacenter: "hel1-dc2"
 ## Network
-#   ipv4: "65.109.140.95" # Value is optional!
-#   ipv6: "2a01:4f9:c011:b83f::1" # Value is optional!
-#   ipv6_network: 2a01:4f9:c011:b83f::" # Value is optional!
-#   ipv6_network_mask: "64" # Value is optional!
-#   private_ipv4: "10.0.0.3" # Value is optional!
-#   private_networks:
+#   hcloud_ipv4: "65.109.140.95" # Value is optional!
+#   hcloud_ipv6: "2a01:4f9:c011:b83f::1" # Value is optional!
+#   hcloud_ipv6_network: 2a01:4f9:c011:b83f::" # Value is optional!
+#   hcloud_ipv6_network_mask: "64" # Value is optional!
+#   hcloud_private_ipv4: "10.0.0.3" # Value is optional!
+#   hcloud_private_networks:
 #     - id: 114690387
 #       name: "my-private-network"
 #       ip: "10.0.0.3"
 #
-hostname: "my-prefix-{{ datacenter }}-{{ name }}-{{ server_type }}"
+hostname: "my-prefix-{{ hcloud_location }}-{{ hcloud_name }}-{{ hcloud_server_type }}"
 """
 
 import sys
+import warnings
 from ipaddress import IPv6Network
 
 from ansible.errors import AnsibleError
@@ -197,16 +202,16 @@ from ansible.plugins.inventory import BaseInventoryPlugin, Cacheable, Constructa
 from ansible.utils.display import Display
 from ansible.utils.vars import combine_vars
 
-from ..module_utils.client import (
+from ..module_utils._client import (
     Client,
     ClientException,
     client_check_required_lib,
     client_get_by_name_or_id,
 )
-from ..module_utils.vendor.hcloud import APIException
-from ..module_utils.vendor.hcloud.networks import Network
-from ..module_utils.vendor.hcloud.servers import Server
-from ..module_utils.version import version
+from ..module_utils._vendor.hcloud import APIException
+from ..module_utils._vendor.hcloud.networks import Network
+from ..module_utils._vendor.hcloud.servers import Server
+from ..module_utils._version import version
 
 if sys.version_info >= (3, 11):
     # The typed dicts are only used to help development and we prefer not requiring
@@ -229,7 +234,7 @@ if sys.version_info >= (3, 11):
         architecture: str
 
         # Datacenter
-        datacenter: str
+        datacenter: str  # Deprecated!
         location: str
 
         # Labels
@@ -321,7 +326,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
 
         if self.get_option("locations"):
             locations: list[str] = self.get_option("locations")
-            servers = [s for s in servers if s.datacenter.location.name in locations]
+            servers = [s for s in servers if s.location.name in locations]
 
         if self.get_option("types"):
             server_types: list[str] = self.get_option("types")
@@ -364,9 +369,16 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                     server_dict["private_ipv4"] = private_net.ip
                     break
 
-        # Datacenter
-        server_dict["datacenter"] = server.datacenter.name
-        server_dict["location"] = server.datacenter.location.name
+        # Location
+        server_dict["location"] = server.location.name
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", category=DeprecationWarning)
+            self.display.warning(
+                "The `hcloud_datacenter` variable is deprecated and will be removed "
+                "after 1 July 2026. Please use the `hcloud_location` variable instead. "
+                "See https://docs.hetzner.cloud/changelog#2025-12-16-phasing-out-datacenters."
+            )
+            server_dict["datacenter"] = server.datacenter and server.datacenter.name
 
         # Image
         if server.image is not None:
