@@ -65,7 +65,7 @@ hcloud_datacenter_info:
     description:
       - The datacenter info as list
     returned: always
-    type: complex
+    type: list
     contains:
         id:
             description: Numeric identifier of the datacenter
@@ -119,9 +119,9 @@ hcloud_datacenter_info:
 
 from ansible.module_utils.basic import AnsibleModule
 
-from ..module_utils.hcloud import AnsibleHCloud
-from ..module_utils.vendor.hcloud import HCloudException
-from ..module_utils.vendor.hcloud.datacenters import BoundDatacenter
+from ..module_utils._base import AnsibleHCloud
+from ..module_utils._vendor.hcloud import HCloudException
+from ..module_utils._vendor.hcloud.datacenters import BoundDatacenter
 
 
 class AnsibleHCloudDatacenterInfo(AnsibleHCloud):
