@@ -48,7 +48,7 @@ RETURN = """
 hcloud_load_balancer_type_info:
     description: The Load Balancer type infos as list
     returned: always
-    type: complex
+    type: list
     contains:
         id:
             description: Numeric identifier of the Load Balancer type
@@ -89,9 +89,9 @@ hcloud_load_balancer_type_info:
 
 from ansible.module_utils.basic import AnsibleModule
 
-from ..module_utils.hcloud import AnsibleHCloud
-from ..module_utils.vendor.hcloud import HCloudException
-from ..module_utils.vendor.hcloud.load_balancer_types import BoundLoadBalancerType
+from ..module_utils._base import AnsibleHCloud
+from ..module_utils._vendor.hcloud import HCloudException
+from ..module_utils._vendor.hcloud.load_balancer_types import BoundLoadBalancerType
 
 
 class AnsibleHCloudLoadBalancerTypeInfo(AnsibleHCloud):
