@@ -3,12 +3,14 @@
 
 # Copyright (C) 2021 IBM CORPORATION
 # Author(s): Sreshtant Bohidar <sreshtant.bohidar@ibm.com>
+#            Rahul Pawar <rahul.p@ibm.com>
+#            Sumit Kumar Gupta <sumit.gupta@ibm.com>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-DOCUMENTATION = '''
+DOCUMENTATION = r'''
 ---
 module: ibm_svc_manage_volume
 short_description: This module manages standard volumes on IBM Storage Virtualize family systems
@@ -29,7 +31,7 @@ options:
     type: str
   clustername:
     description:
-      - The hostname or management IP of the Storage Virtualize system.
+      - The hostname or management IP or Partition IP of the Storage Virtualize system.
     required: true
     type: str
   domain:
@@ -62,13 +64,20 @@ options:
       - Defines the size of the volume. This parameter can also be used to resize an existing volume.
       - Required when I(state=present), to create or modify a volume.
     type: str
+  warning:
+    description:
+      - Raises a warning when the used disk capacity on the thin-provisioned copy first exceeds the specified threshold.
+      - The value is specified as a percentage of the total capacity of the thin-provisioned volume, hence it must be between 0 and 100.
+      - When not specified, the default value is 80%.
+      - Valid when I(state=present), to create or modify a thin-provisioned or compressed volume.
+    type: int
+    version_added: '2.7.0'
   unit:
     description:
       - Specifies the data units to use with the capacity that is specified by the 'size' parameter.
       - I(size) is required when using I(unit).
     type: str
     choices: [ b, kb, mb, gb, tb, pb ]
-    default: mb
   iogrp:
     description:
       - Specifies the list of I/O group names. Group names in the list must be separated by using a comma.
@@ -88,6 +97,7 @@ options:
       - Specifies the type of volume to create. Volume can be thinclone or clone type.
       - Valid when I(state=present), to create a thinclone or clone volume.
       - Supported from Storage Virtualize family systems from 8.6.2.0 or later.
+      - Also used to convert a thinclone volume to clone. type = clone should be specified.
     choices: [thinclone, clone]
     type: str
   fromsourcevolume:
@@ -127,6 +137,14 @@ options:
       - Parameters 'novolumegroup' and 'volumegroup' are mutually exclusive.
       - Valid when I(state=present), to modify a volume.
     type: bool
+  unmap:
+    description:
+      - Removes specified objects associated with the volume which is to be deleted.
+      - Valid when I(state=absent), to delete a volume.
+    type: list
+    elements: str
+    choices: [ host_mappings, remotecopy_relationships, flashcopy_mappings ]
+    version_added: 2.7.0
   old_name:
     description:
       - Specifies the old name of the volume during renaming.
@@ -161,17 +179,50 @@ options:
     description:
       - Path of debug log file.
     type: str
+  grainsize:
+    description:
+      - Sets the grain size for a thin-provisioned volume.
+    choices: [32, 64, 128, 256]
+    type: int
+    version_added: '3.0.0'
+  preferrednode:
+    description:
+      - Specifies the preferred node name that is used to access the volume.
+      - When not specified, the system selects the preferred node automatically.
+    type: str
+    version_added: '3.2.0'
+  cache:
+    description:
+      - Specifies the caching options for the volume.
+      - When not specified, the default value is 'readwrite'.
+    type: str
+    choices: [readwrite, readonly, none]
+    version_added: '3.2.0'
+  autoexpand:
+    description:
+      - Specifies whether thin-provisioned volume copies automatically expand their real capacities.
+      - If specified as off, works as `noautoexpand`.
+    type: str
+    choices: ['on', 'off']
+    version_added: '3.2.0'
 author:
     - Sreshtant Bohidar(@Sreshtant-Bohidar)
+    - Rahul Pawar(@rahul-p)
+    - Sumit Kumar Gupta(@sumitguptaibm)
 notes:
     - This module supports C(check_mode).
+    - For unmap parameter, the option remotecopy_relationships has been deprecated from 8.7.1.0 onwards.
+    - CMMVC9855E The command failed because one of more of the specified volumes does not exist.
+      This error occurs when the user-provided volume(s) do not exist.
+    - This module supports logging in via partition IP.
+    - To create a clone or thinclone of a Volume, please refer to ibm_sv_manage_clone module.
 '''
 
-EXAMPLES = '''
+EXAMPLES = r'''
 - name: Create a volume
   ibm.storage_virtualize.ibm_svc_manage_volume:
     clustername: "{{ clustername }}"
-    domain: "{{domain}}"
+    domain: "{{ domain }}"
     username: "{{ username }}"
     password: "{{ password }}"
     log_path: "{{ log_path }}"
@@ -215,7 +266,7 @@ EXAMPLES = '''
 - name: Creating a volume with iogrp- io_grp0
   ibm.storage_virtualize.ibm_svc_manage_volume:
     clustername: "{{ clustername }}"
-    domain: "{{ domain}}"
+    domain: "{{ domain }}"
     username: "{{ username }}"
     password: "{{ password }}"
     log_path: "{{ log_path }}"
@@ -226,7 +277,7 @@ EXAMPLES = '''
     unit: "gb"
     iogrp: "io_grp0"
 - name: Create thinclone volume from volume vol1
-  ibm_svc_manage_volume:
+  ibm.storage_virtualize.ibm_svc_manage_volume:
     clustername: "{{ clustername }}"
     domain: "{{ domain }}"
     username: "{{ username }}"
@@ -235,8 +286,9 @@ EXAMPLES = '''
     fromsourcevolume: "vol1"
     state: "present"
     pool: "pool0"
+    type: "thinclone"
 - name: Create clone volume from volume vol1
-  ibm_svc_manage_volume:
+  ibm.storage_virtualize.ibm_svc_manage_volume:
     clustername: "{{ clustername }}"
     domain: "{{ domain }}"
     username: "{{ username }}"
@@ -245,6 +297,7 @@ EXAMPLES = '''
     fromsourcevolume: "vol1"
     state: "present"
     pool: "pool0"
+    type: "clone"
 - name: Adding a new iogrp- io_grp1
   ibm.storage_virtualize.ibm_svc_manage_volume:
     clustername: "{{ clustername }}"
@@ -255,9 +308,7 @@ EXAMPLES = '''
     name: "volume_name"
     state: "present"
     pool: "pool_name"
-    size: "1"
-    unit: "gb"
-    iogrp: "io_grp0, iogrp1"
+    iogrp: "io_grp0, io_grp1"
 - name: Rename an existing volume
   ibm.storage_virtualize.ibm_svc_manage_volume:
     clustername: "{{ clustername }}"
@@ -267,6 +318,45 @@ EXAMPLES = '''
     old_name: "volume_name"
     name: "new_volume_name"
     state: "present"
+- name: Convert a thinclone volume to clone
+  ibm.storage_virtualize.ibm_svc_manage_volume:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    name: "vol0-0"
+    type: "clone"
+    log_path: "{{ log_path }}"
+    state: "present"
+- name: Convert list of thinclone volumes to clone
+  ibm.storage_virtualize.ibm_svc_manage_volume:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    name: "vol0:vol1:vol2"
+    type: "clone"
+    log_path: "{{ log_path }}"
+    state: "present"
+- name: Update size of volume
+  ibm.storage_virtualize.ibm_svc_manage_volume:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    name: "volume_name"
+    size: "2"
+    unit: "gb"
+    state: "present"
+- name: Update volumegroup of volume
+  ibm.storage_virtualize.ibm_svc_manage_volume:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    name: "volume_name"
+    volumegroup: "vg1"
+    state: "present"
 - name: Enable cloud backup in an existing volume
   ibm.storage_virtualize.ibm_svc_manage_volume:
     clustername: "{{ clustername }}"
@@ -286,6 +376,30 @@ EXAMPLES = '''
     log_path: "{{ log_path }}"
     name: "new_volume_name"
     state: "absent"
+- name: Delete a volume and remove associated host mappings, remote copy relationships, and flashcopy mappings
+  ibm.storage_virtualize.ibm_svc_manage_volume:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: "{{ log_path }}"
+    name: "new_volume_name"
+    state: "absent"
+    unmap: ['host_mappings', 'remotecopy_relationships', 'flashcopy_mappings']
+- name: Create a thin volume with grainsize
+  ibm.storage_virtualize.ibm_svc_manage_volume:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: "{{ log_path }}"
+    name: "volume_name"
+    state: "present"
+    pool: "pool_name"
+    size: "1"
+    unit: "gb"
+    thin: true
+    grainsize: 32
 '''
 
 RETURN = '''#'''
@@ -296,10 +410,12 @@ from ansible_collections.ibm.storage_virtualize.plugins.module_utils.ibm_svc_uti
     IBMSVCRestApi,
     svc_argument_spec,
     get_logger,
-    strtobool
+    strtobool,
+    is_feature_supported
 )
 from ansible.module_utils._text import to_native
 import random
+import re
 
 
 class IBMSVCvolume(object):
@@ -312,13 +428,15 @@ class IBMSVCvolume(object):
                 state=dict(type='str', required=True, choices=['absent', 'present']),
                 pool=dict(type='str', required=False),
                 size=dict(type='str', required=False),
-                unit=dict(type='str', default='mb', choices=['b', 'kb',
-                                                             'mb', 'gb',
-                                                             'tb', 'pb']),
+                warning=dict(type='int', required=False),
+                unit=dict(type='str', choices=['b', 'kb', 'mb', 'gb', 'tb', 'pb']),
                 buffersize=dict(type='str', required=False),
                 iogrp=dict(type='str', required=False),
                 volumegroup=dict(type='str', required=False),
                 novolumegroup=dict(type='bool', required=False),
+                unmap=dict(type='list', elements='str', required=False, choices=['host_mappings',
+                                                                                 'remotecopy_relationships',
+                                                                                 'flashcopy_mappings']),
                 thin=dict(type='bool', required=False),
                 compressed=dict(type='bool', required=False),
                 deduplicated=dict(type='bool', required=False),
@@ -327,7 +445,11 @@ class IBMSVCvolume(object):
                 cloud_account_name=dict(type='str'),
                 type=dict(type='str', required=False, choices=['clone', 'thinclone']),
                 fromsourcevolume=dict(type='str', required=False),
-                allow_hs=dict(type='bool', default=False)
+                allow_hs=dict(type='bool', default=False),
+                grainsize=dict(type='int', required=False, choices=[32, 64, 128, 256]),
+                preferrednode=dict(type='str', required=False),
+                cache=dict(type='str', required=False, choices=['readwrite', 'readonly', 'none']),
+                autoexpand=dict(type='str', required=False, choices=['on', 'off'])
             )
         )
 
@@ -345,6 +467,7 @@ class IBMSVCvolume(object):
         # Optional Parameters
         self.pool = self.module.params['pool']
         self.size = self.module.params['size']
+        self.warning = self.module.params['warning']
         self.unit = self.module.params['unit']
         self.iogrp = self.module.params['iogrp']
         self.buffersize = self.module.params['buffersize']
@@ -359,6 +482,11 @@ class IBMSVCvolume(object):
         self.allow_hs = self.module.params['allow_hs']
         self.type = self.module.params['type']
         self.fromsourcevolume = self.module.params['fromsourcevolume']
+        self.unmap = self.module.params['unmap']
+        self.grainsize = self.module.params['grainsize']
+        self.preferrednode = self.module.params['preferrednode']
+        self.cache = self.module.params['cache']
+        self.autoexpand = self.module.params['autoexpand']
 
         # internal variable
         self.changed = False
@@ -377,39 +505,44 @@ class IBMSVCvolume(object):
     # assemble iogrp
     def assemble_iogrp(self):
         if self.iogrp:
-            temp = []
-            invalid = []
-            active_iogrp = []
-            existing_iogrp = []
-            if self.iogrp:
-                existing_iogrp = [item.strip() for item in self.iogrp.split(',') if item]
-            uni_exi_iogrp = set(existing_iogrp)
-            if len(existing_iogrp) != len(uni_exi_iogrp):
+            input_iogrps = [item.strip() for item in self.iogrp.split(',') if item]
+            self.len_input_iogrps = len(input_iogrps)
+            if self.len_input_iogrps != len(set(input_iogrps)):
                 self.module.fail_json(msg='Duplicate iogrp detected.')
-            active_iogrp = [item['name'] for item in self.restapi.svc_obj_info('lsiogrp', None, None) if int(item['node_count']) > 0]
-            for item in existing_iogrp:
-                item = item.strip()
-                if item not in active_iogrp:
-                    invalid.append(item)
-                else:
-                    temp.append(item)
-            if invalid:
-                self.module.fail_json(msg='Empty or non-existing iogrp detected: %s' % invalid)
-            self.iogrp = temp
 
-    # for validating mandatory parameters of the module
+            self.active_iogrp = [item['name'] for item in self.restapi.svc_obj_info('lsiogrp', None, None) if int(item['node_count']) > 0]
+
+            valid_iogrp = []
+            invalid_iogrp = []
+            for item in input_iogrps:
+                if item not in self.active_iogrp:
+                    invalid_iogrp.append(item)
+                else:
+                    valid_iogrp.append(item)
+            if invalid_iogrp:
+                self.module.fail_json(msg='Empty or non-existing iogrp detected: {0}'.format(invalid_iogrp))
+
+            self.iogrp = valid_iogrp
+
+    # Validate mandatory parameters of the module
     def mandatory_parameter_validation(self):
         missing = [item[0] for item in [('name', self.name), ('state', self.state)] if not item[1]]
         if missing:
             self.module.fail_json(msg='Missing mandatory parameter: [{0}]'.format(', '.join(missing)))
         if self.volumegroup and self.novolumegroup:
             self.module.fail_json(msg='Mutually exclusive parameters detected: [volumegroup] and [novolumegroup]')
+        if self.thin and self.compressed:
+            self.module.fail_json(msg='Mutually exclusive parameters detected: [thin] and [compressed]')
+        if self.state == 'present' and self.unmap is not None:
+            self.module.fail_json(msg='Parameter [unmap] cannot be specified when creating or updating a volume.')
+        if self.unit and not self.size:
+            self.module.fail_json(msg='Parameter [unit] is invalid without [size]')
 
     # for validating parameter while removing an existing volume
     def volume_deletion_parameter_validation(self):
         invalids = ('pool', 'size', 'iogrp', 'buffersize', 'volumegroup', 'novolumegroup',
                     'thin', 'compressed', 'deduplicated', 'old_name', 'enable_cloud_snapshot',
-                    'cloud_account_name', 'allow_hs', 'type', 'fromsourcevolume')
+                    'cloud_account_name', 'allow_hs', 'type', 'fromsourcevolume', 'warning', 'grainsize', 'preferrednode', 'cache', 'autoexpand')
 
         invalid_params = ', '.join((param for param in invalids if getattr(self, param)))
 
@@ -432,8 +565,23 @@ class IBMSVCvolume(object):
         if (self.type and not self.fromsourcevolume) or (self.fromsourcevolume and not self.type):
             self.module.fail_json(msg='Parameters [type] and [fromsourcevolume] parameters must be used together')
 
+        if (self.warning) and not self.thin and not self.compressed:
+            self.module.fail_json(msg='Parameter [warning] is invalid without [thin] or [compressed]')
+
+        if self.grainsize and not self.thin:
+            self.module.fail_json(msg='Parameter [grainsize] is invalid without [thin]')
+
+        if self.deduplicated and not (self.thin or self.compressed):
+            self.module.fail_json(msg='Parameter [deduplicated] is invalid without [thin] or [compressed]')
+
+        if self.preferrednode and (not self.iogrp or self.len_input_iogrps != 1):
+            self.module.fail_json(msg='Parameter [preferrednode] is only valid with a single iogrp.')
+
+        if self.autoexpand and (not self.thin and not self.compressed):
+            self.module.fail_json(msg='Parameter [autoexpand] is invalid without [thin]')
+
         missing = []
-        if self.type and self.fromsourcevolume:
+        if self.type:
             if not self.pool:
                 missing = ['pool']
             if self.size:
@@ -444,6 +592,13 @@ class IBMSVCvolume(object):
         if missing:
             self.module.fail_json(msg='Missing required parameter(s) while creating: [{0}]'.format(', '.join(missing)))
 
+    def chvolume_supported(self):
+        system_info = self.restapi.svc_obj_info(cmd='lssystem', cmdopts=None, cmdargs=None)
+        code_build_version = system_info['code_level']
+        match = re.match(r'^([\d\.]+)', code_build_version)
+        code_level = match.group(1) if match else None
+        return is_feature_supported('chvolume', code_level)
+
     # for validating parameter while renaming a volume
     def parameter_handling_while_renaming(self):
         if not self.old_name:
@@ -459,7 +614,12 @@ class IBMSVCvolume(object):
             "compressed": self.compressed,
             "deduplicated": self.deduplicated,
             "type": self.type,
-            "fromsourcevolume": self.fromsourcevolume
+            "fromsourcevolume": self.fromsourcevolume,
+            "warning": self.warning,
+            "grainsize": self.grainsize,
+            "preferrednode": self.preferrednode,
+            "cache": self.cache,
+            "autoexpand": self.autoexpand
         }
         parameters_exists = [parameter for parameter, value in parameters.items() if value]
         if parameters_exists:
@@ -487,6 +647,46 @@ class IBMSVCvolume(object):
             'lsvdisk', {'bytes': True}, [volume_name]
         )
 
+    def get_all_target_volumes(self, criteria=None):
+        # This function does following:
+        # 1. It fetches a set of volumes from SVC in all_vols_set
+        # 2. It converts self.name into a provided_vols_set
+        # 3. It gets common volumes set from both that meet the criteria
+        # 4. If any user-provide volume(s) do not exist on the cluster, returns error
+        # 5. It sets a new attribute self.target_vols_list_str which is a string formed
+        #    by joining colon-separated list of common volumes.
+
+        all_vols_set = set()
+        self.target_vols_list_str = ''
+
+        if self.module.check_mode:
+            self.changed = True
+            return
+
+        cmdopts = {}
+        if criteria:
+            cmdopts['filtervalue'] = criteria
+        data = self.restapi.svc_obj_info('lsvdisk', cmdopts, None)
+        if data:
+            for item in data:
+                all_vols_set.add(item['name'])
+
+        user_provided_vols_set = set(self.name.split(':'))
+        invalid_vols_list = list(user_provided_vols_set.difference(all_vols_set))
+        if invalid_vols_list:
+            self.module.fail_json(msg="CMMVC9855E The command failed because one or more of"
+                                  " the specified volumes does not exist.")
+
+        target_vols_list = []
+        if data:
+            for item in data:
+                if item['name'] in user_provided_vols_set and item['volume_type'] == "thinclone":
+                    target_vols_list.append(item['name'])
+        self.target_vols_list_str = ':'.join(target_vols_list)
+        self.log("Volume(s) that need to be converted from thinclone to clone: [%s].", self.target_vols_list_str)
+
+        return
+
     # function to get list of associated iogrp to a volume
     def get_existing_iogrp(self):
         response = []
@@ -546,12 +746,22 @@ class IBMSVCvolume(object):
             cmdopts['buffersize'] = self.buffersize
         if self.name:
             cmdopts['name'] = self.name
+        if self.warning:
+            cmdopts['warning'] = str(self.warning) + '%'
+        if self.preferrednode:
+            cmdopts['preferrednode'] = self.preferrednode
+        if self.cache:
+            cmdopts['cache'] = self.cache
+        if self.autoexpand == 'off':
+            cmdopts['noautoexpand'] = True
         if self.type:
             cmdopts['type'] = self.type
             snapshot_id = self.create_transient_snapshot()
             cmdopts['fromsnapshotid'] = snapshot_id
         if self.fromsourcevolume:
             cmdopts['fromsourcevolume'] = self.fromsourcevolume
+        if self.grainsize:
+            cmdopts['grainsize'] = self.grainsize
 
         result = self.restapi.svc_run_command(cmd, cmdopts, cmdargs=None)
         if result and 'message' in result:
@@ -564,11 +774,21 @@ class IBMSVCvolume(object):
     # function to remove an existing volume
     def remove_volume(self):
         self.volume_deletion_parameter_validation()
+        cmdopts = {}
         if self.module.check_mode:
             self.changed = True
             return
+        name_params_map = {
+            'host_mappings': 'removehostmappings',
+            'remotecopy_relationships': 'removercrelationships',
+            'flashcopy_mappings': 'removefcmaps'
+        }
+        if self.unmap:
+            for name in self.unmap:
+                cmdopts[name_params_map[name]] = True
+
         self.restapi.svc_run_command(
-            'rmvolume', None, [self.name]
+            'rmvolume', cmdopts, [self.name]
         )
         self.changed = True
 
@@ -579,6 +799,7 @@ class IBMSVCvolume(object):
     # function to probe an existing volume
     def probe_volume(self, data):
         props = {}
+
         # check for changes in iogrp
         if self.iogrp:
             input_iogrp = set(self.iogrp)
@@ -594,58 +815,51 @@ class IBMSVCvolume(object):
                     props['iogrp'] = {
                         'remove': list(iogrp_to_remove)
                     }
-        # check for changes in volume size
+        # check for changes in volume size for non-HA volumes
+        # Even if we need to use chvolume, it is ok to calculate
+        # because these are local calculations, and won't have any
+        # effect if chvolume is to be used. Refer to update_volume()
+        # for 'updating size of a volume'
+
         if self.size:
             input_size = self.convert_to_bytes()
             existing_size = int(data[0]['capacity'])
             if input_size != existing_size:
-                if input_size > existing_size:
-                    props['size'] = {
-                        'expand': input_size - existing_size
-                    }
-                elif existing_size > input_size:
-                    props['size'] = {
-                        'shrink': existing_size - input_size
-                    }
+                action = 'expand' if input_size > existing_size else 'shrink'
+                props['size'] = {action: abs(input_size - existing_size)}
+
+        if self.warning:
+            # Check for standard or compressed volume
+            if (data[0]['capacity'] != data[1]['real_capacity']) or (data[1]['compressed_copy'] == 'yes'):
+                if (int(data[1]['warning']) != (self.warning)):
+                    props['warning'] = str(self.warning) + '%'
+            else:
+                self.module.fail_json(msg='Parameter [warning] is applicable only for thin-provisioned and compressed volumes.')
+
         # check for changes in volumegroup
         if self.volumegroup:
             if self.volumegroup != data[0]['volume_group_name']:
                 props['volumegroup'] = {
-                    'name': self.volumegroup
+                    'name': self.volumegroup,
                 }
+
         # check for presence of novolumegroup
         if self.novolumegroup:
             if data[0]['volume_group_name']:
                 props['novolumegroup'] = {
                     'status': True
                 }
-        # check for change in -thin parameter
-        if self.thin is not None:
-            if self.thin is True:
-                # a standard volume or a compressed volume
-                if (data[0]['capacity'] == data[1]['real_capacity']) or (data[1]['compressed_copy'] == 'yes'):
-                    props['thin'] = {
-                        'status': True
-                    }
-            else:
-                if (data[0]['capacity'] != data[1]['real_capacity']) or (data[1]['compressed_copy'] == 'no'):
-                    props['thin'] = {
-                        'status': True
-                    }
-        # check for change in -compressed parameter
-        if self.compressed is True:
-            # not a compressed volume
-            if data[1]['compressed_copy'] == 'no':
-                props['compressed'] = {
-                    'status': True
-                }
-        # check for change in -deduplicated parameter
-        if self.deduplicated is True:
-            # not a deduplicated volume
-            if data[1]['deduplicated_copy'] == 'no':
-                props['deduplicated'] = {
-                    'status': True
-                }
+
+        # check for change in thin, compressed and deduplicated
+        for attr, field in (('thin', 'se_copy'),
+                            ('compressed', 'compressed_copy'),
+                            ('deduplicated', 'deduplicated_copy')):
+            val = getattr(self, attr)
+            if val is not None:
+                current = str(data[1].get(field)).lower() == 'yes'
+                if bool(val) != current:
+                    props[attr] = {'status': True}
+
         # check for change in pool
         if self.pool:
             if self.pool != data[0]['mdisk_grp_name']:
@@ -674,6 +888,20 @@ class IBMSVCvolume(object):
             if self.type != data[0].get('volume_type'):
                 props['type'] = {'status': True}
 
+        if self.grainsize:
+            if self.grainsize != int(data[1].get('grainsize') or 0):
+                props['grainsize'] = {'status': True}
+
+        if self.preferrednode and self.preferrednode != data[0].get('preferred_node_name'):
+            props['preferrednode'] = self.preferrednode
+
+        if self.cache and self.cache != data[0].get('cache'):
+            props['cache'] = self.cache
+
+        if self.autoexpand and self.autoexpand != data[1].get('autoexpand'):
+            props['autoexpand'] = self.autoexpand
+
+        self.log("Properties to be changed: %s", props)
         return props
 
     # function to expand an existing volume size
@@ -733,45 +961,90 @@ class IBMSVCvolume(object):
         )
         self.changed = True
 
+    def convert_to_clone(self):
+        # when check_mode is enabled
+        if self.module.check_mode:
+            self.msg = 'Skipping changes due to check mode.'
+            self.changed = True
+            return
+
+        cmdopts = {}
+        # For a list of volumes, target_volumes_list_str will be set by get_all_target_volumes()
+        if hasattr(self, 'target_vols_list_str') and self.target_vols_list_str != '':
+            cmdopts['volumes'] = self.target_vols_list_str
+        else:
+            cmdopts['volumes'] = self.name
+        cmdargs = None
+        self.restapi.svc_run_command('converttoclone', cmdopts, cmdargs)
+        self.msg = "Volume(s) [{0}] converted to clone.".format(self.name)
+        self.changed = True
+        return
+
     # function to update an existing volume
     def update_volume(self, modify):
-        # raise error for unsupported parameter
-        unsupported_parameters = ['pool', 'thin', 'compressed', 'deduplicated', 'type', 'fromsourcevolume']
-        unsupported_exists = []
-        for parameter in unsupported_parameters:
-            if parameter in modify:
-                unsupported_exists.append(parameter)
+        # raise error for unsupported parameter(s)
+        unsupported_parameters = ['pool', 'thin', 'compressed', 'deduplicated', 'fromsourcevolume', 'grainsize', 'preferrednode']
+        unsupported_exists = [param for param in unsupported_parameters if param in modify]
         if unsupported_exists:
-            self.module.fail_json(msg='Update not supported for parameter: {0}'.format(unsupported_exists))
+            self.module.fail_json(msg=f"Update not supported for parameter(s): {', '.join(unsupported_exists)}")
+
+        invalid_together = ['warning', 'cloud_backup', 'volumegroup', 'novolumegroup', 'size', 'cache', 'autoexpand']
+        mutually_exclusive_params = [param for param in invalid_together if param in modify]
+
+        # If any 2 conflicting parameters are passed, return error
+        if len(mutually_exclusive_params) > 1:
+            self.module.fail_json(msg=f"Parameters are mutually exclusive: {', '.join(mutually_exclusive_params)}")
+
         # when check_mode is enabled
         if self.module.check_mode:
             self.changed = True
             return
+
         # updating iogrps of a volume
         if 'iogrp' in modify:
             if 'add' in modify['iogrp']:
                 self.add_iogrp(modify['iogrp']['add'])
             if 'remove' in modify['iogrp']:
                 self.remove_iogrp(modify['iogrp']['remove'])
-        # updating size of a volume
-        if 'size' in modify:
-            if 'expand' in modify['size']:
-                self.expand_volume(modify['size']['expand'])
-            elif 'shrink' in modify['size']:
-                self.shrink_volume(modify['size']['shrink'])
 
         if 'cloud_backup' in modify:
             self.update_cloud_backup()
 
-        # updating volumegroup, novolumegroup of a volume
+        cmd = 'chvdisk'
+
         cmdopts = {}
         if 'volumegroup' in modify:
             cmdopts['volumegroup'] = modify['volumegroup']['name']
+            if self.chvolume_supported():
+                cmd = 'chvolume'
         if 'novolumegroup' in modify:
             cmdopts['novolumegroup'] = modify['novolumegroup']['status']
+            if self.chvolume_supported():
+                cmd = 'chvolume'
+        if 'warning' in modify:
+            cmdopts['warning'] = modify['warning']
+
+        # updating size of a volume
+        if 'size' in modify:
+            if 'shrink' in modify['size']:
+                self.shrink_volume(modify['size']['shrink'])
+            else:
+                if self.chvolume_supported():
+                    cmd = 'chvolume'
+                    cmdopts['size'] = self.size
+                    if self.unit:
+                        cmdopts['unit'] = self.unit
+                else:
+                    self.expand_volume(modify['size']['expand'])
+
+        if 'cache' in modify:
+            cmdopts['cache'] = modify['cache']
+        if 'autoexpand' in modify:
+            cmdopts['autoexpand'] = modify['autoexpand']
+
         if cmdopts:
             self.restapi.svc_run_command(
-                'chvdisk',
+                cmd,
                 cmdopts,
                 [self.name]
             )
@@ -793,17 +1066,49 @@ class IBMSVCvolume(object):
             if self.module.check_mode:
                 self.changed = True
                 return
-            self.restapi.svc_run_command('chvdisk', {'name': self.name}, [self.old_name])
+
+            cmd = 'chvolume' if self.chvolume_supported() else 'chvdisk'
+            self.restapi.svc_run_command(cmd, {'name': self.name}, [self.old_name])
             self.changed = True
-            msg = "Volume [{0}] has been successfully rename to [{1}]".format(self.old_name, self.name)
+            msg = "Volume [{0}] has been successfully renamed to [{1}]".format(self.old_name, self.name)
         return msg
 
     def apply(self):
         changed, msg, modify = False, None, {}
         self.mandatory_parameter_validation()
-        volume_data = self.get_existing_volume(self.name)
+
+        if ':' in self.name and self.type == 'clone' and self.state == 'present':
+            # Special handling for list of volumes
+            # Only applicable for converting thinclone volumes list to clone
+            self.get_all_target_volumes()
+            # self.target_vols_list_str will be set after calling get_all_target_volumes()
+            if self.target_vols_list_str != '':
+                self.convert_to_clone()
+                self.module.exit_json(msg=self.msg, changed=self.changed)
+            else:
+                self.msg = "Volume(s) [{0}] are not thinclone!!".format(self.name)
+                self.module.exit_json(msg=self.msg, changed=self.changed)
+        else:
+            volume_data = self.get_existing_volume(self.name)
+
+        if volume_data and self.type == 'clone' and not self.fromsourcevolume:
+            # If an existing volume was passed along with type=clone
+            # but not fromsourcevolume, user wants to convert thinclone to clone
+            if volume_data[0].get('volume_type') == 'thinclone':
+                # If volume is thinclone, convert it to clone.
+                self.convert_to_clone()
+                self.module.exit_json(msg=self.msg, changed=self.changed)
+            else:
+                # If volume is not thinclone, just return message.
+                # This is for cases, where it was either already done
+                # the last time it was run, or was never a thinclone.
+                self.module.exit_json(msg='Volume {0} is not a thinclone.'.format(self.name), changed=self.changed)
+
         if self.state == "present" and self.old_name:
-            msg = self.volume_rename(volume_data)
+            if self.name == self.old_name:
+                self.module.exit_json(msg="Volume's name is same as old name.", changed=self.changed)
+            else:
+                msg = self.volume_rename(volume_data)
         elif self.state == "absent" and self.old_name:
             self.module.fail_json(msg="Rename functionality is not supported when 'state' is absent.")
         else:
@@ -850,7 +1155,6 @@ class IBMSVCvolume(object):
         if self.module.check_mode:
             msg = 'Skipping changes due to check mode.'
             self.log('skipping changes due to check mode.')
-
         self.module.exit_json(msg=msg, changed=self.changed)
 
 
