@@ -4,10 +4,11 @@
 # Copyright (C) 2021 IBM CORPORATION
 # Author(s): Shilpi Jain <shilpi.jain1@ibm.com>
 #            Sanjaikumaar M <sanjaikumaar.m@ibm.com>
+#            Sumit Kumar Gupta <sumit.gupta16@ibm.com>
+#            Sandip Gulab Rajbanshi <sandip.rajbanshi@ibm.com>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
-
 __metaclass__ = type
 
 DOCUMENTATION = '''
@@ -32,7 +33,7 @@ options:
         type: str
     clustername:
         description:
-            - The hostname or management IP of the Storage Virtualize system.
+            - The hostname or management IP or Partition IP of the Storage Virtualize system.
         required: true
         type: str
     domain:
@@ -121,6 +122,7 @@ options:
         description:
             - Specifies the type of volume group to be created from the snapshot.
             - Valid during creation of host accessible volume group from an existing snapshot.
+            - Also used to convert a thinclone volumegroup to clone. type = clone should be specified.
         choices: [ clone, thinclone ]
         type: str
         version_added: 1.9.0
@@ -178,7 +180,7 @@ options:
     noreplicationpolicy:
         description:
             - If specified `True`, removes the replication policy assigned to the volume group.
-            - Parameters I(replicationpolicy) and I(noreplicationpolicy) are mutually exclusive.
+            - I(noreplicationpolicy) is mutually exclusive with parameters I(replicationpolicy) and I(nodrreplication).
             - Applies when I(state=present) to modify an existing volume group.
             - Supported from Storage Virtualize family systems 8.5.2.1 or later.
         type: bool
@@ -196,21 +198,48 @@ options:
             - Supported from Storage Virtualize family systems 8.6.1.0 or later.
         type: str
         version_added: 2.1.0
-    nopartition:
+    evictvolumes:
         description:
-            - If specified `True`, removes the volume group from the storage partition.
-            - Parameters I(partition) and I(nopartition) are mutually exclusive.
-            - Applies when I(state=present) to modify an existing volume group.
-            - Supported from Storage Virtualize family systems 8.6.1.0 or later.
+            - If specified `True`, delete the volume group but does not remove volumes.
+            - Applies when I(state=absent) to delete the volume group, keeping associated volumes.
+            - Supported from Storage Virtualize family systems from 8.6.2.0 or later.
         type: bool
-        version_added: 2.1.0
+        version_added: 2.2.0
+    fromsourcevolumes:
+        description:
+            - Specifies colon-separated list of the parent volumes.
+            - When combined with the type parameter and a snapshot, this allows the user to create a volumegroup with a
+              subset of those volumes whose image is present in a snapshot.
+            - Applies when I(state=present) to create volumegroup clone or thinclone, from subset of volumes of snapshot.
+            - Supported from Storage Virtualize family systems from 8.6.2.0 or later.
+        type: str
+        version_added: 2.3.0
+    draftpartition:
+        description:
+            - Specifies the name of the draft partition to be assigned to the volume group.
+            - Applies when I(state=present).
+            - Supported from Storage Virtualize family systems 8.6.3.0 or later.
+        type: str
+        version_added: 2.5.0
+    nodrreplication:
+        description:
+            - If specified `True`, removes the volume group from the async-dr replication policy.
+            - I(nodrreplication) is mutually exclusive with parameters I(replicationpolicy) and I(noreplicationpolicy).
+            - Applies when I(state=present) to modify an existing volume group.
+            - Supported from Storage Virtualize family systems 8.7.1.0 or later.
+        type: bool
+        version_added: 2.6.0
+
 author:
     - Shilpi Jain(@Shilpi-J)
     - Sanjaikumaar M (@sanjaikumaar)
+    - Sumit Kumar Gupta (@sumitguptaibm)
+    - Sandip G. Rajbanshi (@Sandip-Rajbanshi)
 notes:
     - This module supports C(check_mode).
     - Safeguarded policy and snapshot policy cannot be used at the same time.
       Therefore, the parameters I(snapshotpolicy) and I(safeguardpolicyname) are mutually exclusive.
+    - This module supports logging in via partition IP.
 '''
 
 EXAMPLES = '''
@@ -241,7 +270,7 @@ EXAMPLES = '''
     log_path: /tmp/playbook.debug
     name: vg0
     state: present
-    noownershipgroup: True
+    noownershipgroup: true
     safeguardpolicyname: sg1
 - name: Update volumegroup with snapshot policy and remove safeguarded policy
   ibm.storage_virtualize.ibm_svc_manage_volumegroup:
@@ -264,7 +293,7 @@ EXAMPLES = '''
     name: vg0
     safeguarded: true
     snapshotpolicy: sp1
-    ignoreuserfcmaps: yes
+    ignoreuserfcmaps: 'yes'
     state: present
 - name: Suspend snapshot policy in an existing volume group
   ibm.storage_virtualize.ibm_svc_manage_volumegroup:
@@ -289,6 +318,70 @@ EXAMPLES = '''
     fromsourcegroup: vg0
     pool: Pool0
     state: present
+- name: Create a volumegroup thinclone from a list of volumes
+  ibm.storage_virtualize.ibm_svc_manage_volumegroup:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: /tmp/playbook.debug
+    name: vg0
+    type: thinclone
+    fromsourcevolumes: vol1:vol2
+    pool: Pool0
+    state: present
+- name: Create a volumegroup clone from a list of volumes
+  ibm.storage_virtualize.ibm_svc_manage_volumegroup:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: /tmp/playbook.debug
+    name: vg0
+    type: clone
+    fromsourcevolumes: vol1:vol2
+    pool: Pool0
+    state: present
+- name: Convert a thinclone volumegroup to clone
+  ibm.storage_virtualize.ibm_svc_manage_volumegroup:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: /tmp/playbook.debug
+    name: vg0
+    type: clone
+    state: present
+- name: Delete a volume group, keeping volumes which were associated with volumegroup
+  ibm.storage_virtualize.ibm_svc_manage_volumegroup:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: /tmp/playbook.debug
+    name: vg0
+    state: absent
+    evictvolumes: true
+- name: Add new or existing volumegroup to a draft partition
+  ibm.storage_virtualize.ibm_svc_manage_volumegroup:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: /tmp/playbook.debug
+    name: vg0
+    state: present
+    draftpartition: partition_name
+- name: Remove DR replication-policy from volume group
+  ibm.storage_virtualize.ibm_svc_manage_volumegroup:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: /tmp/playbook.debug
+    name: vg0
+    state: absent
+    nodrreplication: true
 '''
 
 RETURN = '''#'''
@@ -298,6 +391,7 @@ from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.ibm.storage_virtualize.plugins.module_utils.ibm_svc_utils import \
     IBMSVCRestApi, svc_argument_spec, get_logger, strtobool
 from ansible.module_utils._text import to_native
+import random
 
 
 class IBMSVCVG(object):
@@ -320,6 +414,7 @@ class IBMSVCVG(object):
                 type=dict(type='str', choices=['clone', 'thinclone']),
                 snapshot=dict(type='str'),
                 fromsourcegroup=dict(type='str'),
+                fromsourcevolumes=dict(type='str', required=False),
                 pool=dict(type='str'),
                 iogrp=dict(type='str'),
                 safeguarded=dict(type='bool', default=False),
@@ -328,7 +423,9 @@ class IBMSVCVG(object):
                 noreplicationpolicy=dict(type='bool'),
                 old_name=dict(type='str', required=False),
                 partition=dict(type='str'),
-                nopartition=dict(type='bool')
+                evictvolumes=dict(type='bool'),
+                draftpartition=dict(type='str'),
+                nodrreplication=dict(type='bool')
             )
         )
 
@@ -354,6 +451,7 @@ class IBMSVCVG(object):
         self.type = self.module.params.get('type', '')
         self.snapshot = self.module.params.get('snapshot', '')
         self.fromsourcegroup = self.module.params.get('fromsourcegroup', '')
+        self.fromsourcevolumes = self.module.params.get('fromsourcevolumes', '')
         self.pool = self.module.params.get('pool', '')
         self.iogrp = self.module.params.get('iogrp', '')
         self.safeguardpolicyname = self.module.params.get('safeguardpolicyname', '')
@@ -364,7 +462,9 @@ class IBMSVCVG(object):
         self.noreplicationpolicy = self.module.params.get('noreplicationpolicy', False)
         self.old_name = self.module.params.get('old_name', '')
         self.partition = self.module.params.get('partition', '')
-        self.nopartition = self.module.params.get('nopartition', False)
+        self.evictvolumes = self.module.params.get('evictvolumes', False)
+        self.draftpartition = self.module.params.get('draftpartition', '')
+        self.nodrreplication = self.module.params.get('nodrreplication', False)
 
         # Dynamic variable
         self.parentuid = None
@@ -385,6 +485,7 @@ class IBMSVCVG(object):
         )
 
     def basic_checks(self):
+        changed = False
         if not self.name:
             self.module.fail_json(msg='Missing mandatory parameter: name')
 
@@ -399,19 +500,26 @@ class IBMSVCVG(object):
                     self.module.fail_json(
                         msg='Parameter `safeguarded` should be passed along with `snapshotpolicy`'
                     )
-        else:
+            if self.evictvolumes is not None:
+                self.module.fail_json(
+                    msg='Parameter `evictvolumes` should be passed only while removing volumegroup'
+                )
+        elif self.state == 'absent':
             unwanted = ('ownershipgroup', 'noownershipgroup', 'safeguardpolicyname',
                         'nosafeguardpolicy', 'snapshotpolicy', 'nosnapshotpolicy',
                         'policystarttime', 'type', 'fromsourcegroup', 'pool', 'iogrp',
                         'safeguarded', 'ignoreuserfcmaps', 'replicationpolicy',
-                        'noreplicationpolicy', 'old_name')
+                        'noreplicationpolicy', 'old_name', 'fromsourcevolumes', 'draftpartition', 'nodrreplication')
 
             param_exists = ', '.join((param for param in unwanted if getattr(self, param)))
 
             if param_exists:
                 self.module.fail_json(
-                    msg='State=absent but following parameters exists: {0}'.format(param_exists)
+                    msg='State=absent but following parameter(s) exist: {0}'.format(param_exists),
+                    changed=changed
                 )
+        else:
+            self.module.fail_json(msg='State should be either present or absent')
 
     def parameter_handling_while_renaming(self):
         parameters = {
@@ -424,7 +532,8 @@ class IBMSVCVG(object):
             "snapshotpolicy": self.snapshotpolicy,
             "nosnapshotpolicy": self.nosnapshotpolicy,
             "partition": self.partition,
-            "nopartition": self.nopartition
+            "fromsourcevolumes": self.fromsourcevolumes,
+            "nodrreplication": self.nodrreplication
         }
         parameters_exists = [parameter for parameter, value in parameters.items() if value]
         if parameters_exists:
@@ -437,7 +546,9 @@ class IBMSVCVG(object):
             ('ownershipgroup', 'policystarttime'),
             ('snapshotpolicy', 'safeguardpolicyname'),
             ('replicationpolicy', 'noreplicationpolicy'),
-            ('partition', 'nopartition')
+            ('draftpartition', 'partition'),
+            ('replicationpolicy', 'nodrreplication'),
+            ('noreplicationpolicy', 'nodrreplication')
         )
 
         for param1, param2 in mutually_exclusive:
@@ -447,17 +558,12 @@ class IBMSVCVG(object):
                 )
 
         unsupported = ('nosafeguardpolicy', 'noownershipgroup', 'nosnapshotpolicy',
-                       'snapshotpolicysuspended', 'noreplicationpolicy')
+                       'snapshotpolicysuspended', 'noreplicationpolicy', 'nodrreplication')
         unsupported_exists = ', '.join((field for field in unsupported if getattr(self, field)))
 
         if unsupported_exists:
             self.module.fail_json(
-                msg='Following paramters not supported during creation scenario: {0}'.format(unsupported_exists)
-            )
-
-        if self.type and not self.snapshot:
-            self.module.fail_json(
-                msg='type={0} but following parameter is missing: snapshot'.format(self.type)
+                msg='Following parameters not supported during creation scenario: {0}'.format(unsupported_exists)
             )
 
     def update_validation(self, data):
@@ -470,8 +576,8 @@ class IBMSVCVG(object):
             ('nosafeguardpolicy', 'nosnapshotpolicy'),
             ('snapshotpolicy', 'nosnapshotpolicy'),
             ('snapshotpolicy', 'safeguardpolicyname'),
-            ('replicationpolicy', 'noreplicationpolicy'),
-            ('partition', 'nopartition')
+            ('replicationpolicy', 'nodrreplication'),
+            ('noreplicationpolicy', 'nodrreplication')
         )
 
         for param1, param2 in mutually_exclusive:
@@ -480,10 +586,32 @@ class IBMSVCVG(object):
                     msg='Mutually exclusive parameters: {0}, {1}'.format(param1, param2)
                 )
 
+        if self.type:
+            # converttoclone accepts only type=clone, so update validation will include that
+            if self.type == 'clone':
+                invalids_while_converting_to_clone = ('safeguardpolicyname', 'nosafeguardpolicy', 'ownershipgroup',
+                                                      'snapshotpolicy', 'policystarttime', 'nosnapshotpolicy',
+                                                      'replicationpolicy', 'nodrreplication', 'noreplicationpolicy')
+                invalid_params_for_convert_to_clone = ', '.join((param for param in invalids_while_converting_to_clone
+                                                                if getattr(self, param)))
+
+                if invalid_params_for_convert_to_clone:
+                    self.module.fail_json(
+                        msg='Following parameter(s) are invalid while converting thinclone volumegroup to clone: {0}'
+                        .format(invalid_params_for_convert_to_clone)
+                    )
+            else:
+                # If type=thinclone (or some invalid value) was passed, return error.
+                self.module.fail_json(
+                    msg='type = {0} is invalid for updating volumegroup. Only type = clone is supported.'
+                    .format(self.type)
+                )
+
         unsupported_maps = (
-            ('type', data.get('volume_group_type', '')),
             ('snapshot', data.get('source_snapshot', '')),
-            ('fromsourcegroup', data.get('source_volume_group_name', ''))
+            ('fromsourcevolumes', data.get('source_volumes_set', '')),
+            ('fromsourcegroup', data.get('source_volume_group_name', '')),
+            ('partition', data.get('partition_name', ''))
         )
         unsupported = (
             fields[0] for fields in unsupported_maps if getattr(self, fields[0]) and getattr(self, fields[0]) != fields[1]
@@ -492,7 +620,7 @@ class IBMSVCVG(object):
 
         if unsupported_exists:
             self.module.fail_json(
-                msg='Following paramters not supported during update: {0}'.format(unsupported_exists)
+                msg='Following parameters not supported during update: {0}'.format(unsupported_exists)
             )
 
     def get_existing_vg(self, vg_name):
@@ -517,6 +645,64 @@ class IBMSVCVG(object):
             merged_result['snapshot_policy_start_time'] = SP_data['snapshot_policy_start_time']
             merged_result['snapshot_policy_suspended'] = SP_data['snapshot_policy_suspended']
 
+        # Make new call as volume list is not present in lsvolumegroup CLI
+        # If existing volumegroup is a thinclone but command params don't contain
+        #  [type], that is also considered as an attempt to create/change an already
+        #  existing volume. So, it should be recorded to throw error later.
+        is_existing_vg_thinclone = False
+
+        if merged_result and merged_result.get('volume_group_type') == 'thinclone':
+            is_existing_vg_thinclone = True
+        if merged_result and (self.type and self.fromsourcevolumes) or is_existing_vg_thinclone is True:
+            volumes_data = []
+            if self.type == "thinclone" or is_existing_vg_thinclone is True:
+                cmd = 'lsvolumepopulation'
+                cmdopts = {"filtervalue": "volume_group_name={0}".format(self.name)}
+                volumes_data = self.restapi.svc_obj_info(cmd, cmdopts, cmdargs=None)
+            else:
+                # Source volumes for clone volumes needs to be fetched for verification
+                # 1. First get the volumes associated with volumegroup provided
+                associated_volumes_data = []
+                cmd = 'lsvdisk'
+                cmdopts = {"filtervalue": "volume_group_name={0}".format(self.name)}
+                associated_volumes_data = self.restapi.svc_obj_info(cmd, cmdopts, cmdargs=None)
+                vol_names = set()
+                for vol in associated_volumes_data:
+                    vol_names.add(vol['name'])
+
+                # 2. Run lsvdisk for each volume provided in command to get source_volume_name
+                for volname in vol_names:
+                    cmd = 'lsvdisk' + "/" + volname
+                    cmdopts = None
+                    cmdargs = None
+                    single_vol_data = self.restapi.svc_obj_info(cmd, cmdopts, cmdargs=None)
+                    if single_vol_data:
+                        volumes_data.append(single_vol_data[0])
+
+            # Make a set from source volumes of all volumes
+            if volumes_data:
+                source_volumes_set = set()
+                source_volumes_pool_set = set()
+                for volume_data in volumes_data:
+                    # Add the value of 'source_volume_name' to the merged_result
+                    source_volumes_set.add(volume_data['source_volume_name'])
+                merged_result['source_volumes_set'] = source_volumes_set
+                # If pool is provided, verify that pool matches with the one provided in command
+                if self.pool:
+                    cmd = 'lsvdisk'
+                    cmdopts = {"filtervalue": "parent_mdisk_grp_name={0}".format(self.pool)}
+
+                    vdisks_data = self.restapi.svc_obj_info(cmd, cmdopts, cmdargs=None)
+                    remaining_vdisks = len(source_volumes_set)
+                    for vdisk_data in vdisks_data:
+                        if vdisk_data['name'] in source_volumes_set:
+                            source_volumes_pool_set.add(vdisk_data['parent_mdisk_grp_name'])
+                            remaining_vdisks = remaining_vdisks - 1
+                            if remaining_vdisks == 0:
+                                break
+
+                merged_result['source_volumes_pool_set'] = source_volumes_pool_set
+
         return merged_result
 
     def set_parentuid(self):
@@ -555,7 +741,8 @@ class IBMSVCVG(object):
             ('nosnapshotpolicy', not bool(data.get('snapshot_policy_name', ''))),
             ('noreplicationpolicy', not bool(data.get('replication_policy_name', ''))),
             ('partition', data.get('partition_name', '')),
-            ('nopartition', not bool(data.get('partition_name', '')))
+            ('draftpartition', data.get('draft_partition_name', '')),
+            ('nodrreplication', not bool(data.get('replication_policy_name', '')))
         )
 
         props = dict((k, getattr(self, k)) for k, v in params_mapping if getattr(self, k) and getattr(self, k) != v)
@@ -582,14 +769,42 @@ class IBMSVCVG(object):
                 props['snapshotpolicy'] = self.snapshotpolicy
                 props['safeguarded'] = self.safeguarded
 
+        if self.draftpartition:
+            if "draftpartition" in props and props["draftpartition"] == data.get('partition_name'):
+                props.pop("draftpartition")
+                self.log("Partition [%s] which contains Volumegroup [%s] is already published.", self.draftpartition, self.name)
+            elif self.draftpartition == data.get("draft_partition_name"):
+                self.log("Partition [%s] which contains Volumegroup [%s] is already in draft state.", self.draftpartition, self.name)
+
         # Adding snapshotpolicysuspended to props
         if self.snapshotpolicysuspended and self.snapshotpolicysuspended != data.get('snapshot_policy_suspended', ''):
             props['snapshotpolicysuspended'] = self.snapshotpolicysuspended
 
+        if self.type and self.type != data.get('volume_group_type'):
+            # Handle cases other than '' to clone
+            if not (data.get('volume_group_type') == '' and self.type == 'clone'):
+                props['type'] = self.type
+
         self.log("volumegroup props = %s", props)
 
         return props
 
+    def create_transient_snapshot(self):
+        # Required parameters
+        snapshot_cmd = 'addsnapshot'
+        snapshot_opts = {}
+        random_number = ''.join(random.choices('0123456789', k=10))
+        snapshot_name = f"snapshot_{random_number}"
+        snapshot_opts['name'] = snapshot_name
+
+        # Optional parameters
+        snapshot_opts['pool'] = self.module.params.get('pool', '')
+        snapshot_opts['volumes'] = self.module.params.get('fromsourcevolumes', '')
+        snapshot_opts['retentionminutes'] = 5
+
+        self.restapi.svc_run_command(snapshot_cmd, snapshot_opts, cmdargs=None, timeout=10)
+        return snapshot_name
+
     def vg_create(self):
         self.create_validation()
         if self.module.check_mode:
@@ -615,10 +830,23 @@ class IBMSVCVG(object):
             if self.iogrp:
                 cmdopts['iogroup'] = self.iogrp
 
+            if self.fromsourcevolumes:
+                cmdopts['fromsourcevolumes'] = self.fromsourcevolumes
+                if not self.snapshot:
+                    # If thinclone or clone is to be created from volumes, do following:
+                    # 1. Create transient snapshot with 5-min retentionminutes
+                    # 2. Create a thinclone volumegroup from this snapshot
+                    # 3. There is no need to delete snapshot, as it is auto-managed due to retentionminutes
+                    try:
+                        self.snapshot = self.create_transient_snapshot()
+                        cmdopts['snapshot'] = self.snapshot
+                    except Exception as e:
+                        self.log('Exception in creating transient snapshot: %s', format_exc())
+                        self.module.fail_json(msg='Module failed. Error [%s].' % to_native(e))
             self.set_parentuid()
             if self.parentuid:
                 cmdopts['fromsourceuid'] = self.parentuid
-            else:
+            elif self.fromsourcegroup:
                 cmdopts['fromsourcegroup'] = self.fromsourcegroup
 
         if self.ignoreuserfcmaps:
@@ -632,7 +860,8 @@ class IBMSVCVG(object):
 
         if self.partition:
             cmdopts['partition'] = self.partition
-
+        elif self.draftpartition:
+            cmdopts['draftpartition'] = self.draftpartition
         if self.ownershipgroup:
             cmdopts['ownershipgroup'] = self.ownershipgroup
         elif self.safeguardpolicyname:
@@ -653,36 +882,49 @@ class IBMSVCVG(object):
         self.changed = True
 
     def vg_update(self, modify):
+        if 'type' in modify and modify['type'] != "clone":
+            self.module.fail_json(msg='Only type=clone is supported for updating volumegroup.')
         if self.module.check_mode:
             self.changed = True
             return
 
         # update the volume group
         self.log("updating volume group '%s' ", self.name)
+        cmdopts = dict()
         cmdargs = [self.name]
 
         try:
             del modify['snapshotpolicysuspended']
         except KeyError:
-            self.log("snapshotpolicysuspended modification not reqiured!!")
+            self.log("snapshotpolicysuspended modification not required!!")
         else:
             cmd = 'chvolumegroupsnapshotpolicy'
             cmdopts = {'snapshotpolicysuspended': self.snapshotpolicysuspended}
             self.restapi.svc_run_command(cmd, cmdopts, cmdargs)
 
-        cmd = 'chvolumegroup'
-        unmaps = ('noownershipgroup', 'nosafeguardpolicy', 'nosnapshotpolicy', 'noreplicationpolicy')
-        for field in unmaps:
-            cmdopts = {}
-            if field == 'nosafeguardpolicy' and field in modify:
-                cmdopts['nosafeguardedpolicy'] = modify.pop('nosafeguardpolicy')
-                self.restapi.svc_run_command(cmd, cmdopts, cmdargs)
-            elif field in modify:
-                cmdopts[field] = modify.pop(field)
-                self.restapi.svc_run_command(cmd, cmdopts, cmdargs)
-        if modify:
-            cmdopts = modify
+        if modify.get('type') == "clone":
+            # Run converttoclone command
+            cmd = 'converttoclone'
+            cmdopts['volumegroup'] = self.name
+            cmdargs = None
             self.restapi.svc_run_command(cmd, cmdopts, cmdargs)
+            self.log("Volumegroup %s converted from thinclone to clone!!", self.name)
+        else:
+            cmd = 'chvolumegroup'
+            unmaps = ('noownershipgroup', 'nosafeguardpolicy', 'nosnapshotpolicy', 'noreplicationpolicy', 'nodrreplication')
+            for field in unmaps:
+                cmdopts = {}
+                if field == 'nosafeguardpolicy' and field in modify:
+                    cmdopts['nosafeguardedpolicy'] = modify.pop('nosafeguardpolicy')
+                    self.restapi.svc_run_command(cmd, cmdopts, cmdargs)
+                elif field in modify:
+                    cmdopts[field] = modify.pop(field)
+                    self.restapi.svc_run_command(cmd, cmdopts, cmdargs)
+
+            if modify:
+                cmdopts = modify
+                self.restapi.svc_run_command(cmd, cmdopts, cmdargs)
+
         # Any error would have been raised in svc_run_command
         self.changed = True
 
@@ -694,8 +936,10 @@ class IBMSVCVG(object):
         self.log("deleting volume group '%s'", self.name)
 
         cmd = 'rmvolumegroup'
-        cmdopts = None
+        cmdopts = {}
         cmdargs = [self.name]
+        if self.evictvolumes is not None:
+            cmdopts['evictvolumes'] = self.evictvolumes
 
         self.restapi.svc_run_command(cmd, cmdopts, cmdargs)
         # Any error will have been raised in svc_run_command
@@ -732,21 +976,62 @@ class IBMSVCVG(object):
         else:
             if vg_data:
                 if self.state == 'present':
-                    modify = self.vg_probe(vg_data)
-                    if modify:
-                        self.vg_update(modify)
-                        self.msg = "volume group [%s] has been modified." % self.name
+                    is_existing_vg_thinclone = False
+                    existing_vg_type = vg_data.get('volume_group_type')
+                    if existing_vg_type == 'thinclone':
+                        is_existing_vg_thinclone = True
+
+                    if self.type and not self.fromsourcevolumes:
+                        modify = self.vg_probe(vg_data)
+                        if modify:
+                            self.vg_update(modify)
+                            self.msg = "Volume group [%s] has been modified." % self.name
+                        else:
+                            self.msg = "No Modifications detected."
                     else:
-                        self.msg = "No Modifications detected, Volume group already exists."
+                        if (self.type and self.fromsourcevolumes) or is_existing_vg_thinclone is True:
+                            # Check whether provided source volumes are same as in existing volumegroup
+                            volumes_with_existing_vg = None
+                            if 'source_volumes_set' in vg_data:
+                                volumes_with_existing_vg = vg_data['source_volumes_set']
+                            provided_volumes_set = set()
+                            if self.fromsourcevolumes:
+                                provided_volumes_set = set(self.fromsourcevolumes.split(":"))
+                            if volumes_with_existing_vg or provided_volumes_set:
+                                self.changed = False
+                                if not provided_volumes_set and volumes_with_existing_vg:
+                                    self.module.fail_json(
+                                        msg="Existing thinclone volumegroup found.",
+                                        changed=self.changed
+                                    )
+                                if volumes_with_existing_vg != provided_volumes_set:
+                                    self.module.fail_json(
+                                        msg="Parameter [fromsourcevolumes] is invalid for modifying volumegroup.",
+                                        changed=self.changed
+                                    )
+                                elif self.pool and vg_data['source_volumes_pool_set'] and (list(vg_data['source_volumes_pool_set'])[0] != self.pool):
+                                    self.module.fail_json(
+                                        msg="Parameter [pool] is invalid for modifying volumegroup.",
+                                        changed=self.changed
+                                    )
+                                else:
+                                    self.msg = "A volumegroup with name [%s] already exists." % self.name
+                        else:
+                            modify = self.vg_probe(vg_data)
+                            if modify:
+                                self.vg_update(modify)
+                                self.msg = "Volume group [%s] has been modified." % self.name
+                            else:
+                                self.msg = "No Modifications detected, Volume group already exists."
                 else:
                     self.vg_delete()
-                    self.msg = "volume group [%s] has been deleted." % self.name
+                    self.msg = "Volume group [%s] has been deleted." % self.name
             else:
                 if self.state == 'absent':
                     self.msg = "Volume group [%s] does not exist." % self.name
                 else:
                     self.vg_create()
-                    self.msg = "volume group [%s] has been created." % self.name
+                    self.msg = "Volume group [%s] has been created." % self.name
 
         if self.module.check_mode:
             self.msg = 'skipping changes due to check mode.'
