@@ -100,7 +100,6 @@ options:
     - Required for I(import)
     - A valid signed certicate in PEM format (Base64 encoded)
     - Includes the "-----BEGIN CERTIFICATE-----" and "-----END CERTIFICATE-----" lines
-    - Does not exceed 3000 characters in length
   intermeadiate_cert:
     type: str
     description:
@@ -337,7 +336,6 @@ def import_cert(module, array, reimport=False):
         certificate=module.params["certificate"],
         intermediate_certificate=module.params["intermeadiate_cert"],
         key=module.params["key"],
-        key_size=module.params["key_size"],
         passphrase=module.params["passphrase"],
         status="imported",
     )
@@ -370,9 +368,8 @@ def export_cert(module, array):
                     ssl.errors[0].message
                 )
             )
-        ssl_file = open(module.params["export_file"], "w")
-        ssl_file.write(list(ssl.items)[0].certificate)
-        ssl_file.close()
+        with open(module.params["export_file"], "w", encoding="utf-8") as ssl_file:
+            ssl_file.write(list(ssl.items)[0].certificate)
     module.exit_json(changed=changed)
 
 
@@ -448,9 +445,8 @@ def create_csr(module, array):
                 certificate=certificate
             ).items
         )[0].certificate_signing_request
-        csr_file = open(module.params["export_file"], "w")
-        csr_file.write(csr)
-        csr_file.close()
+        with open(module.params["export_file"], "w", encoding="utf-8") as csr_file:
+            csr_file.write(list(csr))
     module.exit_json(changed=changed)
 
 
